Package: depmap
Type: Package
Title: Cancer Dependency Map Data Package
Version: 1.23.0
Authors@R: c(person(given = "Laurent", family = "Gatto",
                    email = "laurent.gatto@uclouvain.be",
                    comment = c(ORCID = "0000-0002-1520-2268"),
                    role = c("cre", "aut")),
            person(given = "Theo", family = "Killian",
                    role = "aut"),
            person(given = "Alexander", family = "Peltzer", role = "ctb",
                    comment = c(ORCID = "0000-0002-6503-2180")))
Description: The depmap package is a data package that accesses datsets from the
    Broad Institute DepMap cancer dependency study using ExperimentHub. Datasets
    from the most current release are available, including RNAI and CRISPR-Cas9
    gene knockout screens quantifying the genetic dependency for select cancer
    cell lines. Additional datasets are also available pertaining to the log
    copy number of genes for select cell lines, protein expression of cell lines
    as measured by reverse phase protein lysate microarray (RPPA), 'Transcript
    Per Million' (TPM) data, as well as supplementary datasets which contain
    metadata and mutation calls for the other datasets found in the current
    release. The 19Q3 release adds the drug_dependency dataset, that contains
    cancer cell line dependency data with respect to drug and drug-candidate
    compounds. The 20Q2 release adds the proteomic dataset that contains
    quantitative profiling of proteins via mass spectrometry. This package will
    be updated on a quarterly basis to incorporate the latest Broad Institute
    DepMap Public cancer dependency datasets. All data made available in this
    package was generated by the Broad Institute DepMap for research purposes
    and not intended for clinical use. This data is distributed under the
    Creative Commons license (Attribution 4.0 International (CC BY 4.0)).
Depends: R (>= 4.1.0), methods, dplyr
Imports: utils, ExperimentHub, AnnotationHub, BiocFileCache, httr2,
        curl, tibble
License: Artistic-2.0
Encoding: UTF-8
RoxygenNote: 7.3.1
Suggests: knitr, rmarkdown, BiocStyle, viridis, gridExtra, ggplot2,
        readr, stringr, tidyverse, magick
VignetteBuilder: knitr
biocViews: ExperimentHub, ExperimentData, ReproducibleResearch,
        RepositoryData, AssayDomainData, CopyNumberVariationData,
        DiseaseModel, CancerData, BreastCancerData, ColonCancerData,
        KidneyCancerData, LeukemiaCancerData, LungCancerData,
        OvarianCancerData, ProstateCancerData, OrganismData,
        Homo_sapiens_Data, PackageTypeData, SpecimenSource,
        CellCulture, Genome, Proteome, StemCell, Tissue
git_url: https://git.bioconductor.org/packages/depmap
git_branch: devel
git_last_commit: bc169e5
git_last_commit_date: 2025-04-15
Repository: Bioconductor 3.22
Date/Publication: 2025-04-17
NeedsCompilation: no
Packaged: 2025-04-17 15:23:15 UTC; biocbuild
Author: Laurent Gatto [cre, aut] (ORCID:
    <https://orcid.org/0000-0002-1520-2268>),
  Theo Killian [aut],
  Alexander Peltzer [ctb] (ORCID:
    <https://orcid.org/0000-0002-6503-2180>)
Maintainer: Laurent Gatto <laurent.gatto@uclouvain.be>

# Generated by roxygen2: do not edit by hand

export(DepMapDataset)
export(DepMapFiles)
export(depmap_RPPA)
export(depmap_TPM)
export(depmap_achilles)
export(depmap_copyNumber)
export(depmap_crispr)
export(depmap_drug_sensitivity)
export(depmap_gene_summary)
export(depmap_metadata)
export(depmap_mutationCalls)
export(depmap_proteomic)
export(depmap_release)
export(depmap_rnai)
export(dmCache)
export(dmFileNames)
export(dmNumFiles)
export(dmTitle)
export(dmfiles)
export(dmget)
export(dmsets)
import(dplyr)
import(methods)
importFrom(AnnotationHub,query)
importFrom(BiocFileCache,BiocFileCache)
importFrom(BiocFileCache,bfcadd)
importFrom(BiocFileCache,bfcquery)
importFrom(BiocFileCache,bfcrpath)
importFrom(ExperimentHub,ExperimentHub)
importFrom(ExperimentHub,createHubAccessors)
importFrom(curl,has_internet)
importFrom(httr2,req_perform)
importFrom(httr2,request)
importFrom(httr2,resp_body_json)
importFrom(tibble,as_tibble)
importFrom(tools,R_user_dir)
importFrom(utils,read.csv)

# The `depmap` package

## Introduction

[depmap](https://github.com/UCLouvain-CBIO/depmap/) is an
R/Bioconductor data package that disseminates cancer dependency omics
datasets from the [Broad Institute
depmap](https://depmap.org/portal/download/) project.

<!-- As the DepMap -->
<!-- screening efforts continue, the -->
<!-- [depmap](https://github.com/UCLouvain-CBIO/depmap/) package will -->
<!-- updated on a quarterly basis, in line with the Broad Institute -->
<!-- [depmap](https://depmap.org/portal/download/) cancer dependency -->
<!-- mapping initiative. -->

- Portal: https://depmap.org/portal/
- Selected publications: see https://depmap.org/portal/depmap/

The [github page](https://github.com/UCLouvain-CBIO/depmap) page is
for active development, issue tracking and forking/pulling purposes.

The [depmap](https://github.com/UCLouvain-CBIO/depmap/) package aims
to provide a reproducible research framework to cancer dependency data
described by [Tsherniak, Aviad, et al. "Defining a cancer dependency
map." Cell 170.3 (2017):
564-576.](https://www.ncbi.nlm.nih.gov/pubmed/28753430).

To get an overview of the package, see the depmap vignette.

## Installation

To install [depmap](https://github.com/UCLouvain-CBIO/depmap/), the
[BiocManager](https://cran.r-project.org/web/packages/BiocManager/index.html)
Bioconductor Project Package Manager is required. If
[BiocManager](https://cran.r-project.org/web/packages/BiocManager/index.html)
is not already installed, it will need to be done so beforehand with
(within R) `install.packages("BiocManager")`. Once it is installed,
`depmap` can be installed from Biocondctor:

```r
install.packages("BiocManager")
BiocManager::install("depmap")
```

To install the version from GitHub, use

```r
install.packages("BiocManager")
BiocManager::install("UCLouvain-CBIO/depmap")
```

## Questions

Feel also free to open a GitHub
[issue](https://github.com/UCLouvain-CBIO/depmap/issues), in
particular for bug reports.

Questions can also be posted on the [Bioconductor
forum](https://support.bioconductor.org/).

## Contributing

Contributions to the package are more than welcome. If you want to
contribute to this package, you should follow the same conventions as
the rest of the functions. Please do get in touch (preferable opening
a [github issue](https://github.com/UCLouvain-CBIO/depmap/issues/)) to
discuss any suggestions.

Please note that this project is released with a [Contributor Code of
Conduct](https://github.com/UCLouvain-CBIO/depmap/blob/master/CONDUCT.md).
By participating in this project you agree to abide by its terms.

The .csv files in this package originate from the Broad Institute Depmap Data 
Portal: https://depmap.org/portal/download/

These datafiles have been put in long format via dplyr for usage with R packages
such as ggplot2. The only modification of the datasets is that the datasets have
been renamed to shorter names (such as "metadata") and the column names have
been changed to snake case. The data has been put on ExperimentHub AWS for easy
access and to keep this package lightweight. 

If the need arises to reproduce the data files manually, they can be generated
by running the make-data.R scripts (of the appropriate version) found in this
directory. In order to generate the .rda data files correctly, it is necessary
to create an empty directory ./inst/eh_data to generate the data per the
make-data.R scripts. 

In this directory, save ./inst/scripts/data.R that load the csv files and 
save the rda files directly in ./data/.

```
## example
ccle_depmap <- read.csv("../extdata/CCLE_depMap_19Q1_TPM.zip")
## cleaning, ...
save(ccle_depmap, file = "../../data/ccle_depmap.rda", 
     compress = "xz", compression_level = 9)
```

### =========================================================================
### Make 19Q1 depmap data
### -------------------------------------------------------------------------
###

## This scripts documents how to download and generate the data files.
## Note 1: This scipt assumes (!!!) that it is run in ./depmap/inst/scripts/ and
## saves the resulting .rda files in ./depmap/inst/data  
## (e.g. *setwd(./depmap/inst/scripts/)*)
## Note 2: the Broad Institute may change the download urls for these datasets.
## If the link to one of these datasets is broken, please contact the package
## maintainer. All Depmap data can be downloaded from the API at
## https://depmap.org/portal/download/ even if the specific links may change

library("readr")
library("dplyr")
library("tidyr")
library("ExperimentHub")

##########################################
## EH2266 depmap `metadata_19Q1` dataset
##########################################

##  data cleaning of `metadata` dataset

### loading data (downloading .csv file from online source)
url_1 <- "https://depmap.org/portal/download/api/download/external?file_name=processed_portal_downloads%2Fdepmap-public-cell-line-metadata-183e.4%2FDepMap-2019q1-celllines_v2.csv"
depmap_19Q1_cell_lines <- read_csv(url_1)

### DepMap-2019q1-celllines.csv data renamed to `metadata`
metadata_19Q1 <- depmap_19Q1_cell_lines

#### Rename `metadata` columns to contain underscores and be in camel case
## names(metadata) 
names(metadata_19Q1)[1:9] <- c("depmap_id", "cell_line", "aliases", "cosmic_id", 
                                "sanger_id", "primary_disease",
                               "subtype_disease", "gender", "source")
### visual check
# head(metadata_19Q1)

### saving cleaned and converted `metadata` data as .rda file
save(metadata_19Q1, file = "../eh_data/metadata_19Q1.rda",
     compress = "xz", compression_level = 9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")
# EH2266 <- x[["EH2266"]]

##########################################
## `depmap_id_to_name_19Q1` map `depmap_id` to `cell_line`
##########################################

## The subset of `metadata`, `depmap_id_to_name_19Q1` is used to map 
## `cell_line` and depmap_id via left_join in other depmap datasets that do not
## contain both variables. If you are generating the depmap data from scratch,
## you will need to run the following code to generate the data correctly.

### `depmap_id_to_name` to add `depmap_id` or `cell_line` to other datasets
depmap_id_to_name_19Q1 <- metadata_19Q1 %>% dplyr::select(depmap_id, cell_line)

### visual check
# head(depmap_id_to_name_19Q1)

##########################################
## EH2265 depmap `mutationCalls_19Q1` dataset
##########################################

## data cleaning of `mutationCalls` dataset

### loading data (downloading .csv file from online source)
url_2 <- "https://depmap.org/portal/download/api/download/external?file_name=ccle%2Fdepmap-mutation-calls-9a1a.9%2Fdepmap_19Q1_mutation_calls_v2.csv"
depmap_19Q1_mutation_calls <- read_csv(url_2)

### depmap_19Q1_mutation_calls data renamed to `mutationCalls`
mutationCalls_19Q1 <- depmap_19Q1_mutation_calls

#### drop superfluous first row
mutationCalls_19Q1[[1]] <- NULL

#### rename last column to depmap_id
#names(mutationCalls_19Q1)
names(mutationCalls_19Q1)[1:35] <- c("gene_name", "entrez_id", "ncbi_build",            
                                    "chromosome", "start_pos", "end_pos",
                                    "strand", "var_class","var_type",
                                    "ref_allele","tumor_seq_allele1","dbSNP_RS", 
                                    "dbSNP_val_status", "genome_change",
                                    "annotation_transcript",
                                    "tumor_sample_barcode", "cDNA_change",
                                    "codon_change", "protein_change",        
                                    "is_deleterious", "is_tcga_hotspot",
                                    "tcga_hsCnt", "is_cosmic_hotspot",
                                    "cosmic_hsCnt", "ExAC_AF", "VA_WES_AC",
                                    "CGA_WES_AC", "sanger_WES_AC", 
                                    "sanger_recalib_WES_AC","RNAseq_AC","HC_AC",                 
                                    "RD_AC", "WGS_AC", "var_annotation",
                                    "depmap_id") #names converted to snake case

### rearrange columns into same column format as other datasets
mutationCalls_19Q1 <- mutationCalls_19Q1 %>%
    select(depmap_id, gene_name, entrez_id, ncbi_build, chromosome, start_pos,
           end_pos, strand, var_class, var_type, ref_allele, tumor_seq_allele1,
           dbSNP_RS, dbSNP_val_status, genome_change, annotation_transcript,
           tumor_sample_barcode, cDNA_change, codon_change, protein_change,
           is_deleterious, is_tcga_hotspot, tcga_hsCnt, is_cosmic_hotspot,
           cosmic_hsCnt, ExAC_AF, VA_WES_AC, CGA_WES_AC, sanger_WES_AC,
           sanger_recalib_WES_AC, RNAseq_AC, HC_AC, RD_AC, WGS_AC,
           var_annotation)

### visual check
# head(mutationCalls_19Q1)

### saving cleaned and converted `mutationCalls` data as .rda file
save(mutationCalls_19Q1, file = "../eh_data/mutationCalls_19Q1.rda",
     compress = "xz", compression_level = 9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")
# EH2265 <- x[["EH2265"]]

##########################################
## EH2262 depmap `copyNumber_19Q1` dataset
##########################################

##  data cleaning of `copyNumber` dataset 

### loading data (downloading .csv file from online source)
url_3 <- "https://depmap.org/portal/download/api/download/external?file_name=ccle%2Fdepmap-wes-cn-data-97cc.14%2Fpublic_19Q1_gene_cn.csv"
public_19Q1_gene_cn  <- read_csv(url_3)

### public_19Q1_gene_cn.csv data renamed to `copyNumber`
copyNumber_19Q1 <- public_19Q1_gene_cn

### rename column first column to "depmap_id"
names(copyNumber_19Q1)[1] <- "depmap_id"

### gather into long form on columns: `depmap_id`, `gene`, `logCopyNumber`
copyNumber_19Q1_long <- gather(copyNumber_19Q1, gene, log_copy_number,
                               -depmap_id)

### mutate gene column into `gene_name` and `entrez_id`
copyNumber_19Q1_long <- copyNumber_19Q1_long %>% 
    mutate(entrez_id = gsub("&", ";", sub("\\)", "", sub("^.+ \\(", "", gene))),
           gene_name = gsub("&", ";", sub(" \\(.+\\)$", "", gene))) 

### left_join `copyNumber` & `depmap_id_to_name_19Q1` on `depmap_id`,`cell_line`     
copyNumber_19Q1 <- copyNumber_19Q1_long %>% 
    left_join(depmap_id_to_name_19Q1, by = c("depmap_id" = "depmap_id"))

### rearrange columns into same column format as other datasets
copyNumber_19Q1 <- copyNumber_19Q1 %>% 
                                    select(depmap_id, gene, log_copy_number,
                                           entrez_id, gene_name, cell_line) %>%
                                           type_convert(cols(entrez_id = "i"))
### visual check
# head(copyNumber_19Q1)

### saving cleaned and converted `copyNumber` data as .rda file
save(copyNumber_19Q1, file = "../eh_data/copyNumber_19Q1.rda",
     compress = "xz", compression_level = 9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")
# EH2262 <- x[["EH2262"]]

##########################################
## EH2261 depmap `crispr_19Q1` dataset
##########################################

##  data cleaning of `crispr` dataset`

### loading data (downloading .csv file from online source)
url_4 <- "https://ndownloader.figshare.com/files/14221385"
gene_effect_corrected <- read_csv(url_4)

### gene_effect_corrected.csv data renamed to `crispr`
crispr_19Q1 <- gene_effect_corrected

### rename column first column to "depmap_id"
names(crispr_19Q1)[1] <-"depmap_id"

### gather cripsr into long form with columns: `depmap_id`, `gene`, `dependency`
crispr_19Q1_long <- gather(crispr_19Q1, gene, dependency, -depmap_id)

### mutate gene into `gene_name` and `entrez_id`
crispr_19Q1_long <- crispr_19Q1_long %>% 
    mutate(entrez_id = gsub("&", ";", sub("\\)", "", sub("^.+ \\(", "", gene))),
           gene_name = gsub("&", ";", sub(" \\(.+\\)$", "", gene))) 

### left_join `crispr_long` & `depmap_id_to_name_19Q1` to add `cell_line` column
crispr_19Q1 <- crispr_19Q1_long %>% left_join(depmap_id_to_name_19Q1, 
                                    by = c("depmap_id" = "depmap_id"))

### rearrange columns into same column format as other datasets
crispr_19Q1 <- crispr_19Q1 %>% select(depmap_id, gene, dependency, entrez_id,
                                      gene_name, cell_line) %>%
                                      type_convert(cols(entrez_id = "i"))
### visual check
# head(crispr_19Q1)

### saving cleaned and converted `crispr` data as .rda file
save(crispr_19Q1, file = "../eh_data/crispr_19Q1.rda",
     compress = "xz", compression_level = 9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")
# EH2261 <- x[["EH2261"]]

##########################################
## EH2264 depmap `TPM_19Q1` dataset
##########################################

## data cleaning of `TPM` dataset

### loading data (downloading .csv file from online source)
url_5 <- "https://depmap.org/portal/download/api/download/external?file_name=ccle%2Fdepmap-rnaseq-expression-data-ccd0.12%2FCCLE_depMap_19Q1_TPM.csv"
CCLE_depMap_19Q1_TPM  <- read_csv(url_5)

### CCLE_depMap_19Q1_TPM.csv data renamed to `TPM`
TPM_19Q1 <- CCLE_depMap_19Q1_TPM

### rename column first column to "depmap_id"
names(TPM_19Q1)[1] <-"depmap_id"

### gather `TPM` into long form on columns: `depmap_id`, `gene`, `expression`
TPM_19Q1_long <- gather(TPM_19Q1, gene, expression, -depmap_id)

### mutate gene into gene_name and ensembl_id
TPM_19Q1_long <- TPM_19Q1_long %>% 
    mutate(ensembl_id = gsub("&", ";", sub("\\)", "", sub("^.+ \\(", "",gene))),
           gene_name = gsub("&", ";", sub(" \\(.+\\)$", "", gene))) 

### left_join join `TPM` and `depmap_id_to_name_19Q1` to add `cell_line` column
TPM_19Q1 <- TPM_19Q1_long %>% left_join(depmap_id_to_name_19Q1, 
                              by = c("depmap_id" = "depmap_id"))

### rearrange columns into same column format as other datasets
TPM_19Q1 <- TPM_19Q1 %>% select(depmap_id, gene, expression, ensembl_id,
                                gene_name, cell_line)
### visual check
# head(TPM_19Q1)

### saving cleaned and converted `TPM` data as .rda file
save(TPM_19Q1, file = "../eh_data/TPM_19Q1.rda", compress="xz",
     compression_level=9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")
# EH2264 <- x[["EH2264"]]

##########################################
## EH2263 depmap `RPPA_19Q1` dataset
##########################################

## data cleaning of `RPPA` dataset

### loading data (downloading .csv file from online source)
url_6 <- "https://depmap.org/portal/download/api/download/external?file_name=ccle%2FCCLE_RPPA_20180123.csv"
CCLE_RPPA_20180123  <- read_csv(url_6)

### CCLE_RPPA_20180123.csv data renamed to `RPPA`
RPPA_19Q1 <- CCLE_RPPA_20180123

### rename column first column to "cell_line"
names(RPPA_19Q1)[1] <-"cell_line"

### gather cell line columns and split gene name into gene_name and entrez_id
RPPA_19Q1_long <- RPPA_19Q1 %>% gather(antibody, expression, -cell_line)

### join cell_line name    
RPPA_19Q1 <- RPPA_19Q1_long %>% left_join(depmap_id_to_name_19Q1, 
                                by = c("cell_line" = "cell_line"))

### rearrange columns into same column format as other datasets
RPPA_19Q1 <- RPPA_19Q1 %>% select(cell_line, antibody, expression, depmap_id)

### visual check
# head(RPPA_19Q1)

### saving cleaned and converted `RPPA` data as .rda file
save(RPPA_19Q1, file="../eh_data/RPPA_19Q1.rda", compress="xz",
     compression_level=9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")
# EH2263 <- x[["EH2263"]]

##########################################
## EH2260 depmap `rnai_19Q1` dataset
##########################################

## data cleaning of `rnai` dataset

### loading data (downloading .csv file from online source)
url_7 <- "https://ndownloader.figshare.com/files/13515395"
D2_combined_genetic_dependency_scores  <- read_csv(url_7)

### D2_combined_genetic_dependency_scores.csv data renamed to `rnai`
rnai_19Q1 <- D2_combined_genetic_dependency_scores

### rename column first column to "gene"
names(rnai_19Q1)[1] <- "gene"

### gather rnai into long form with columns: depmap_id, gene and dependency
rnai_19Q1 <- gather(rnai_19Q1, key = cell_line, value = dependency, -gene) %>%
    mutate(entrez_id = gsub("&", ";", sub("\\)", "", sub("^.+ \\(", "", gene))),
           gene_name = gsub("&", ";", sub(" \\(.+\\)$", "", gene))) %>%
    left_join(depmap_id_to_name_19Q1, by = c("cell_line" = "cell_line"))

### rearrange columns into same column format as other datasets
rnai_19Q1 <- rnai_19Q1 %>% select(gene, cell_line, dependency, entrez_id,
                                  gene_name, depmap_id) %>%
                                  type_convert(cols(entrez_id = "i"))

### visual check
# head(rnai_19Q1)

### saving cleaned and converted `rnai` data as .rda file
save(rnai_19Q1, file="../eh_data/rnai_19Q1.rda", compress="xz",
     compression_level=9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")
# EH2260 <- x[["EH2260"]]

#' depmap: Cancer Dependency Map Data Package
#'
#' The depmap package is a data package that accesses datsets from the Broad
#' Institute DepMap cancer dependency study using ExperimentHub. Datasets from
#' the most current release are available, including RNAI and CRISPR-Cas9 gene
#' knockout screens quantifying the genetic dependency for select cancer cell
#' lines. Additional datasets are also available pertaining to the log copy
#' number of genes for select cell lines, protein expression of cell lines as
#' measured by reverse phase protein lysate microarray (RPPA), 'Transcript Per
#' Million' (TPM) data, chemical dependecy (drug_sensativity), mass spectrometry
#' proteomic quantification (proteomic) as well as supplementary datasets which
#' contain metadata and mutation calls for the other datasets found in the
#' current release. This package will be updated on a quarterly basis to
#' incorporate the latest Broad Institute DepMap Public cancer dependency
#' datasets. All data made available in this package was generated by the Broad
#' Institute DepMap for research purposes and not intended for clinical use.
#' This data is distributed under the Creative Commons license
#' (Attribution 4.0 International (CC BY 4.0)).
#'
#' See the package vignettes and respective man pages for details.
#'
#' @name depmap
"_PACKAGE"

##' @title Returns the depmap release
##' @return `character(1)` with the depmap release
##' @md
##' @export
depmap_release <- function() "22Q2"

#' @import methods
NULL

### =========================================================================
### Make 19Q2 depmap data
### -------------------------------------------------------------------------
###

## This scripts documents how to download and generate the data files.
## Note 1: This scipt assumes (!!!) that it is run in ./depmap/inst/scripts/ and
## saves the resulting .rda files in ./depmap/inst/data  
## (e.g. *setwd(./depmap/inst/scripts/)*)
## Note 2: the Broad Institute may change the download urls for these datasets.
## If the link to one of these datasets is broken, please contact the package
## maintainer. All Depmap data can be downloaded from the API at
## https://depmap.org/portal/download/ even if the specific links may change

library("readr")
library("dplyr")
library("tidyr")
library("ExperimentHub")

##########################################
## EH2556 depmap `metadata_19Q2` dataset
##########################################

##  data cleaning of `metadata` dataset

### loading data (downloading .csv file from online source)
url_8 <- "https://ndownloader.figshare.com/files/15023525"
sample_info <- read_csv(url_8)

### DepMap-2019q1-celllines.csv data renamed to `metadata`
metadata_19Q2 <- sample_info
# names(metadata_19Q2)
# [1] "DepMap_ID"               "stripped_cell_line_name"
# [3] "CCLE_name"               "alias"                  
# [5] "COSMIC_ID"               "Sanger_ID"              
# [7] "disease"                 "disease_sutype"         
# [9] "disease_sub_subtype"     "gender"                 
# [11] "source"                  "Achilles_n_replicates"  
# [13] "cell_line_NNMD"          "culture_type"           
# [15] "culture_medium"          "cas9_activity"  


#### Rename `metadata` columns to contain underscores and be in camel case
## note: "metadata_19Q2" has different columns than "metadata_19Q2"
names(metadata_19Q2)[1:9] <-c("depmap_id", "stripped_cell_line_name",
                               "cell_line", "aliases", "cosmic_id", 
                               "sanger_id", "primary_disease","subtype_disease",
                               "sub_subtype_disease")

### visual check
# head(metadata_19Q2)

### saving cleaned and converted `metadata` data as .rda file
save(metadata_19Q2, file = "../eh_data/metadata_19Q2.rda",
     compress = "xz", compression_level = 9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")
# EH2556 <- x[["EH2556"]]

##########################################
## `depmap_id_to_name_19Q2 map `depmap_id` to `cell_line`
##########################################

##  generation of `metadata` subset `depmap_id_to_name_19Q2`

## The subset of `metadata`, `depmap_id_to_name_Q2` is used to map `cell_line`
## and depmap_id via left_join in other depmap datasets that do not contain
## both variables. If you are generating the depmap data from scratch, you will
## need to run the following code to generate the data correctly.

### `depmap_id_to_name` to add `depmap_id` or `cell_line` to other datasets
depmap_id_to_name_19Q2 <- metadata_19Q2 %>% dplyr::select(depmap_id, cell_line)

### visual check
# head(depmap_id_to_name_19Q2)

##########################################
## EH2555 depmap `mutationCalls_19Q2` dataset
##########################################

## data cleaning of `mutationCalls` dataset

### loading data (downloading .csv file from online source)
url_9 <- "https://ndownloader.figshare.com/files/15023498"
CCLE_mutations_19Q2 <- read_csv(url_9)

### depmap_19Q1_mutation_calls data renamed to `mutationCalls`
mutationCalls_19Q2 <- CCLE_mutations_19Q2
# names(mutationCalls_19Q2)

#### drop superfluous first two rows
mutationCalls_19Q2["X1"] <- NULL
mutationCalls_19Q2["X"] <- NULL

#### rename last column to depmap_id
# head(mutationCalls_19Q2)
# [3] "Hugo_Symbol"            "Entrez_Gene_Id"        
# [5] "NCBI_Build"             "Chromosome"            
# [7] "Start_position"         "End_position"          
# [9] "Strand"                 "Variant_Classification"
# [11] "Variant_Type"           "Reference_Allele"      
# [13] "Tumor_Seq_Allele1"      "dbSNP_RS"              
# [15] "dbSNP_Val_Status"       "Genome_Change"         
# [17] "Annotation_Transcript"  "Tumor_Sample_Barcode"  
# [19] "cDNA_Change"            "Codon_Change"          
# [21] "Protein_Change"         "isDeleterious"         
# [23] "isTCGAhotspot"          "TCGAhsCnt"             
# [25] "isCOSMIChotspot"        "COSMIChsCnt"           
# [27] "ExAC_AF"                "CGA_WES_AC"            
# [29] "SangerWES_AC"           "SangerRecalibWES_AC"   
# [31] "RNAseq_AC"              "HC_AC"                 
# [33] "RD_AC"                  "WGS_AC"                
# [35] "Variant_annotation"     "DepMap_ID" 

## note: "mutationCalls_19Q2" has different columns than "mutationCalls_19Q1"
## the variable "VA_WES_AC" is no longer present in this dataset, unlike
## previous releases! 
names(mutationCalls_19Q2)[1:34] <- c("gene_name", "entrez_id", "ncbi_build",            
                                "chromosome", "start_pos", "end_pos", "strand", 
                                "var_class","var_type", "ref_allele", 
                                "tumor_seq_allele1", "dbSNP_RS", 
                                "dbSNP_val_status", "genome_change",
                                "annotation_transcript", "tumor_sample_barcode", 
                                "cDNA_change", "codon_change", "protein_change",        
                                "is_deleterious", "is_tcga_hotspot","tcga_hsCnt",
                                "is_cosmic_hotspot", "cosmic_hsCnt", "ExAC_AF", 
                                "CGA_WES_AC", "sanger_WES_AC", 
                                "sanger_recalib_WES_AC", "RNAseq_AC", "HC_AC",                 
                                "RD_AC", "WGS_AC", "var_annotation","depmap_id")

### rearrange columns into same column format as other datasets
mutationCalls_19Q2 <- mutationCalls_19Q2 %>%
    select(depmap_id, gene_name, entrez_id, ncbi_build, chromosome, start_pos,
           end_pos, strand, var_class, var_type, ref_allele, tumor_seq_allele1,
           dbSNP_RS, dbSNP_val_status, genome_change, annotation_transcript,
           tumor_sample_barcode, cDNA_change, codon_change, protein_change, 
           is_deleterious, is_tcga_hotspot, tcga_hsCnt, is_cosmic_hotspot,
           cosmic_hsCnt, ExAC_AF, CGA_WES_AC, sanger_WES_AC,
           sanger_recalib_WES_AC, RNAseq_AC, HC_AC, RD_AC, WGS_AC,
           var_annotation)

### visual check
# head(mutationCalls_19Q2)

### saving cleaned and converted `mutationCalls` data as .rda file
save(mutationCalls_19Q2, file = "../eh_data/mutationCalls_19Q2.rda",
     compress = "xz", compression_level = 9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")
# EH2555 <- x[["EH2555"]]

##########################################
## EH2552 depmap `copyNumber_19Q2` dataset
##########################################

##  data cleaning of `copyNumber` dataset 

### loading data (downloading .csv file from online source)
url_10 <- "https://ndownloader.figshare.com/files/15023495"
CCLE_gene_cn_19Q2 <- read_csv(url_10)

### public_19Q1_gene_cn.csv data renamed to `copyNumber`
copyNumber_19Q2 <- CCLE_gene_cn_19Q2
#names(copyNumber_19Q2)

### rename column first column to "depmap_id"
names(copyNumber_19Q2)[1] <- "depmap_id"

### gather into long form on columns: `depmap_id`, `gene`, `logCopyNumber`
copyNumber_19Q2_long <- gather(copyNumber_19Q2, gene, log_copy_number,
                               -depmap_id)

### mutate gene column into `gene_name` and `entrez_id`
copyNumber_19Q2_long <- copyNumber_19Q2_long %>% 
    mutate(entrez_id = gsub("&", ";", sub("\\)", "", sub("^.+ \\(", "", gene))),
           gene_name = gsub("&", ";", sub(" \\(.+\\)$", "", gene))) 

### left_join `copyNumber` & `depmap_id_to_name_19Q2` on `depmap_id`, 
## `cell_line`     
copyNumber_19Q2 <- copyNumber_19Q2_long %>% 
    left_join(depmap_id_to_name_19Q2, by = c("depmap_id" = "depmap_id"))

### rearrange columns into same column format as other datasets
copyNumber_19Q2 <- copyNumber_19Q2 %>% 
                        select(depmap_id, gene, log_copy_number,
                               entrez_id, gene_name, cell_line) %>%
                               type_convert(cols(entrez_id = "i"))
### visual check
# head(copyNumber_19Q2)

### saving cleaned and converted `copyNumber` data as .rda file
save(copyNumber_19Q2, file = "../eh_data/copyNumber_19Q2.rda",
     compress = "xz", compression_level = 9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")
# EH2552 <- x[["EH2552"]]

##########################################
## EH2551 depmap `crispr_19Q2` dataset
##########################################

##  data cleaning of `crispr` dataset`

### loading data (downloading .csv file from online source)
url_11 <- "https://ndownloader.figshare.com/files/15023465"
Achilles_gene_effect_19Q2 <- read_csv(url_11)

### gene_effect_corrected.csv data renamed to `crispr`
crispr_19Q2 <- Achilles_gene_effect_19Q2

### rename column first column to "depmap_id"
names(crispr_19Q2)[1] <-"depmap_id"

### gather cripsr into long form with columns: `depmap_id`, `gene`, `dependency`
crispr_19Q2_long <- gather(crispr_19Q2, gene, dependency, -depmap_id)

### mutate gene into `gene_name` and `entrez_id`
crispr_19Q2_long <- crispr_19Q2_long %>% 
    mutate(entrez_id = gsub("&", ";", sub("\\)", "", sub("^.+ \\(", "", gene))),
           gene_name = gsub("&", ";", sub(" \\(.+\\)$", "", gene))) 

### left_join `crispr_long` and `depmap_id_to_name` to add `cell_line` column   
crispr_19Q2 <- crispr_19Q2_long %>% left_join(depmap_id_to_name_19Q2, 
                                    by = c("depmap_id" = "depmap_id"))

### rearrange columns into same column format as other datasets
crispr_19Q2 <- crispr_19Q2 %>% select(depmap_id, gene, dependency, entrez_id,
                                      gene_name, cell_line) %>%
                                      type_convert(cols(entrez_id = "i"))
### visual check
# head(crispr_19Q2)

### saving cleaned and converted `crispr` data as .rda file
save(crispr_19Q2, file = "../eh_data/crispr_19Q2.rda",
     compress = "xz", compression_level = 9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")
# EH2551 <- x[["EH2551"]]

##########################################
## EH2554 depmap `TPM_19Q2` dataset
##########################################

## data cleaning of `TPM` dataset

### loading data (downloading .csv file from online source)
url_12 <- "https://ndownloader.figshare.com/files/15023483"
CCLE_expression_full_19Q2 <- read_csv(url_12)

### CCLE_depMap_19Q1_TPM.csv data renamed to `TPM`
TPM_19Q2 <- CCLE_expression_full_19Q2

### rename column first column to "depmap_id"
names(TPM_19Q2)[1] <-"depmap_id"

### gather `TPM` into long form on columns: `depmap_id`, `gene`, `expression`
TPM_19Q2_long <- gather(TPM_19Q2, gene, expression, -depmap_id)

### mutate gene into gene_name and ensembl_id
TPM_19Q2_long <- TPM_19Q2_long %>% 
    mutate(ensembl_id = gsub("&", ";", sub("\\)", "", sub("^.+ \\(", "",gene))),
           gene_name = gsub("&", ";", sub(" \\(.+\\)$", "", gene))) 

### left_join join `TPM` and `depmap_id_to_name_19Q2` to add `cell_line` column
TPM_19Q2 <- TPM_19Q2_long %>% left_join(depmap_id_to_name_19Q2, 
                              by = c("depmap_id" = "depmap_id"))

### rearrange columns into same column format as other datasets
TPM_19Q2 <- TPM_19Q2 %>% select(depmap_id, gene, expression, ensembl_id,
                                gene_name, cell_line)
### visual check
# head(TPM_19Q2)

### saving cleaned and converted `TPM` data as .rda file
save(TPM_19Q2, file = "../eh_data/TPM_19Q2.rda", compress="xz",
     compression_level=9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")
# EH2554 <- x[["EH2554"]]

##########################################
## EH2553 depmap `RPPA_19Q2` dataset
##########################################

## data cleaning of `RPPA` dataset

### loading data (downloading .csv file from online source)
url_13 <- "https://depmap.org/portal/download/api/download/external?file_name=ccle%2FCCLE_RPPA_20180123.csv"
CCLE_RPPA_20180123_19Q2 <- read_csv(url_13)

### CCLE_RPPA_20180123.csv data renamed to `RPPA`
RPPA_19Q2 <- CCLE_RPPA_20180123_19Q2

### rename column first column to "cell_line"
names(RPPA_19Q2)[1] <-"cell_line"

### gather cell line columns and split gene name into gene_name and entrez_id
RPPA_19Q2_long <- RPPA_19Q2 %>% gather(antibody, expression, -cell_line)

### join cell_line name    
RPPA_19Q2 <- RPPA_19Q2_long %>% left_join(depmap_id_to_name_19Q2, 
                                by = c("cell_line" = "cell_line"))

### rearrange columns into same column format as other datasets
RPPA_19Q2 <- RPPA_19Q2 %>% select(cell_line, antibody, expression, depmap_id) 

### visual check
# head(RPPA_19Q2)

### saving cleaned and converted `RPPA` data as .rda file
save(RPPA_19Q2, file="../eh_data/RPPA_19Q2.rda", compress="xz",
     compression_level=9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")
# EH2553 <- x[["EH2553"]]

##########################################
## EH2550 depmap `rnai_19Q2` dataset
##########################################

## data cleaning of `rnai` dataset

### loading data (downloading .csv file from online source)
url_14 <- "https://ndownloader.figshare.com/files/13515395"
D2_combined_gene_dep_scores_19Q2 <- read_csv(url_14)

### D2_combined_genetic_dependency_scores.csv data renamed to `rnai`
rnai_19Q2 <- D2_combined_gene_dep_scores_19Q2

### rename column first column to "gene"
names(rnai_19Q2)[1] <- "gene"

### gather rnai into long form with columns: depmap_id, gene and dependency
rnai_19Q2 <- gather(rnai_19Q2, key = cell_line, value = dependency, -gene) %>%
    mutate(entrez_id = gsub("&", ";", sub("\\)", "", sub("^.+ \\(", "", gene))),
           gene_name = gsub("&", ";", sub(" \\(.+\\)$", "", gene))) %>%
    left_join(depmap_id_to_name_19Q2, by = c("cell_line" = "cell_line"))

### rearrange columns into same column format as other datasets
rnai_19Q2 <- rnai_19Q2 %>% select(gene, cell_line, dependency, entrez_id,
                                  gene_name, depmap_id) %>%
                                  type_convert(cols(entrez_id = "i"))
### visual check
# head(rnai_19Q2)

### saving cleaned and converted `rnai` data as .rda file
save(rnai_19Q2, file="../eh_data/rnai_19Q2.rda", compress="xz",
     compression_level=9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")
# EH2550 <- x[["EH2550"]]

### =========================================================================
### depmap metadata 20Q1 data 
### -------------------------------------------------------------------------
### this script generates the metadata_20Q1.csv
## note: this script assumes that your current directory is depmap/inst/scripts/

meta_20Q1 <- data.frame(
    Title = c(paste0("crispr_20Q1"), 
              paste0("copyNumber_20Q1"),
              paste0("TPM_20Q1"),
              paste0("mutationCalls_20Q1"),
              paste0("metadata_20Q1")),
    Description = c( paste0("(CERES) Batch and off-target corrected CRISPR-Cas9 ", 
                           "gene knockdout dependency data for 18333 genes, ", 
                           "739 cell lines, 29 primary diseases and 26 ", 
                           "lineages."), 
                    paste0("WES log copy number data for 27639 genes, 1713 ", 
                           "cell lines, 35 primary diseases and 36 lineages."),
                    paste0("CCLE 'Transcript Per Million' (TPM) RNAseq gene ", 
                           "expression data (in scale scale (log2(TPM+1))) ", 
                           "for protein coding genes from 19144 genes, 1270 ", 
                           "cancer cell lines, 32 primary diseases and 34 ", 
                           "lineages."), 
                    paste0("Merged mutation calls (for coding region, germline ", 
                           "filtered) and includes data from 18802 genes, 1697 ", 
                           "cell lines, 35 primary diseases and 36 lineages. "),
                    paste0("Metadata for cell lines in the 20Q1 DepMap release, ", 
                           "for 0 genes, 1775 cell lines, 35 primary diseases ", 
                           "and 37 lineages.")),
    BiocVersion = "3.12",
    Genome = "", 
    SourceType = "CSV", 
    SourceUrl = c(paste0("https://ndownloader.figshare.com/files/21521910"),
                  paste0("https://ndownloader.figshare.com/files/21521964"),
                  paste0("https://ndownloader.figshare.com/files/21521940"),
                  paste0("https://ndownloader.figshare.com/files/21521967"),
                  paste0("https://ndownloader.figshare.com/files/21522000")),
    SourceVersion = "Feb 20 2020",
    Species = "Homo sapiens",
    TaxonomyId = 9606,
    Coordinate_1_based = TRUE,
    DataProvider = "Broad Institute",
    Maintainer = "Theo Killian <theodore.killian@uclouvain.be>",
    RDataClass = "tibble",
    DispatchClass = "Rda",
    RDataPath = c(paste0("depmap/crispr_20Q1.rda"), 
                  paste0("depmap/copyNumber_20Q1.rda"),
                  paste0("depmap/TPM_20Q1.rda"),
                  paste0("depmap/mutationCalls_20Q1.rda"),
                  paste0("depmap/metadata_20Q1.rda")),
    Tags=paste0("ExperimentHub, ExperimentData, ReproducibleResearch, RepositoryData, AssayDomainData, ", 
                "CopyNumberVariationData, DiseaseModel, CancerData, BreastCancerData, ColonCancerData, ", 
                "KidneyCancerData, LeukemiaCancerData, LungCancerData, OvarianCancerData, ProstateCancerData", 
                "OrganismData, Homo_sapiens_Data, PackageTypeData, SpecimenSource, CellCulture, Genome, ", 
                "Proteome, StemCell, Tissue"),
    Notes = "This dataset is from the 20Q1 release")

write.csv(meta_20Q1, file = "../extdata/metadata_20Q1.csv", row.names = FALSE)
## to upload this metadata to EH, enter the following into the CL
## ExperimentHubData::makeExperimentHubMetadata("~/tmp/depmap/", fileName = "metadata_20Q1.csv")

#' drug_sensitivity_21Q2
#'
#' The `drug_sensitivity` dataset contains the 19Q3 replicate collapsed logfold
#' change values relative to DMSO, corrected for experimental confounders using
#' ComBat. This dataset contains information refering to 4686 compounds, 578
#' cell lines, 23 primary diseases and 25 lineages. This dataset is part of the
#' SIGMA Re-purposing release which contains small molecule viability datasets
#' generated using the Broad Re-purposing Library and the PRISM multiplexed
#' cell-line viability assay. The columns of `drug_sensitivity` are: `depmap_id`
#' a foreign key corresponding to the cancer cell lineage, `cell_line` the
#' common CCLE name of the cancer cell lines, `compound` the synonym for the
#' drug compound, and `dependency` which contains the numerical dependency score
#' values for each pair of genes and cell lines. Compounded metadata has also
#' been added.
#'
#' @format A data frame with 2708508 rows (cell lines) and 14 variables:
#' \describe{
#'      \item{depmap_id}{Cell line foreign key (i.e. "ACH-000956")}
#'      \item{cell_line}{Name of cancer cell line (i.e. "22RV1_PROSTATE")}
#'      \item{compound}{Drug compound name (i.e. BRD-A00077618-236-07-6::2.5::HTS)}
#'      \item{dependency}{numerical depenency score of a compound on a cell line}
#'      \item{broad_id}{Broad ID for compound (i.e. BRD-A00077618-236-07-6)}
#'      \item{name}{Standard chemical name (i.e. 8-bromo-cGMP)}
#'      \item{dose}{Dose of compound}
#'      \item{screen_id}{Broad ID for compound (i.e. HTS)}
#'      \item{moa}{Mechanism of action (i.e. PKA activator)}
#'      \item{target}{Molecular target of compount (i.e. PRKG1)}
#'      \item{disease_area}{Anatomical target (i.e. hematologic malignancy)}
#'      \item{indication}{Prescribed for disease (i.e. acute myeloid leukemia (AML))}
#'      \item{smiles}{Simplified molecular-input line-entry specification}
#'      \item{phase}{Clincal phase}
#' }
#'
#' @details This data originates from the
#' `primary_replicate_collapsed_logfold_change.csv` file taken from the 19Q3
#' [Broad Institute](https://depmap.org/portal/download/) cancer depenedency
#' study. The derived dataset found in the `depmap` package features the
#' addition of a foreign key `depmap_id` found in the first column of this
#' dataset, which was added from the `metadata` dataset. This dataset has been
#' converted to a long format tibble. Variables names from the original dataset
#' were converted to lower case, put in snake case, and abbreviated where
#' feasible. Note: compound metadata was added to this dataset, consisting of
#' 10 new features derived from the file
#' `primary-screen-replicate-collapsed-treatment-info.csv` from the
#' [Broad Institute](https://depmap.org/portal/download/) website. The
#' Drug sensitivity data remains from 19Q3, however the version was bumped to
#' 21Q2 to distinguish between the different datasets.
#'
#' @section Change log:
#'
#' - 19Q3: Initial dataset consisted of a data frame with 2708508 rows (cell
#' lines) and 6 variables representing 686 compounds, 578 cell lines, 23 primary
#' diseases and 25 lineages.
#'
#' - 19Q4: no change, no further releases are scheduled at this time.
#'
#' - 20Q1: no change, no further releases are scheduled at this time.
#'
#' - 20Q2: no change, no further releases are scheduled at this time.
#'
#' - 20Q3: no change, no further releases are scheduled at this time.
#'
#' - 20Q4: no change, no further releases are scheduled at this time.
#'
#' - 21Q1: no change, no further releases are scheduled at this time.
#'
#' - 21Q2: Drug sensitivity data combined with compound metadata, added 10 new
#'  features from the file primary-screen-replicate-collapsed-treatment-info.csv
#'
#' - 21Q3: no change, no further releases are scheduled at this time.
#'
#' - 21Q4: no change, no further releases are scheduled at this time.
#'
#' - 22Q1: no change, no further releases are scheduled at this time.
#'
#' - 22Q2: no change, no further releases are scheduled at this time.
#'
#' @docType data
#'
#' @import dplyr
#'
#' @keywords datasets
#'
#' @references Tsherniak, A., Vazquez, F., Montgomery, P. G., Weir, B. A.,
#' Kryukov, G., Cowley, G. S., ... & Meyers, R. M. (2017). Defining a cancer
#' dependency map. Cell, 170(3), 564-576.
#'
#' Steven M Corsello, Rohith T Nagari, Ryan D Spangler, Jordan Rossen,
#' Mustafa Kocak, Jordan G Bryan, Ranad Humeidi, David Peck, Xiaoyun
#' Wu, Andrew A Tang, Vickie MWang, Samantha A Bender, Evan Lemire,
#' Rajiv Narayan, Philip Montgomery, Uri Ben-David, Yejia Chen,
#' Matthew G Rees, Nicholas J Lyons, James M McFarland, Bang TWong, Li
#' Wang, Nancy Dumont, Patrick J O'Hearn, Eric Stefan, John G Doench,
#' HeidiGreulich, Matthew Meyerson, Francisca Vazquez, Aravind
#' Subramanian, Jennifer A Roth, Joshua A Bittker, Jesse S Boehm,
#' Christopher C Mader, Aviad Tsherniak, Todd R
#' Golub. 2019. Non-oncology drugs are a source of previously
#' unappreciated anti-cancer activity.
#' bioRXiv. https://www.biorxiv.org/content/10.1101/730119v1
#'
#' @source DepMap, Broad Institute: https://depmap.org/portal/download/
#'
#' @rdname drug_sensitivity
#'
#' @aliases depmap_drug_sensitivity drug_sensitivity_19Q3 drug_sensitivity_21Q1
#' drug_sensitivity_21Q2
drug_sensitivity <- NULL

### =========================================================================
### Make 22Q2 depmap data
### -------------------------------------------------------------------------

## This scripts documents how to download and generate the data files.
## Note 1: This scipt assumes (!!!) that it is run in ./depmap/inst/scripts/ and
## saves the resulting .rda files in ./depmap/inst/data
## (e.g. *setwd(./depmap/inst/scripts/)*)
## Note 2: the Broad Institute may change the download urls for these datasets.
## If the link to one of these datasets is broken, please contact the package
## maintainer. All Depmap data can be downloaded from the API at
## https://depmap.org/portal/download/ even if the specific links may change

## load libraries
library("readr")
library("dplyr")
library("tidyr")

setwd("~/tmp/depmap/inst/scripts/")
## set environment variable to allow download from depmap website
Sys.setenv(VROOM_CONNECTION_SIZE = 500072)

##########################################
## depmap `metadata_22Q2` dataset
##########################################

### loading data (downloading .csv file from online source)
read_csv(file = "https://ndownloader.figshare.com/files/35020903"
         ) -> metadata_22Q2

#### Rename `metadata` columns to contain underscores and be in snake case
## note: "metadata_22Q2" has different columns than "metadata_22Q2"
names(metadata_22Q2)[1:29] <- c(
    "depmap_id", "cell_line_name",
    "stripped_cell_line_name", "cell_line",
    "aliases", "cosmic_id",
    "sex", "source",
    "RRID", "WTSI_master_cell_ID",
    "sample_collection_site", "primary_or_metastasis",
    "primary_disease", "subtype_disease",
    "age", "sanger_id",
    "additional_info", "lineage",
    "lineage_subtype", "lineage_sub_subtype",
    "lineage_molecular_subtype", "default_growth_pattern",
    "model_manipulation", "model_manipulation_details",
    "patient_id", "parent_depmap_id",
    "Cellosaurus_NCIt_disease", "Cellosaurus_NCIt_id",
    "Cellosaurus_issues")

    ## these columns have been moved the achilles
    # "Achilles_n_replicates", "cell_line_NNMD", "culture_medium",
    # "cas9_activity", 

    ## info from column "culture_type" has been split into the following:
    # "default_growth_pattern" "model_manipulation" "model_manipulation_details"

### saving cleaned and converted `metadata` data as .rda file
save(metadata_22Q2, file = "../eh_data/metadata_22Q2.rda",
      compress = "xz", compression_level = 9)

##########################################
## `dep_2_name_22Q2 map `depmap_id` to `cell_line`
##########################################

##  generation of `metadata` subset `dep_2_name_22Q2`
## The subset of `metadata`, `dep_2_name_Q2` is used to map `cell_line`
## and depmap_id via left_join in other depmap datasets that do not contain
## both variables. If you are generating the depmap data from scratch, you will
## need to run the following code to generate the data correctly.

### `dep_2_name` to add `depmap_id` or `cell_line` to other datasets
metadata_22Q2 %>% dplyr::select(depmap_id, cell_line) -> dep_2_name_22Q2

##########################################
## depmap `mutationCalls_22Q2` dataset
##########################################

### loading data (downloading .csv file from online source)
read_csv(file = "https://ndownloader.figshare.com/files/34989940"
         ) -> mutationCalls_22Q2

## note: "mutationCalls_22Q2" has different columns than "mutationCalls_19Q1"
## the variable "VA_WES_AC" is no longer present in this dataset, unlike
## previous releases (e.g. 19Q1)!
## In the 22Q2 release the feature, "tumor_seq_allele1" was changed to
## "alt_allele"
names(mutationCalls_22Q2)[1:32] <- c(
    "gene_name", "entrez_id",
    "ncbi_build", "chromosome",
    "start_pos", "end_pos",
    "strand", "var_class",
    "var_type", "ref_allele",
    "alt_allele", "dbSNP_RS",
    "dbSNP_val_status", "genome_change",
    "annotation_trans", "depmap_id",
    "cDNA_change", "codon_change",
    "protein_change", "is_deleterious",
    "is_tcga_hotspot", "tcga_hsCnt",
    "is_cosmic_hotspot", "cosmic_hsCnt",
    "ExAC_AF", "var_annotation",
    "CGA_WES_AC", "HC_AC",
    "RD_AC", "RNAseq_AC",
    "sanger_WES_AC", "WGS_AC")

### rearrange columns into same column format as other datasets
mutationCalls_22Q2 %>%
    dplyr::select(depmap_id, everything()) -> mutationCalls_22Q2

### saving cleaned and converted `mutationCalls` data as .rda file
save(mutationCalls_22Q2, file = "../eh_data/mutationCalls_22Q2.rda",
     compress = "xz", compression_level = 9)

##########################################
## depmap `copyNumber_22Q2` dataset
##########################################

### loading data (downloading .csv file from online source)
read_csv("https://ndownloader.figshare.com/files/34989937") -> copyNumber_22Q2

### rename column first column to "depmap_id"
names(copyNumber_22Q2)[1] <- "depmap_id"

### gather into long form on columns: `depmap_id`, `gene`, `logCopyNumber`
copyNumber_22Q2 %>%
  tidyr::gather(gene, log_copy_number, -depmap_id) -> copyNumber_22Q2_long

### mutate gene column into `gene_name` and `entrez_id`
copyNumber_22Q2_long %>%
    dplyr::mutate(
      entrez_id = gsub("&", ";", sub("\\)", "", sub("^.+ \\(", "", gene))),
      gene_name = gsub("&", ";", sub(" \\(.+\\)$", "", gene))
                  ) -> copyNumber_22Q2_long

### left_join `copyNumber` & `dep_2_name_22Q2` on `depmap_id`,
copyNumber_22Q2_long %>%
    dplyr::left_join(dep_2_name_22Q2, by = c("depmap_id" = "depmap_id")
                     ) -> copyNumber_22Q2

### rearrange columns into same column format as other datasets
copyNumber_22Q2 %>% 
  dplyr::select(depmap_id, gene, log_copy_number, entrez_id, gene_name,
                cell_line) %>%
  readr::type_convert(cols(entrez_id = "i")) -> copyNumber_22Q2

### saving cleaned and converted `copyNumber` data as .rda file
save(copyNumber_22Q2, file = "../eh_data/copyNumber_22Q2.rda",
     compress = "xz", compression_level = 9)

##########################################
## depmap `crispr_22Q2` dataset
##########################################

### loading data (downloading .csv file from online source)
read_csv(file = "https://ndownloader.figshare.com/files/34990036"
         ) -> crispr_22Q2

### rename column first column to "depmap_id"
names(crispr_22Q2)[1] <-"depmap_id"

### gather cripsr into long form with columns: `depmap_id`, `gene`, `dependency`
crispr_22Q2 %>%
  tidyr::gather(gene, dependency, -depmap_id) -> crispr_22Q2_long

### mutate gene into `gene_name` and `entrez_id`
crispr_22Q2_long %>%
    dplyr::mutate(
        entrez_id = gsub("&", ";", sub("\\)", "", sub("^.+ \\(", "", gene))),
        gene_name = gsub("&", ";", sub(" \\(.+\\)$", "", gene))
                  ) -> crispr_22Q2_long

### left_join `crispr_long` and `dep_2_name` to add `cell_line` column
crispr_22Q2_long %>%
  dplyr::left_join(dep_2_name_22Q2, by = c("depmap_id" = "depmap_id")
                   ) -> crispr_22Q2

### rearrange columns into same column format as other datasets
crispr_22Q2 %>%
  dplyr::select(depmap_id, gene, dependency, entrez_id, gene_name,
                cell_line) %>%
  readr::type_convert(cols(entrez_id = "i")) -> crispr_22Q2

### saving cleaned and converted `crispr` data as .rda file
save(crispr_22Q2, file = "../eh_data/crispr_22Q2.rda",
     compress = "xz", compression_level = 9)

##########################################
## depmap `TPM_22Q2` dataset
##########################################

### loading data (downloading .csv file from online source)
TPM_22Q2 <- read_csv(file = "https://ndownloader.figshare.com/files/34989919")

### rename column first column to "depmap_id"
names(TPM_22Q2)[1] <-"depmap_id"

### gather `TPM` into long form on columns: `depmap_id`, `gene`, `expression`
TPM_22Q2 %>%
  tidyr::gather(gene, rna_expression, -depmap_id) -> TPM_22Q2_long

### mutate gene into gene_name and entrez_id
TPM_22Q2_long %>%
    dplyr::mutate(
        entrez_id = gsub("&", ";", sub("\\)", "", sub("^.+ \\(", "", gene))),
        gene_name = gsub("&", ";", sub(" \\(.+\\)$", "", gene))
                  ) -> TPM_22Q2_long

### left_join join `TPM` and `dep_2_name_22Q2` to add `cell_line` column
TPM_22Q2_long %>%
  dplyr::left_join(dep_2_name_22Q2, by = c("depmap_id" = "depmap_id")
                   ) -> TPM_22Q2

### rearrange columns into same column format as other datasets
TPM_22Q2 %>%
    dplyr::select(depmap_id, gene, rna_expression, entrez_id, gene_name,
                  cell_line) %>%
    readr::type_convert(cols(entrez_id = "i")) -> TPM_22Q2

### saving cleaned and converted `TPM` data as .rda file
save(TPM_22Q2, file = "../eh_data/TPM_22Q2.rda", compress = "xz",
     compression_level = 9)

##########################################
## depmap `achilles_metadata_22Q2` dataset
##########################################
read_csv(file = "https://ndownloader.figshare.com/files/34989901"
         ) -> achilles_metadata

names(achilles_metadata)[1:5] <- c(
  "depmap_id", "achilles_n_replicates", "cell_line_NNMD", 
  "culture_medium", "cas9_activity")

## note: "culture_type" column was removed

achilles_metadata %>% 
  dplyr::left_join(dep_2_name_22Q2, by = "depmap_id") %>%
  dplyr::select(depmap_id, cell_line, everything()) -> achilles_metadata_22Q2

### saving cleaned and converted `metadata` data as .rda file
save(achilles_metadata_22Q2, file = "../eh_data/achilles_22Q2.rda",
      compress = "xz", compression_level = 9)

### =========================================================================
### Make 19Q3 depmap data
### -------------------------------------------------------------------------
###

## This scripts documents how to download and generate the data files.
## Note 1: This scipt assumes (!!!) that it is run in ./depmap/inst/scripts/ and
## saves the resulting .rda files in ./depmap/inst/data  
## (e.g. *setwd(./depmap/inst/scripts/)*)
## Note 2: the Broad Institute may change the download urls for these datasets.
## If the link to one of these datasets is broken, please contact the package
## maintainer. All Depmap data can be downloaded from the API at
## https://depmap.org/portal/download/ even if the specific links may change

library("readr")
library("dplyr")
library("tidyr")
library("ExperimentHub")

##########################################
## EH3086 depmap `metadata_19Q3` dataset
##########################################

##  data cleaning of `metadata` dataset

### loading data (downloading .csv file from online source)
url_15 <- "https://ndownloader.figshare.com/files/16757723"
sample_info <- read_csv(url_15)

### DepMap-2019q1-celllines.csv data renamed to `metadata`
metadata_19Q3 <- sample_info
# names(metadata_19Q3)
# [1] "DepMap_ID"               "stripped_cell_line_name" "CCLE Name"              
# [4] "alias"                   "COSMIC_ID"               "lineage"                
# [7] "lineage_subtype"         "lineage_sub_subtype"     "sex"                    
# [10] "source"                  "Achilles_n_replicates"   "cell_line_NNMD"         
# [13] "culture_type"            "culture_medium"          "cas9_activity"          
# [16] "RRID"                    "sample_collection_site"  "primary_or_metastasis"  
# [19] "disease"                 "disease_subtype"         "age"                    
# [22] "Sanger_model_ID"         "additional_info"   


#### Rename `metadata` columns to contain underscores and be in camel case
## note: "metadata_19Q3" has different columns than "metadata_19Q3"
names(metadata_19Q3)[1:23] <-c("depmap_id", "stripped_cell_line_name",
                              "cell_line", "aliases", "cosmic_id", "lineage",
                              "lineage_subtype", "lineage_sub_subtype", "sex",
                              "source", "Achilles_n_replicates",
                              "cell_line_NNMD", "culture_type",
                              "culture_medium", "cas9_activity", "RRID",
                              "sample_collection_site", "primary_or_metastasis",
                              "primary_disease", "subtype_disease", "age",
                              "sanger_id", "additional_info")

### visual check
# View(metadata_19Q3)

### saving cleaned and converted `metadata` data as .rda file
save(metadata_19Q3, file = "../eh_data/metadata_19Q3.rda",
     compress = "xz", compression_level = 9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")
# EH3086 <- x[["EH3086"]]

##########################################
## `depmap_id_to_name_19Q3 map `depmap_id` to `cell_line`
##########################################

##  generation of `metadata` subset `depmap_id_to_name_19Q3`

## The subset of `metadata`, `depmap_id_to_name_Q2` is used to map `cell_line`
## and depmap_id via left_join in other depmap datasets that do not contain
## both variables. If you are generating the depmap data from scratch, you will
## need to run the following code to generate the data correctly.

### `depmap_id_to_name` to add `depmap_id` or `cell_line` to other datasets
depmap_id_to_name_19Q3 <- metadata_19Q3 %>% dplyr::select(depmap_id, cell_line)

### visual check
# head(depmap_id_to_name_19Q3)

##########################################
## EH3085 depmap `mutationCalls_19Q3` dataset
##########################################

## data cleaning of `mutationCalls` dataset

### loading data (downloading .csv file from online source)
url_16 <- "https://ndownloader.figshare.com/files/16757702"
CCLE_mutations_19Q3 <- read_csv(url_16)

### depmap_19Q1_mutation_calls data renamed to `mutationCalls`
mutationCalls_19Q3 <- CCLE_mutations_19Q3
# head(mutationCalls_19Q3)

#### rename last column to depmap_id
# names(mutationCalls_19Q3)
# [1] "Hugo_Symbol"            "Entrez_Gene_Id"         "NCBI_Build"            
# [4] "Chromosome"             "Start_position"         "End_position"          
# [7] "Strand"                 "Variant_Classification" "Variant_Type"          
# [10] "Reference_Allele"       "Tumor_Seq_Allele1"      "dbSNP_RS"              
# [13] "dbSNP_Val_Status"       "Genome_Change"          "Annotation_Transcript"
# [16] "Tumor_Sample_Barcode"   "cDNA_Change"            "Codon_Change"          
# [19] "Protein_Change"         "isDeleterious"          "isTCGAhotspot"         
# [22] "TCGAhsCnt"              "isCOSMIChotspot"        "COSMIChsCnt"           
# [25] "ExAC_AF"                "CGA_WES_AC"             "SangerWES_AC"          
# [28] "SangerRecalibWES_AC"    "RNAseq_AC"              "HC_AC"                 
# [31] "RD_AC"                  "WGS_AC"                 "Variant_annotation"
# [34] "DepMap_ID"             

## note: "mutationCalls_19Q3" has different columns than "mutationCalls_19Q1"
## the variable "VA_WES_AC" is no longer present in this dataset, unlike
## previous releases (e.g. 19Q1)! 
names(mutationCalls_19Q3)[1:34] <- c("gene_name", "entrez_id", "ncbi_build",
                                "chromosome", "start_pos", "end_pos", "strand",
                                "var_class","var_type", "ref_allele",
                                "tumor_seq_allele1", "dbSNP_RS",
                                "dbSNP_val_status", "genome_change",
                                "annotation_transcript", "tumor_sample_barcode",
                                "cDNA_change", "codon_change", "protein_change",  
                                "is_deleterious", "is_tcga_hotspot",
                                "tcga_hsCnt", "is_cosmic_hotspot",
                                "cosmic_hsCnt", "ExAC_AF", "CGA_WES_AC",
                                "sanger_WES_AC", "sanger_recalib_WES_AC",
                                "RNAseq_AC", "HC_AC", "RD_AC", "WGS_AC",
                                "var_annotation","depmap_id")

### rearrange columns into same column format as other datasets
mutationCalls_19Q3 <- mutationCalls_19Q3 %>%
    dplyr::select(depmap_id, gene_name, entrez_id, ncbi_build, chromosome,
                  start_pos, end_pos, strand, var_class, var_type, ref_allele,
                  tumor_seq_allele1, dbSNP_RS, dbSNP_val_status, genome_change,
                  annotation_transcript, tumor_sample_barcode, cDNA_change,
                  codon_change, protein_change, is_deleterious, is_tcga_hotspot,
                  tcga_hsCnt, is_cosmic_hotspot, cosmic_hsCnt, ExAC_AF,
                  CGA_WES_AC, sanger_WES_AC, sanger_recalib_WES_AC, RNAseq_AC,
                  HC_AC, RD_AC, WGS_AC, var_annotation)

### visual check
# head(mutationCalls_19Q3)

### saving cleaned and converted `mutationCalls` data as .rda file
save(mutationCalls_19Q3, file = "../eh_data/mutationCalls_19Q3.rda",
     compress = "xz", compression_level = 9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")
# EH3085 <- x[["EH3085"]]

##########################################
## EH3082 depmap `copyNumber_19Q3` dataset
##########################################

##  data cleaning of `copyNumber` dataset 

### loading data (downloading .csv file from online source)
url_17 <- "https://ndownloader.figshare.com/files/16757699"
CCLE_gene_cn_19Q3 <- read_csv(url_17)

### public_19Q1_gene_cn.csv data renamed to `copyNumber`
copyNumber_19Q3 <- CCLE_gene_cn_19Q3
# names(copyNumber_19Q3)

### rename column first column to "depmap_id"
names(copyNumber_19Q3)[1] <- "depmap_id"

### gather into long form on columns: `depmap_id`, `gene`, `logCopyNumber`
copyNumber_19Q3_long <- gather(copyNumber_19Q3, gene, log_copy_number,
                               -depmap_id)

### mutate gene column into `gene_name` and `entrez_id`
copyNumber_19Q3_long <- copyNumber_19Q3_long %>% 
    mutate(entrez_id = gsub("&", ";", sub("\\)", "", sub("^.+ \\(", "", gene))),
           gene_name = gsub("&", ";", sub(" \\(.+\\)$", "", gene))) 

### left_join `copyNumber` & `depmap_id_to_name_19Q3` on `depmap_id`, 
## `cell_line`     
copyNumber_19Q3 <- copyNumber_19Q3_long %>% 
    left_join(depmap_id_to_name_19Q3, by = c("depmap_id" = "depmap_id"))

### rearrange columns into same column format as other datasets
copyNumber_19Q3 <- copyNumber_19Q3 %>% 
                        dplyr::select(depmap_id, gene, log_copy_number,
                                      entrez_id, gene_name, cell_line) %>%
                                      type_convert(cols(entrez_id = "i"))
### visual check
# head(copyNumber_19Q3)

### saving cleaned and converted `copyNumber` data as .rda file
save(copyNumber_19Q3, file = "../eh_data/copyNumber_19Q3.rda",
     compress = "xz", compression_level = 9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")
# EH3082 <- x[["EH3082"]]

##########################################
## EH3081 depmap `crispr_19Q3` dataset
##########################################

##  data cleaning of `crispr` dataset`

### loading data (downloading .csv file from online source)
url_18 <- "https://ndownloader.figshare.com/files/16757666"
Achilles_gene_effect_19Q3 <- read_csv(url_18)

### gene_effect_corrected.csv data renamed to `crispr`
crispr_19Q3 <- Achilles_gene_effect_19Q3

### visual check
# head(crispr_19Q3)

### rename column first column to "depmap_id"
names(crispr_19Q3)[1] <-"depmap_id"

### gather cripsr into long form with columns: `depmap_id`, `gene`, `dependency`
crispr_19Q3_long <- gather(crispr_19Q3, gene, dependency, -depmap_id)

### mutate gene into `gene_name` and `entrez_id`
crispr_19Q3_long <- crispr_19Q3_long %>% 
    mutate(entrez_id = gsub("&", ";", sub("\\)", "", sub("^.+ \\(", "", gene))),
           gene_name = gsub("&", ";", sub(" \\(.+\\)$", "", gene))) 

### left_join `crispr_long` and `depmap_id_to_name` to add `cell_line` column   
crispr_19Q3 <- crispr_19Q3_long %>% left_join(depmap_id_to_name_19Q3, 
                                    by = c("depmap_id" = "depmap_id"))

### rearrange columns into same column format as other datasets
crispr_19Q3 <- crispr_19Q3 %>% dplyr::select(depmap_id, gene,
                                             dependency, entrez_id,
                                             gene_name, cell_line) %>%
                                             type_convert(cols(entrez_id = "i"))
### visual check
# head(crispr_19Q3)

### saving cleaned and converted `crispr` data as .rda file
save(crispr_19Q3, file = "../eh_data/crispr_19Q3.rda",
     compress = "xz", compression_level = 9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")
# EH3081 <- x[["EH3081"]]

##########################################
## EH3084 depmap `TPM_19Q3` dataset
##########################################

## data cleaning of `TPM` dataset

### loading data (downloading .csv file from online source)
url_19 <- "https://ndownloader.figshare.com/files/16757690"
CCLE_expression_full_19Q3 <- read_csv(url_19)

### CCLE_depMap_19Q3_TPM.csv data renamed to `TPM`
TPM_19Q3 <- CCLE_expression_full_19Q3
# names(TPM_19Q3)

### rename column first column to "depmap_id"
names(TPM_19Q3)[1] <-"depmap_id"

### gather `TPM` into long form on columns: `depmap_id`, `gene`, `expression`
TPM_19Q3_long <- gather(TPM_19Q3, gene, expression, -depmap_id)

### mutate gene into gene_name and ensembl_id
TPM_19Q3_long <- TPM_19Q3_long %>% 
    mutate(ensembl_id = gsub("&", ";", sub("\\)", "", sub("^.+ \\(", "",gene))),
           gene_name = gsub("&", ";", sub(" \\(.+\\)$", "", gene))) 

### left_join join `TPM` and `depmap_id_to_name_19Q3` to add `cell_line` column
TPM_19Q3 <- TPM_19Q3_long %>% left_join(depmap_id_to_name_19Q3, 
                              by = c("depmap_id" = "depmap_id"))

### rearrange columns into same column format as other datasets
TPM_19Q3 %>%
    dplyr::select(depmap_id, gene, expression, entrez_id, gene_name,
                  cell_line) %>%
    type_convert(cols(entrez_id = "i")) -> TPM_19Q3

### saving cleaned and converted `TPM` data as .rda file
save(TPM_19Q3, file = "../eh_data/TPM_19Q3.rda", compress="xz",
     compression_level=9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")
# EH3084 <- x[["EH3084"]]

##########################################
## EH3083 depmap `RPPA_19Q3` dataset
##########################################

## data cleaning of `RPPA` dataset

### loading data (downloading .csv file from online source)
url_20 <- "https://depmap.org/portal/download/api/download/external?file_name=ccle%2Fccle_2019%2FCCLE_RPPA_20181003.csv"
CCLE_RPPA_20180123_19Q3 <- read_csv(url_20)

### CCLE_RPPA_20180123.csv data renamed to `RPPA`
RPPA_19Q3 <- CCLE_RPPA_20180123_19Q3
# head(RPPA_19Q3)

### rename column first column to "cell_line"
names(RPPA_19Q3)[1] <-"cell_line"

### gather cell line columns and split gene name into gene_name and entrez_id
RPPA_19Q3_long <- RPPA_19Q3 %>% gather(antibody, expression, -cell_line)

### join cell_line name    
RPPA_19Q3 <- RPPA_19Q3_long %>% left_join(depmap_id_to_name_19Q3, 
                                by = c("cell_line" = "cell_line"))

### rearrange columns into same column format as other datasets
RPPA_19Q3 <- RPPA_19Q3 %>% dplyr::select(cell_line, antibody, expression,
                                            depmap_id) 

### visual check
# head(RPPA_19Q3)

### saving cleaned and converted `RPPA` data as .rda file
save(RPPA_19Q3, file="../eh_data/RPPA_19Q3.rda", compress="xz",
     compression_level=9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")
# EH3083 <- x[["EH3083"]]

##########################################
## EH3080 depmap `rnai_19Q3` dataset
##########################################

## data cleaning of `rnai` dataset

### loading data (downloading .csv file from online source)
url_21 <- "https://ndownloader.figshare.com/files/13515395"
D2_combined_gene_dep_scores_19Q3 <- read_csv(url_21)

### D2_combined_genetic_dependency_scores.csv data renamed to `rnai`
rnai_19Q3 <- D2_combined_gene_dep_scores_19Q3
# head(rnai_19Q3)

### rename column first column to "gene"
names(rnai_19Q3)[1] <- "gene"

### gather rnai into long form with columns: depmap_id, gene and dependency
rnai_19Q3 <- gather(rnai_19Q3, key = cell_line, value = dependency, -gene) %>%
    mutate(entrez_id = gsub("&", ";", sub("\\)", "", sub("^.+ \\(", "", gene))),
           gene_name = gsub("&", ";", sub(" \\(.+\\)$", "", gene))) %>%
    left_join(depmap_id_to_name_19Q3, by = c("cell_line" = "cell_line"))

### rearrange columns into same column format as other datasets
rnai_19Q3 <- rnai_19Q3 %>% dplyr::select(gene, cell_line, dependency, entrez_id,
                                         gene_name, depmap_id) %>%
                                         type_convert(cols(entrez_id = "i"))
### visual check
# head(rnai_19Q3)

### saving cleaned and converted `rnai` data as .rda file
save(rnai_19Q3, file="../eh_data/rnai_19Q3.rda", compress="xz",
     compression_level=9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")
# EH3080 <- x[["EH3080"]]

##########################################
## EH3087 depmap `drug_sensativity_19Q3` dataset
##########################################

## data cleaning of `drug_sensativity` dataset

### loading data (downloading .csv file from online source)
url_22 <- "https://depmap.org/portal/download/api/download/external?file_name=drug%2Fprimary-screen-e5c7.7%2Fprimary_replicate_collapsed_logfold_change.csv"
primary_replicate_collapsed_logfold_change_19Q3 <- read_csv(url_22)

### primary_replicate_collapsed_logfold_change_19Q3.csv data renamed to 
### `drug_sensativity_19Q3`
drug_sensativity_19Q3 <- primary_replicate_collapsed_logfold_change_19Q3
# head(drug_sensativity_19Q3)

### rename column first column to "depmap_id"
names(drug_sensativity_19Q3)[1] <- "depmap_id"

### gather drug_sensativity into long form with columns: depmap_id, compound and
### dependency
drug_sensativity_19Q3 <- gather(drug_sensativity_19Q3, key = compound,
                                value = dependency, -depmap_id) %>%
                                left_join(depmap_id_to_name_19Q3,
                                          by = c("depmap_id" = "depmap_id"))

### rearrange columns into same column format as other datasets
drug_sensativity_19Q3 <- drug_sensativity_19Q3 %>% 
    dplyr::select(depmap_id, cell_line, compound, dependency)

### visual check
head(drug_sensativity_19Q3)

### saving cleaned and converted `drug_sensativity` data as .rda file
save(drug_sensativity_19Q3, file="../eh_data/drug_sensativity_19Q3.rda",
     compress="xz", compression_level=9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")
# EH3087 <- x[["EH3087"]]

### =========================================================================
### depmap metadata 19Q3 data 
### -------------------------------------------------------------------------
### this script generates the metadata_19Q3.csv
## note: this script assumes that your current directory is depmap/inst/scripts/

meta_19Q3 <- data.frame(
    Title = c(paste0("rnai_19Q3"),
              paste0("crispr_19Q3"), 
              paste0("copyNumber_19Q3"),
              paste0("RPPA_19Q3"), 
              paste0("TPM_19Q3"),
              paste0("mutationCalls_19Q3"),
              paste0("metadata_19Q3"),
              paste0("drug_sensitivity_19Q3")),
    Description = c(paste0("(DEMETER2) Batch and off-target corrected RNAi ", 
                           "gene knockdown dependency data for 17309 genes, ", 
                           "712 cancer cell lines, 31 primary Diseases and ", 
                           "31 lineages."), 
                    paste0("(CERES) Batch and off-target corrected CRISPR-Cas9 ", 
                           "gene knockdout dependency data for 18333 genes, ", 
                           "625 cell lines, 28 primary diseases and 29 ", 
                           "lineages."), 
                    paste0("WES log copy number data for 27562 genes, 1657 ", 
                           "cell lines, 36 primary diseases and 34 lineages."),
                    paste0("Reverse Phase Protein Array (RPPA) Western Blot ", 
                           "expression data from 214 genes, 899 cancer cell ", 
                           "lines, 28 primary diseases and 28 lineages."),
                    paste0("CCLE 'Transcript Per Million' (TPM) RNAseq gene ", 
                           "expression data (in scale scale (log2(TPM+1))) ", 
                           "for protein coding genes from 19144 genes, 1210 ", 
                           "cancer cell lines, 32 primary diseases and 33 ", 
                           "lineages."), 
                    paste0("Merged mutation calls (for coding region, germline ", 
                           "filtered) and includes data from 18798 genes, 1656 ", 
                           "cell lines, 36 primary diseases and 34 lineages. "),
                    paste0("Metadata for cell lines in the 19Q3 DepMap release, ", 
                           "for 0 genes, 1736 cell lines, 37 primary diseases ", 
                           "and 34 lineages."),
                    paste0("Drug sensitivity data for cancer cell lines ",
                           "derived from replicate collapsed logfold change ",
                           "values relative to DMSO, corrected for experimental ",
                           "confounders using ComBat representing 4686 compounds, ",
                           "578 cell lines, 23 primary diseases and 25 lineages")),
    BiocVersion = "3.10",
    Genome = "", 
    SourceType = "CSV", 
    SourceUrl = c(paste0("https://ndownloader.figshare.com/files/13515395"),
                  paste0("https://ndownloader.figshare.com/files/16757666"),
                  paste0("https://ndownloader.figshare.com/files/16757699"),
                  paste0("https://depmap.org/portal/download/api/download/external?file_name=ccle%2Fccle_2019%2FCCLE_RPPA_20181003.csv"),
                  paste0("https://ndownloader.figshare.com/files/16757690"),
                  paste0("https://ndownloader.figshare.com/files/16757702"),
                  paste0("https://ndownloader.figshare.com/files/16757723"),
                  paste0("https://ndownloader.figshare.com/files/17008628")),
    SourceVersion = "Aug 7 2019",
    Species = "Homo sapiens",
    TaxonomyId = 9606,
    Coordinate_1_based = TRUE,
    DataProvider = "Broad Institute",
    Maintainer = "Theo Killian <theodore.killian@uclouvain.be>",
    RDataClass = "tibble",
    DispatchClass = "Rda",
    RDataPath = c(paste0("depmap/rnai_19Q3.rda"), 
                  paste0("depmap/crispr_19Q3.rda"), 
                  paste0("depmap/copyNumber_19Q3.rda"), 
                  paste0("depmap/RPPA_19Q3.rda"), 
                  paste0("depmap/TPM_19Q3.rda"),
                  paste0("depmap/mutationCalls_19Q3.rda"),
                  paste0("depmap/metadata_19Q3.rda"),
                  paste0("depmap/drug_sensitivity_19Q3.rda")),
    Tags=paste0("ExperimentHub, ExperimentData, ReproducibleResearch, RepositoryData, AssayDomainData, ", 
                "CopyNumberVariationData, DiseaseModel, CancerData, BreastCancerData, ColonCancerData, ", 
                "KidneyCancerData, LeukemiaCancerData, LungCancerData, OvarianCancerData, ProstateCancerData", 
                "OrganismData, Homo_sapiens_Data, PackageTypeData, SpecimenSource, CellCulture, Genome, ", 
                "Proteome, StemCell, Tissue"),
    Notes = "This dataset is from the 19Q3 release")

write.csv(meta_19Q3, file="../extdata/metadata_19Q3.csv", row.names=FALSE)
## to upload this metadata to EH, enter the following into the CL
## ExperimentHubData::makeExperimentHubMetadata("~/tmp/depmap/", fileName = "metadata_19Q3.csv")

##' @importFrom curl has_internet
.onLoad <- function(libname, pkgname) {
    if (curl::has_internet())
        .createDepMapHubAccessors()
    else
        warning("Not internet connectivity. Unable to create Hub accessors.",
                call. = FALSE)
}

.onAttach <- function(libname, pkgname) {
    packageStartupMessage(paste0("This is depmap release ", depmap_release()))
}

#' achilles_22Q2
#'
#' The `achilles` dataset contains the metadata for DepMap’s cancer models/cell
#' lines, specific to Project Achilles’ 22Q2 CRISPR screens. This dataset can be
#' loaded into the R environment with the `depmap_achilles` function.
#'
#' @format A data frame with 1036 rows and 6 variables:
#' \describe{
#'     \item{depmap_id}{cancer cancer cell line foreign key (i.e. "ACH-00001")}
#'     \item{cell_line}{CCLE name of cancer cell line (i.e. "184A1_BREAST")}
#'     \item{achilles_n_replicates}{Number of replicates used in Achilles CRISPR
#'      screen passing QC}
#'     \item{cell_line_NNMD}{Difference in the means of positive and negative
#'      controls normalized by the standard deviation of the negative control
#'      distribution}
#'     \item{culture_medium}{Medium used to grow cell line}
#'     \item{cas9_activity}{Percentage of cells remaining GFP negative on days
#'      12-14 of cas9 activity assay as measured by FACs}
#' }
#'
#' @details This data represents the `Achilles_metadata.csv` file taken from the
#' 22Q2 [Broad Institute](https://depmap.org/portal/download/) release.
#'
#' @section Change log:
#'
#' - 22Q1: Initial dataset
#'
#' - 22Q2: "culture_type" column was removed
#'
#' @docType data
#'
#' @import dplyr
#'
#' @keywords datasets
#'
#' @examples
#' \dontrun{
#' depmap_achilles()
#' }
#'
#' @references Tsherniak, A., Vazquez, F., Montgomery, P. G., Weir, B. A.,
#' Kryukov, G., Cowley, G. S., ... & Meyers, R. M. (2017). Defining a cancer
#' dependency map. Cell, 170(3), 564-576.
#'
#' James M. McFarland, Zandra V. Ho, Guillaume Kugener, Joshua M. Dempster,
#' Phillip G. Montgomery, Jordan G. Bryan, John M. Krill-Burger, Thomas M.
#' Green, Francisca Vazquez, Jesse S. Boehm, Todd R. Golub, William C. Hahn,
#' David E. Root, Aviad Tsherniak. (2018). Improved estimation of cancer
#' dependencies from large-scale RNAi screens using model-based normalization
#' and data integration. Nature Communications 9, 1.
#'
#' @source DepMap, Broad Institute: https://depmap.org/portal/download/
#'
#' @rdname achilles
#'
#' @aliases depmap_achilles achilles_22Q1 achilles_22Q2
achilles <- NULL

##' @title DepMap Dataset and Files
##'
##' @aliases DepMapDataset dmFileNames dmTitle dmNumFiles
##' @aliases DepMapFiles dmsets dmfiles dmget
##'
##' @description
##'
##' Two tibbles are provided that give access to DepMap data, as
##' shared by the Broad Institute's DepMap project on Figshare
##' (https://figshare.com/authors/Broad_DepMap/5514062).
##'
##' - The [dmsets()] function returns a tibble with DepMap
##'   datasets. Each dataset is described by its title, its unique
##'   identifier, the number of files it contains, the Figshare URL,
##'   and a `DepMapDataset` object that contains further details of
##'   the dataset.
##'
##' - The [dmfiles()] function returns a tibble with DepMap
##'   files. Each file is described by its dataset identifier, its own
##'   unique identifier, its name, size (in bytes), a download URL,
##'   md5 hash and mime type.
##'
##' - Depmap data files can be downloaded with the [dmget()] function,
##'   that takes as input a tibble or data.frame of depmap files such
##'   as `dmfiles`. Files are downloaded and automatically in the
##'   package's central cache. See [dmCache()].
##'
##' @details
##'
##' The `DepMapDataset` class stores the informtion describing a
##' depmap dataset, as stored on Figshare (articles, as it's called
##' there). The [DepMapDataset()] constructor requires one or multiple
##' dataset identifiers and returns one or a list of instances.
##'
##' The following accessors are available:
##' - [dmFileNames()] returns the dataset's filenames.
##' - [dmTitle()] returns the dataset's title.
##' - [dmNumFiles()] returns the number of files in the dataset.
##'
##' (These are used to construct the main depmap dataset tibble.)
##'
##' A tibble describing the files in depmap dataset can be cretated
##' with the [DepMapFiles()] function. It either takes one or multiple
##' dataset idenifiers, or one or a list of `DepMapDataset` instances
##'
##' The [DepMapDataset()] and [DepMapFiles()] functions are mostly
##' used internally, to create the `dmsets` and `dmfiles` tibbles. If
##' a more recent dataset is available on Figshare and not (yet) in
##' the `depmap` package, a user might create the depmap files table
##' to download the files, and/or open a [GitHub
##' issue](https://github.com/UCLouvain-CBIO/depmap) for the new data
##' to be added by the maintainer(s).
##'
##' All the information is retrieved from Figshare using their API, as
##' described at https://docs.figshare.com.
##'
##' @section Adding new datasets:
##'
##' Adding new datasets is simple. Once a new dataset (or Article, as
##' called on Figshare) has been identified on the Broad Institute's
##' [DepMap project on
##' Figshare](https://figshare.com/authors/Broad_DepMap/5514062), one
##' needs to add the dataset's URL to the `depmapURLs` vector in
##' [`inst/extdata/make-dmfiles.R`](https://github.com/UCLouvain-CBIO/depmap/blob/master/inst/scripts/make-dmfiles.R),
##' and re-run the script to update the `dmsets.rds.` and
##' `dmfiles.rds` files in `inst/extdata`.
##'
##' Feel free to send a GitHub pull request or open a [GitHub
##' issue](https://github.com/UCLouvain-CBIO/depmap) for the new data
##' to be added by the maintainer(s).
##'
##' @name DepMapFiles
##'
##' @author Laurent Gatto
##'
##' @importFrom httr2 request req_perform resp_body_json
##' @importFrom tibble as_tibble
##'
##' @examples
##'
##' ## The depmap datasets
##' dmsets
##'
##' ## The depmap files
##' dmfiles
##'
##' ############################################################
##' ## Mostly for internal use, or to update/generate the depmap
##' ## dataset and files tables.
##'
##' ## One dataset identifier: 24667905
##' my_dmset <- DepMapDataset(24667905)
##' my_dmset
##'
##' ## Multiple dataset identifiers
##' my_dmsets <- DepMapDataset(c(24667905, 22765112))
##' my_dmsets
##'
##' ## Create the files table from one or dataset multiple dataset
##' ## identifiers
##'
##' DepMapFiles(24667905)
##' DepMapFiles(my_dmset)
##'
##' DepMapFiles(c(24667905, 22765112))
##' DepMapFiles(my_dmsets)
NULL

.DepMapDataset <-
    setClass("DepMapDataset",
         slots = c(files = "list",
                   title = "character",
                   id = "integer",
                   license = "character",
                   size = "numeric",
                   other = "list"))

setMethod("show", "DepMapDataset",
          function(object) {
              cat("Title:", object@title, "\n")
              cat("Id:", object@id, "\n")
              cat("License:", object@license, "\n")
              cat("Use `DepMapFiles()` to list",
                  length(object@files), "files\n")
          })



.DepMapFiles <- function(x) {
    .dmFiles <- function(x) {
        dataset_id <- x@id
        x <- x@files
        data.frame(
            dataset_id = dataset_id,
            id = sapply(x, "[[", "id"),
            name = sapply(x, "[[", "name"),
            size = sapply(x, "[[", "size"),
            download_url = sapply(x, "[[", "download_url"),
            md5 = sapply(x, "[[", "computed_md5"),
            mimetype = sapply(x, "[[", "mimetype")) |>
            as_tibble()
    }
    if (inherits(x, "DepMapDataset")) .dmFiles(x)
    else do.call(rbind, lapply(x, .dmFiles))
}

##' @rdname DepMapFiles
##' @export
##'
##' @param id `numeric()` with one or multiple DepMap dataset
##'     identifier(s). Note that `id` is converted to an
##'     integer. Missing values are not permitted.
DepMapDataset <- function(id) {
    id <- as.integer(id)
    if (anyNA(id))
        stop("Dataset id must be a non-missing integer.")
    .article <- function(.id) {
        url <- paste0("https://api.figshare.com/v2/articles/", .id)
        x <- request(url) |>
            req_perform() |>
            resp_body_json()
        .DepMapDataset(files = x[[1]],
                       title = x[["title"]],
                       id = x[["id"]],
                       license = x[["license"]][["name"]],
                       size = x[["size"]],
                       other = x[-1])
    }
    res <- lapply(id, .article)
    if (length(res) == 1) res[[1]]
    else res
}

##' @rdname DepMapFiles
##' @export
##'
##' @param x either an `numeric()` that will be passed to
##'     `DepMapDataset` or an instance (or list of) `DepMapDataset`.
DepMapFiles <- function(x) {
    if (is.numeric(x))
        x <- DepMapDataset(x)
    .DepMapFiles(x)
}

##' @rdname DepMapFiles
##' @export
##'
##' @param object an instance of class `DepMapDataset`.
dmFileNames <- function(object) {
    stopifnot(inherits(object, "DepMapDataset"))
    sapply(object@files, "[[", "name")
}

##' @rdname DepMapFiles
##' @export
dmTitle <- function(object) {
        stopifnot(inherits(object, "DepMapDataset"))
        object@title
}

##' @rdname DepMapFiles
##' @export
dmNumFiles <- function(object) {
    stopifnot(inherits(object, "DepMapDataset"))
    length(object@files)
}


##' @rdname DepMapFiles
##' @export
##'
##' @param dmtab A `tibble` or `data.frame` containing the file to be
##'     downloaded, such as [dmfiles()], or created by
##'     [DepMapFiles()]. If is expected to contain the `"name"`,
##'     `"id"` and `"dowload_url"` variables.
##'
##' @param cache Object of class [BiocFileCache()]. Default is to use
##'     the central `depmap` cache returned by [dmCache()], but users
##'     can use their own cache.
dmget <- function(dmtab, cache = dmCache()) {
    if (all(colnames(dmtab) %in% c("name", "id", "dowload_url")))
        stop("Expected variables not found. See ?dmget for details.")
    if (!nrow(dmtab) > 0)
        stop("Empty input.")
    res <- character()
    for (i in seq_len(nrow(dmtab))) {
        .name <- dmtab[i, 'name']
        .id <- dmtab[i, 'id']
        .url <- dmtab[['download_url']][i]
        message("File: ", .name, " (", .id, ")")
        res <- append(res, dmget1(.url, cache))
    }
    res
}

##' @rdname DepMapFiles
##' @export
dmfiles <- function()
    readRDS(dir(system.file("extdata", package = "depmap"),
                pattern = "dmfiles.rds", full.names = TRUE))

##' @rdname DepMapFiles
##' @export
dmsets <- function()
    readRDS(dir(system.file("extdata", package = "depmap"),
                pattern = "dmsets.rds", full.names = TRUE))

##' @importFrom utils read.csv
##' @importFrom ExperimentHub createHubAccessors
.createDepMapHubAccessors <- function(pkgname = "depmap") {
    fls <- dir(system.file("extdata", pkgname),
               full.names = TRUE, pattern = "metadata")
    sapply(fls,
           function(fl) {
               titles <- read.csv(fl, stringsAsFactors = FALSE)$Title
               ExperimentHub::createHubAccessors(pkgname, titles)
           })
}


##' @importFrom AnnotationHub query
##' @importFrom ExperimentHub ExperimentHub

depmap_data_loading <- function(name) {
   eh <- ExperimentHub::ExperimentHub()
   eh <- AnnotationHub::query(eh, c("depmap", name), ignore.case = FALSE)
   eh_name <- names(eh)[length(eh)]
   eh[[eh_name]]
}

#' @export
depmap_rnai <- function()
   depmap_data_loading("rnai")

#' @export
depmap_crispr <- function()
   depmap_data_loading("crispr")

#' @export
depmap_copyNumber <- function()
   depmap_data_loading("copyNumber")

#' @export
depmap_RPPA <- function()
   depmap_data_loading("RPPA")

#' @export
depmap_TPM <- function()
   depmap_data_loading("TPM")

#' @export
depmap_metadata <- function()
   depmap_data_loading("metadata")

#' @export
depmap_mutationCalls <- function()
   depmap_data_loading("mutationCalls")

#' @export
depmap_drug_sensitivity <- function()
   depmap_data_loading("drug_sensitivity")

#' @export
depmap_proteomic <- function()
    depmap_data_loading("proteomic")

#' @export
depmap_achilles <- function()
   depmap_data_loading("achilles")

#' @export
depmap_gene_summary <- function()
   depmap_data_loading("gene_summary")

#' gene_summary_22Q1
#'
#' The `gene_summary` dataset contains the 22Q1 gene essentiality
#' probabilities for select genes. This dataset can be loaded into the R
#' environment with the `depmap_gene_summary` function.
#'
#' @format A data frame with 69746 rows (cell lines) and 7 variables:
#' \describe{
#'     \item{entrez_id}{Entrez ID# (e.g. 100316904)}
#'     \item{gene_name}{HUGO symbol (e.g. "SAP25")}
#'     \item{dataset}{which dataset this probability derives}
#'     \item{dependent_cell_lines}{number of dependent cell lines}
#'     \item{cell_lines_with_data}{number of cell lines with relevant dependency
#'      data}
#'     \item{strongly_selective}{Gene knockout is selective (not pan-lethal)}
#'     \item{common_essential}{common essential gene dependency}
#' }
#'
#' @details This data represents the `Gene Dependency Profile Summary.csv` file
#' taken from the 22Q1
#' [Broad Institute](https://depmap.org/portal/api/download/gene_dep_summary)
#' release.
#'
#' @section Change log:
#'
#' - 22Q1: Initial dataset
#'
#' - 22Q2: no change, no further releases are scheduled at this time.
#'
#' @docType data
#'
#' @import dplyr
#'
#' @keywords datasets
#'
#' @examples
#' \dontrun{
#' depmap_gene_summary()
#' }
#'
#' @references Tsherniak, A., Vazquez, F., Montgomery, P. G., Weir, B. A.,
#' Kryukov, G., Cowley, G. S., ... & Meyers, R. M. (2017). Defining a cancer
#' dependency map. Cell, 170(3), 564-576.
#'
#' James M. McFarland, Zandra V. Ho, Guillaume Kugener, Joshua M. Dempster,
#' Phillip G. Montgomery, Jordan G. Bryan, John M. Krill-Burger, Thomas M.
#' Green, Francisca Vazquez, Jesse S. Boehm, Todd R. Golub, William C. Hahn,
#' David E. Root, Aviad Tsherniak. (2018). Improved estimation of cancer
#' dependencies from large-scale RNAi screens using model-based normalization
#' and data integration. Nature Communications 9, 1.
#'
#' @source DepMap, Broad Institute: https://depmap.org/portal/download/
#'
#' @rdname gene_summary
#'
#' @aliases gene_summary_22Q1 depmap_gene_summary
gene_summary <- NULL

### =========================================================================
### depmap metadata 22Q1 data 
### -------------------------------------------------------------------------
### This script generates the metadata_22Q1.csv
## note: this script assumes that your current directory is depmap/inst/scripts/
# setwd("~/tmp/depmap/inst/scripts/")
## Links to download: https://depmap.org/portal/download/

data.frame(
    Title = c("crispr_22Q1", "copyNumber_22Q1", "TPM_22Q1",
              "mutationCalls_22Q1", "metadata_22Q1", "achilles_22Q1",
              "gene_summary_22Q1", "drug_sensitivity_21Q2"),
    Description = c(
        paste0("(CERES) Batch and off-target corrected CRISPR-Cas9 gene, ",
               "knockdout dependency data for 17386 genes, 1070 cell lines, ",
               "32 primary diseases and 31 lineages."),
        paste0("WES log copy number data for 25368 genes, 1754 cell lines, 35 ",
               "primary diseases and 38 lineages."),
        paste0("CCLE 'Transcript Per Million' (TPM) RNAseq gene expression ",
               "data (in scale scale (log2(TPM+1))) for protein coding genes ",
               "from 19177 genes, 1393 cell lines, 33 primary diseases ",
               "and 38 lineages."),
        paste0("CCLE mutation calls (for coding region, germline filtered) ",
               "and includes data from 18784 genes, 1759 cell lines, 35 ", 
               "primary diseases and 38 lineages."),
        paste0("Metadata for cell lines in the 22Q1 DepMap release, for 0 ",
               "genes, 1829 cell lines, 35 primary diseases and 40 lineages."),
        paste0("Metadata for DepMap’s cancer models/cell lines, specific to ",
               "Project Achilles’ CRISPR screens."),
        paste0("Gene summaries displaying probability of dependency for each ",
               "cell line"),
        paste0("Drug sensitivity data for cancer cell lines derived from ",
               "replicate collapsed logfold change values relative to DMSO, ",
               "corrected for experimental confounders using ComBat ",
               "representing 4686 compounds, 578 cell lines, 23 primary ",
               "diseases and 25 lineages")),
    BiocVersion = "3.15",
    Genome = "", 
    SourceType = "CSV",
    SourceUrl = c("https://ndownloader.figshare.com/files/34008491",
                  "https://ndownloader.figshare.com/files/34008428",
                  "https://ndownloader.figshare.com/files/34008404",
                  "https://ndownloader.figshare.com/files/34008434",
                  "https://ndownloader.figshare.com/files/34008503",
                  "https://ndownloader.figshare.com/files/34008386",
                  "https://depmap.org/portal/api/download/gene_dep_summary",
                  "https://ndownloader.figshare.com/files/17008628"
                  ),
    SourceVersion = "Feb 17 2022",
    Species = "Homo sapiens",
    TaxonomyId = 9606,
    Coordinate_1_based = TRUE,
    DataProvider = "Broad Institute",
    Maintainer = "Theo Killian <theo.killian@vib.be>",
    RDataClass = "tibble",
    DispatchClass = "Rda",
    RDataPath = c("depmap/crispr_22Q1.rda",
                  "depmap/copyNumber_22Q1.rda",
                  "depmap/TPM_22Q1.rda",
                  "depmap/mutationCalls_22Q1.rda",
                  "depmap/metadata_22Q1.rda",
                  "depmap/achilles_22Q1.rda",
                  "depmap/gene_summary_22Q1.rda",
                  "depmap/drug_sensitivity_21Q2.rda"),
    Tags = paste0(
 "ExperimentHub, ExperimentData, ReproducibleResearch, RepositoryData, ",
 "AssayDomainData, CopyNumberVariationData, DiseaseModel, CancerData, ",
 "BreastCancerData, ColonCancerData, KidneyCancerData, LeukemiaCancerData, ",
 "LungCancerData, OvarianCancerData, ProstateCancerData OrganismData, ",
 "Homo_sapiens_Data, PackageTypeData, SpecimenSource, CellCulture, Genome, ", 
 "Proteome, StemCell, Tissue"),
    Notes = "This dataset is from the 22Q1 release") -> meta_22Q1

write.csv(meta_22Q1, file = "../extdata/metadata_22Q1.csv", row.names = FALSE)
## to upload this metadata to EH, enter the following into the CL
# ExperimentHubData::makeExperimentHubMetadata(pathToPackage = "~/tmp/depmap/",
#                                              fileName = "metadata_22Q1.csv")

##' @title Depmap Package Cache
##'
##' @name dmCache
##'
##' @description
##'
##' Function to access (and manage) the depmap package
##' cache. `dmCache()` returns the central `depmap` cache.
##'
##' @details
##'
##' The cache is an object of class `BiocFileCache`, and created with
##' [BiocFileCache::BiocFileCache()]. It can be either the
##' package-wide cache as defined by `dmCache()` or an instaned
##' provided by the user.
##'
##' When projects are cached, they are given a resource name
##' (`rname`), that is set to the file's identifier.
##'
##' @return The `dmCache()` function returns an instance of class
##'     `BiocFileCache`.
##'
##' @rdname cache
##'
##' @author Laurent Gatto
##'
##' @export
##'
##' @importFrom tools R_user_dir
##' @importFrom BiocFileCache BiocFileCache bfcquery bfcadd bfcrpath
##'
##' @examples
##'
##' ## Default depmap cache
##' dmCache()
dmCache <- function() {
    cache <- tools::R_user_dir(package = "depmap", which = "cache")
    BiocFileCache::BiocFileCache(cache, ask = interactive())
}

dmget1 <- function(url, cache = dmCache()) {
    ## Query the local depmap cache
    rid <- bfcquery(cache, url, "fpath", exact = TRUE)$rid
    ## Add the new file to the cache
    if (!length(rid)) {
        message("Downloading ", basename(url), " file." )
        rid <- names(bfcadd(cache, url, url))
    } else {
        message("Loading ", basename(url), " from cache." )
    }
    bfcrpath(cache, rids = rid)
}

### =========================================================================
### depmap metadata 21Q1 data 
### -------------------------------------------------------------------------
### this script generates the metadata_21Q1.csv
## note: this script assumes that your current directory is depmap/inst/scripts/
## https://depmap.org/portal/download/

meta_21Q1 <- data.frame(
    Title = c(paste0("crispr_21Q1"), 
              paste0("copyNumber_21Q1"),
              paste0("TPM_21Q1"),
              paste0("mutationCalls_21Q1"),
              paste0("metadata_21Q1")),
    Description = c(
        paste0("(CERES) Batch and off-target corrected CRISPR-Cas9 gene, ",
               "knockdout dependency data for 18119 genes, 808 cell lines, 31 ",
               "primary diseases and 29 lineages."),
        paste0("WES log copy number data for 27562 genes, 1740 cell lines, 35 ",
               "primary diseases and 38 lineages."),
        paste0("CCLE 'Transcript Per Million' (TPM) RNAseq gene expression ",
               "data (in scale scale (log2(TPM+1))) for protein coding genes ",
               "from 19177 genes, 1376 cancer cell lines, 33 primary diseases ",
               "and 37 lineages."),
        paste0("CCLE mutation calls (for coding region, germline filtered) ",
               "and includes data from 18788 genes, 1747 cell lines, 35 ", 
               "primary diseases and 38 lineages."),
        paste0("Metadata for cell lines in the 21Q1 DepMap release, for 0 ",
               "genes, 1811 cell lines, 35 primary diseases and 39 lineages.")),
    BiocVersion = "3.12",
    Genome = "", 
    SourceType = "CSV",
    SourceUrl = c(paste0("https://ndownloader.figshare.com/files/26261293"),
                  paste0("https://ndownloader.figshare.com/files/26261524"),
                  paste0("https://ndownloader.figshare.com/files/26261476"),
                  paste0("https://ndownloader.figshare.com/files/26261527"),
                  paste0("https://ndownloader.figshare.com/files/26261569")),
    SourceVersion = "Feb 7 2021",
    Species = "Homo sapiens",
    TaxonomyId = 9606,
    Coordinate_1_based = TRUE,
    DataProvider = "Broad Institute",
    Maintainer = "Theo Killian <theodore.killian@kuleuven.vib.be>",
    RDataClass = "tibble",
    DispatchClass = "Rda",
    RDataPath = c(paste0("depmap/crispr_21Q1.rda"), 
                  paste0("depmap/copyNumber_21Q1.rda"),
                  paste0("depmap/TPM_21Q1.rda"),
                  paste0("depmap/mutationCalls_21Q1.rda"),
                  paste0("depmap/metadata_21Q1.rda")),
    Tags = paste0(
 "ExperimentHub, ExperimentData, ReproducibleResearch, RepositoryData, ",
 "AssayDomainData, CopyNumberVariationData, DiseaseModel, CancerData, ",
 "BreastCancerData, ColonCancerData, KidneyCancerData, LeukemiaCancerData, ",
 "LungCancerData, OvarianCancerData, ProstateCancerData OrganismData, ",
 "Homo_sapiens_Data, PackageTypeData, SpecimenSource, CellCulture, Genome, ", 
  "Proteome, StemCell, Tissue"),
    Notes = "This dataset is from the 21Q1 release")

write.csv(meta_21Q1, file = "../extdata/metadata_21Q1.csv", row.names = FALSE)
## to upload this metadata to EH, enter the following into the CL
# ExperimentHubData::makeExperimentHubMetadata("~/tmp/depmap/",
#                                              fileName = "metadata_21Q1.csv")

#' rnai_19Q3
#'
#' The `rnai` dataset contains the 19Q3 cancer dependency of select cancer cell
#' lines for genes found by RNAi gene knockdown. This dataset includes data from
#' 17309 genes, 712 cancer cell lines, 31 primary diseases and 31 lineages.
#' The columns of `rnai` are: `depmap_id`, a foreign key corresponding to the
#' cancer cell lineage, `cell_line` containing the common CCLE name of the
#' cancer cell lines, `gene` containing both the HUGO gene name of the knockdown
#' gene along with entrez ID#, `gene_name` which only contains HUGO gene name,
#' `entrez_id` which contains only the entrez ID# and `dependency` which
#' contains the numerical dependency score values for each pair of genes and
#' cell lines. This dataset can be loaded into the R environment with the
#' `depmap_rnai` function.
#'
#' @format A data frame with 12324008 rows (cell lines) and 6 variables:
#' \describe{
#'     \item{depmap_id}{cancer cancer cell line foreign key (i.e. "ACH-00001")}
#'     \item{cell_line}{CCLE name of cancer cell line (i.e. "184A1_BREAST")}
#'     \item{gene}{HUGO symbol (e.g. "SAP25") and Entrez ID# (e.g. 100316904)}
#'     \item{gene_name}{HUGO symbol (e.g. "SAP25")}
#'     \item{entrez_id}{Entrez ID# (e.g. 100316904)}
#'     \item{dependency}{numerical depenency score of a gene for a cell line}
#' }
#'
#' @details This data represents the `D2_combined_genetic_dependency_scores`
#' file taken from the 19Q3 [Broad Institute](https://depmap.org/portal/download/)
#' cancer depenedency study. The derived dataset found in the `depmap` package
#' features the addition of a foreign key `depmap_id` found in the first column
#' of this dataset, which was added from the `metadata` dataset. This dataset
#' has been converted to a long format tibble. Variables names from the original
#' dataset were converted to lower case, put in snake case, and abbreviated
#' where feasible.
#'
#' @section Change log:
#'
#' - 19Q1: Initial dataset consisted of a data frame with 12324008 rows (cell
#' lines) and 6 variables representing 17309 genes, 711 cancer cell lines, 30
#' primary diseases and 31 lineages.
#'
#' - 19Q2: adds 1 cell line
#'
#' - 19Q3: adds 1 primary disease
#'
#' - 19Q4: no change, no further releases are scheduled at this time. NOTE:
#' as of this release, the crispr dataset replaces the rnai dataset for
#' dependency measurements in all future releases.
#'
#' - 20Q1: no change, this dataset is superceded by the CRISPR dependency
#' screens and no further releases are scheduled.
#'
#' @docType data
#'
#' @import dplyr
#'
#' @keywords datasets
#'
#' @examples
#' \dontrun{
#' depmap_rnai()
#' }
#'
#' @references Tsherniak, A., Vazquez, F., Montgomery, P. G., Weir, B. A.,
#' Kryukov, G., Cowley, G. S., ... & Meyers, R. M. (2017). Defining a cancer
#' dependency map. Cell, 170(3), 564-576.
#'
#' James M. McFarland, Zandra V. Ho, Guillaume Kugener, Joshua M. Dempster,
#' Phillip G. Montgomery, Jordan G. Bryan, John M. Krill-Burger, Thomas M.
#' Green, Francisca Vazquez, Jesse S. Boehm, Todd R. Golub, William C. Hahn,
#' David E. Root, Aviad Tsherniak. (2018). Improved estimation of cancer
#' dependencies from large-scale RNAi screens using model-based normalization
#' and data integration. Nature Communications 9, 1.
#'
#' @source DepMap, Broad Institute: https://depmap.org/portal/download/
#'
#' @rdname rnai
#'
#' @aliases rnai_19Q3 rnai_19Q2 rnai_19Q1 depmap_rnai
rnai <- NULL

### =========================================================================
### Make 20Q3 depmap data
### -------------------------------------------------------------------------

## This scripts documents how to download and generate the data files.
## Note 1: This scipt assumes (!!!) that it is run in ./depmap/inst/scripts/ and
## saves the resulting .rda files in ./depmap/inst/data  
## (e.g. *setwd(./depmap/inst/scripts/)*)
## Note 2: the Broad Institute may change the download urls for these datasets.
## If the link to one of these datasets is broken, please contact the package
## maintainer. All Depmap data can be downloaded from the API at
## https://depmap.org/portal/download/ even if the specific links may change

library("readr")
library("dplyr")
library("tidyr")
library("ExperimentHub")

##########################################
## depmap `metadata_20Q3` dataset
##########################################

### loading data (downloading .csv file from online source)
url_39 <- "https://ndownloader.figshare.com/files/24613394"
sample_info <- read_csv(url_39)

### DepMap-2020Q3-celllines.csv data renamed to `metadata`
metadata_20Q3 <- sample_info
# names(metadata_20Q3)

#### Rename `metadata` columns to contain underscores and be in snake case
## note: "metadata_20Q3" has different columns than "metadata_20Q3"
names(metadata_20Q3)[1:25] <-c(
    "depmap_id", "stripped_cell_line_name", "cell_line", "aliases", "cosmic_id",
    "sex", "source", "Achilles_n_replicates", "cell_line_NNMD", "culture_type",
    "culture_medium", "cas9_activity", "RRID", "sample_collection_site",
    "primary_or_metastasis", "primary_disease", "subtype_disease", "age",
    "sanger_id", "WTSI_master_cell_ID", "additional_info", "lineage",
    "lineage_subtype", "lineage_sub_subtype", "lineage_molecular_subtype")

### saving cleaned and converted `metadata` data as .rda file
save(metadata_20Q3, file = "../eh_data/metadata_20Q3.rda",
     compress = "xz", compression_level = 9)

##########################################
## `depmap_id_to_name_20Q3 map `depmap_id` to `cell_line`
##########################################

##  generation of `metadata` subset `depmap_id_to_name_20Q3`
## The subset of `metadata`, `depmap_id_to_name_Q2` is used to map `cell_line`
## and depmap_id via left_join in other depmap datasets that do not contain
## both variables. If you are generating the depmap data from scratch, you will
## need to run the following code to generate the data correctly.

### `depmap_id_to_name` to add `depmap_id` or `cell_line` to other datasets
depmap_id_to_name_20Q3 <- metadata_20Q3 %>% dplyr::select(depmap_id, cell_line)

##########################################
## depmap `mutationCalls_20Q3` dataset
##########################################

### loading data (downloading .csv file from online source)
url_40 <- "https://ndownloader.figshare.com/files/24613355"
CCLE_mutations_20Q3 <- read_tsv(url_40)

### depmap_20Q3_mutation_calls data renamed to `mutationCalls`
mutationCalls_20Q3 <- CCLE_mutations_20Q3

## note: "mutationCalls_20Q3" has different columns than "mutationCalls_19Q1"
## the variable "VA_WES_AC" is no longer present in this dataset, unlike
## previous releases (e.g. 19Q1)! 
names(mutationCalls_20Q3)[1:34] <- c(
    "gene_name", "entrez_id", "ncbi_build", "chromosome", "start_pos",
    "end_pos", "strand", "var_class","var_type", "ref_allele",
    "tumor_seq_allele1", "dbSNP_RS", "dbSNP_val_status", "genome_change",
    "annotation_transcript", "tumor_sample_barcode", "cDNA_change",
    "codon_change", "protein_change", "is_deleterious", "is_tcga_hotspot",
    "tcga_hsCnt", "is_cosmic_hotspot", "cosmic_hsCnt", "ExAC_AF", "CGA_WES_AC",
    "sanger_WES_AC", "sanger_recalib_WES_AC", "RNAseq_AC", "HC_AC", "RD_AC",
    "WGS_AC", "var_annotation","depmap_id")

### rearrange columns into same column format as other datasets
mutationCalls_20Q3 <- mutationCalls_20Q3 %>%
    dplyr::select(depmap_id, everything())

### saving cleaned and converted `mutationCalls` data as .rda file
save(mutationCalls_20Q3, file = "../eh_data/mutationCalls_20Q3.rda",
     compress = "xz", compression_level = 9)

##########################################
## depmap `copyNumber_20Q3` dataset
##########################################

### loading data (downloading .csv file from online source)
url_41 <- "https://ndownloader.figshare.com/files/24613352"
CCLE_gene_cn_20Q3 <- read_csv(url_41)

### public_20Q3_gene_cn.csv data renamed to `copyNumber`
copyNumber_20Q3 <- CCLE_gene_cn_20Q3

### rename column first column to "depmap_id"
names(copyNumber_20Q3)[1] <- "depmap_id"

### gather into long form on columns: `depmap_id`, `gene`, `logCopyNumber`
copyNumber_20Q3_long <- gather(copyNumber_20Q3, gene, log_copy_number,
                               -depmap_id)

### mutate gene column into `gene_name` and `entrez_id`
copyNumber_20Q3_long <- copyNumber_20Q3_long %>% 
    mutate(entrez_id = gsub("&", ";", sub("\\)", "", sub("^.+ \\(", "", gene))),
           gene_name = gsub("&", ";", sub(" \\(.+\\)$", "", gene))) 

### left_join `copyNumber` & `depmap_id_to_name_20Q3` on `depmap_id`, 
## `cell_line`     
copyNumber_20Q3 <- copyNumber_20Q3_long %>% 
    left_join(depmap_id_to_name_20Q3, by = c("depmap_id" = "depmap_id"))

### rearrange columns into same column format as other datasets
copyNumber_20Q3 <- copyNumber_20Q3 %>% 
                        dplyr::select(depmap_id, gene, log_copy_number,
                                      entrez_id, gene_name, cell_line) %>%
                                      type_convert(cols(entrez_id = "i"))

### saving cleaned and converted `copyNumber` data as .rda file
save(copyNumber_20Q3, file = "../eh_data/copyNumber_20Q3.rda",
     compress = "xz", compression_level = 9)

##########################################
## depmap `crispr_20Q3` dataset
##########################################

### loading data (downloading .csv file from online source)
url_42 <- "https://ndownloader.figshare.com/files/24613292"
Achilles_gene_effect_20Q3 <- read_csv(url_42)

### gene_effect_corrected.csv data renamed to `crispr`
crispr_20Q3 <- Achilles_gene_effect_20Q3

### rename column first column to "depmap_id"
names(crispr_20Q3)[1] <-"depmap_id"

### gather cripsr into long form with columns: `depmap_id`, `gene`, `dependency`
crispr_20Q3_long <- gather(crispr_20Q3, gene, dependency, -depmap_id)

### mutate gene into `gene_name` and `entrez_id`
crispr_20Q3_long <- crispr_20Q3_long %>% 
    mutate(entrez_id = gsub("&", ";", sub("\\)", "", sub("^.+ \\(", "", gene))),
           gene_name = gsub("&", ";", sub(" \\(.+\\)$", "", gene))) 

### left_join `crispr_long` and `depmap_id_to_name` to add `cell_line` column   
crispr_20Q3 <- crispr_20Q3_long %>% left_join(depmap_id_to_name_20Q3, 
                                    by = c("depmap_id" = "depmap_id"))

### rearrange columns into same column format as other datasets
crispr_20Q3 <- crispr_20Q3 %>% dplyr::select(depmap_id, gene,
                                             dependency, entrez_id,
                                             gene_name, cell_line) %>%
                                             type_convert(cols(entrez_id = "i"))

### saving cleaned and converted `crispr` data as .rda file
save(crispr_20Q3, file = "../eh_data/crispr_20Q3.rda",
     compress = "xz", compression_level = 9)

##########################################
## depmap `TPM_20Q3` dataset
##########################################

### loading data (downloading .csv file from online source)
url_43 <- "https://ndownloader.figshare.com/files/24613325"
CCLE_expression_full_20Q3 <- read_tsv(url_43)

### CCLE_depMap_20Q3_TPM.csv data renamed to `TPM`
TPM_20Q3 <- CCLE_expression_full_20Q3
# names(TPM_20Q3)

### rename column first column to "depmap_id"
names(TPM_20Q3)[1] <-"depmap_id"

### gather `TPM` into long form on columns: `depmap_id`, `gene`, `expression`
TPM_20Q3_long <- gather(TPM_20Q3, gene, rna_expression, -depmap_id)

### mutate gene into gene_name and ensembl_id
TPM_20Q3_long %>% 
    mutate(ensembl_id = gsub("&", ";", sub("\\)", "", sub("^.+ \\(", "",gene))),
           gene_name = gsub("&", ";", sub(" \\(.+\\)$", "", gene))
           ) -> TPM_20Q3_long 

### left_join join `TPM` and `depmap_id_to_name_20Q3` to add `cell_line` column
TPM_20Q3_long %>%
    left_join(depmap_id_to_name_20Q3, by = c("depmap_id" = "depmap_id")
              ) -> TPM_20Q3

### rearrange columns into same column format as other datasets
TPM_20Q3 %>%
    select(depmap_id, gene, rna_expression, entrez_id, gene_name, cell_line) %>%
    type_convert(cols(entrez_id = "i")) -> TPM_20Q3

### saving cleaned and converted `TPM` data as .rda file
save(TPM_20Q3, file = "../eh_data/TPM_20Q3.rda", compress = "xz",
     compression_level = 9)

### =========================================================================
### Make 20Q2 depmap data
### -------------------------------------------------------------------------
###

## This scripts documents how to download and generate the data files.
## Note 1: This scipt assumes (!!!) that it is run in ./depmap/inst/scripts/ and
## saves the resulting .rda files in ./depmap/inst/data  
## (e.g. *setwd(./depmap/inst/scripts/)*)
## Note 2: the Broad Institute may change the download urls for these datasets.
## If the link to one of these datasets is broken, please contact the package
## maintainer. All Depmap data can be downloaded from the API at
## https://depmap.org/portal/download/ even if the specific links may change

library("readr")
library("dplyr")
library("tidyr")
library("ExperimentHub")

##########################################
## depmap `metadata_20Q2` dataset
##########################################

##  data cleaning of `metadata` dataset

### loading data (downloading .csv file from online source)
url_33 <- "https://ndownloader.figshare.com/files/22629137"
sample_info <- read_csv(url_33)

### DepMap-2020q2-celllines.csv data renamed to `metadata`
metadata_20Q2 <- sample_info
names(metadata_20Q2)

# [1] "DepMap_ID"                 "stripped_cell_line_name"  
# [3] "CCLE_Name"                 "Alias"                    
# [5] "COSMICID"                  "sex"                      
# [7] "source"                    "Achilles_n_replicates"    
# [9] "cell_line_NNMD"            "culture_type"             
# [11] "culture_medium"            "cas9_activity"            
# [13] "RRID"                      "sample_collection_site"   
# [15] "primary_or_metastasis"     "primary_disease"          
# [17] "Subtype"                   "age"                      
# [19] "Sanger_Model_ID"           "depmap_public_comments"   
# [21] "lineage"                   "lineage_subtype"          
# [23] "lineage_sub_subtype"       "lineage_molecular_subtype"

#### Rename `metadata` columns to contain underscores and be in snake case
## note: "metadata_20Q2" has different columns than "metadata_20Q2"
names(metadata_20Q2)[1:24] <-c("depmap_id", "stripped_cell_line_name",
                              "cell_line", "aliases", "cosmic_id", "sex",
                              "source", "Achilles_n_replicates",
                              "cell_line_NNMD", "culture_type",
                              "culture_medium", "cas9_activity", "RRID",
                              "sample_collection_site", "primary_or_metastasis",
                              "primary_disease", "subtype_disease", "age",
                              "sanger_id", "additional_info", "lineage",
                              "lineage_subtype", "lineage_sub_subtype",
                              "lineage_molecular_subtype")

### visual check
# View(metadata_20Q2)

### saving cleaned and converted `metadata` data as .rda file
save(metadata_20Q2, file = "../eh_data/metadata_20Q2.rda",
     compress = "xz", compression_level = 9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")

##########################################
## `depmap_id_to_name_20Q2 map `depmap_id` to `cell_line`
##########################################

##  generation of `metadata` subset `depmap_id_to_name_20Q2`

## The subset of `metadata`, `depmap_id_to_name_Q2` is used to map `cell_line`
## and depmap_id via left_join in other depmap datasets that do not contain
## both variables. If you are generating the depmap data from scratch, you will
## need to run the following code to generate the data correctly.

### `depmap_id_to_name` to add `depmap_id` or `cell_line` to other datasets
depmap_id_to_name_20Q2 <- metadata_20Q2 %>% dplyr::select(depmap_id, cell_line)

### visual check
# head(depmap_id_to_name_20Q2)

##########################################
## depmap `mutationCalls_20Q2` dataset
##########################################

## data cleaning of `mutationCalls` dataset

### loading data (downloading .csv file from online source)
url_34 <- "https://ndownloader.figshare.com/files/22629110"
CCLE_mutations_20Q2 <- read_tsv(url_34)

### depmap_20Q2_mutation_calls data renamed to `mutationCalls`
mutationCalls_20Q2 <- CCLE_mutations_20Q2

#### rename last column to depmap_id
# names(mutationCalls_20Q2)
# [1] "Hugo_Symbol"            "Entrez_Gene_Id"         "NCBI_Build"            
# [4] "Chromosome"             "Start_position"         "End_position"          
# [7] "Strand"                 "Variant_Classification" "Variant_Type"          
# [10] "Reference_Allele"       "Tumor_Seq_Allele1"      "dbSNP_RS"              
# [13] "dbSNP_Val_Status"       "Genome_Change"          "Annotation_Transcript" 
# [16] "Tumor_Sample_Barcode"   "cDNA_Change"            "Codon_Change"          
# [19] "Protein_Change"         "isDeleterious"          "isTCGAhotspot"         
# [22] "TCGAhsCnt"              "isCOSMIChotspot"        "COSMIChsCnt"           
# [25] "ExAC_AF"                "CGA_WES_AC"             "SangerWES_AC"          
# [28] "SangerRecalibWES_AC"    "RNAseq_AC"              "HC_AC"                 
# [31] "RD_AC"                  "WGS_AC"                 "Variant_annotation"    
# [34] "DepMap_ID"             

## note: "mutationCalls_20Q2" has different columns than "mutationCalls_19Q1"
## the variable "VA_WES_AC" is no longer present in this dataset, unlike
## previous releases (e.g. 19Q1)! 
names(mutationCalls_20Q2)[1:34] <- c("gene_name", "entrez_id", "ncbi_build",
                                "chromosome", "start_pos", "end_pos", "strand",
                                "var_class","var_type", "ref_allele",
                                "tumor_seq_allele1", "dbSNP_RS",
                                "dbSNP_val_status", "genome_change",
                                "annotation_transcript", "tumor_sample_barcode",
                                "cDNA_change", "codon_change", "protein_change",  
                                "is_deleterious", "is_tcga_hotspot",
                                "tcga_hsCnt", "is_cosmic_hotspot",
                                "cosmic_hsCnt", "ExAC_AF", "CGA_WES_AC",
                                "sanger_WES_AC", "sanger_recalib_WES_AC",
                                "RNAseq_AC", "HC_AC", "RD_AC", "WGS_AC",
                                "var_annotation","depmap_id")

### rearrange columns into same column format as other datasets
mutationCalls_20Q2 <- mutationCalls_20Q2 %>%
    dplyr::select(depmap_id, everything())

### visual check
# View(mutationCalls_20Q2)

### saving cleaned and converted `mutationCalls` data as .rda file
save(mutationCalls_20Q2, file = "../eh_data/mutationCalls_20Q2.rda",
     compress = "xz", compression_level = 9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")

##########################################
## depmap `copyNumber_20Q2` dataset
##########################################

##  data cleaning of `copyNumber` dataset 
### loading data (downloading .csv file from online source)
url_35 <- "https://ndownloader.figshare.com/files/22629107"
CCLE_gene_cn_20Q2 <- read_csv(url_35)

### public_20Q2_gene_cn.csv data renamed to `copyNumber`
copyNumber_20Q2 <- CCLE_gene_cn_20Q2

### rename column first column to "depmap_id"
names(copyNumber_20Q2)[1] <- "depmap_id"

### gather into long form on columns: `depmap_id`, `gene`, `logCopyNumber`
copyNumber_20Q2_long <- gather(copyNumber_20Q2, gene, log_copy_number,
                               -depmap_id)

### mutate gene column into `gene_name` and `entrez_id`
copyNumber_20Q2_long <- copyNumber_20Q2_long %>% 
    mutate(entrez_id = gsub("&", ";", sub("\\)", "", sub("^.+ \\(", "", gene))),
           gene_name = gsub("&", ";", sub(" \\(.+\\)$", "", gene))) 

### left_join `copyNumber` & `depmap_id_to_name_20Q2` on `depmap_id`, 
## `cell_line`     
copyNumber_20Q2 <- copyNumber_20Q2_long %>% 
    left_join(depmap_id_to_name_20Q2, by = c("depmap_id" = "depmap_id"))

### rearrange columns into same column format as other datasets
copyNumber_20Q2 <- copyNumber_20Q2 %>% 
                        dplyr::select(depmap_id, gene, log_copy_number,
                                      entrez_id, gene_name, cell_line) %>%
                                      type_convert(cols(entrez_id = "i"))
### visual check
head(copyNumber_20Q2)

### saving cleaned and converted `copyNumber` data as .rda file
save(copyNumber_20Q2, file = "../eh_data/copyNumber_20Q2.rda",
     compress = "xz", compression_level = 9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")

##########################################
## depmap `crispr_20Q2` dataset
##########################################

##  data cleaning of `crispr` dataset`

### loading data (downloading .csv file from online source)
url_36 <- "https://ndownloader.figshare.com/files/22629068"
Achilles_gene_effect_20Q2 <- read_csv(url_36)

### gene_effect_corrected.csv data renamed to `crispr`
crispr_20Q2 <- Achilles_gene_effect_20Q2

### visual check
# head(crispr_20Q2)

### rename column first column to "depmap_id"
names(crispr_20Q2)[1] <-"depmap_id"

### gather cripsr into long form with columns: `depmap_id`, `gene`, `dependency`
crispr_20Q2_long <- gather(crispr_20Q2, gene, dependency, -depmap_id)

### mutate gene into `gene_name` and `entrez_id`
crispr_20Q2_long <- crispr_20Q2_long %>% 
    mutate(entrez_id = gsub("&", ";", sub("\\)", "", sub("^.+ \\(", "", gene))),
           gene_name = gsub("&", ";", sub(" \\(.+\\)$", "", gene))) 

### left_join `crispr_long` and `depmap_id_to_name` to add `cell_line` column   
crispr_20Q2 <- crispr_20Q2_long %>% left_join(depmap_id_to_name_20Q2, 
                                    by = c("depmap_id" = "depmap_id"))

### rearrange columns into same column format as other datasets
crispr_20Q2 <- crispr_20Q2 %>% dplyr::select(depmap_id, gene,
                                             dependency, entrez_id,
                                             gene_name, cell_line) %>%
                                             type_convert(cols(entrez_id = "i"))
### visual check
head(crispr_20Q2)

### saving cleaned and converted `crispr` data as .rda file
save(crispr_20Q2, file = "../eh_data/crispr_20Q2.rda",
     compress = "xz", compression_level = 9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")

##########################################
## depmap `TPM_20Q2` dataset
##########################################

## data cleaning of `TPM` dataset

### loading data (downloading .csv file from online source)
url_37 <- "https://ndownloader.figshare.com/files/22629092"
CCLE_expression_full_20Q2 <- read_tsv(url_37)

### CCLE_depMap_20Q2_TPM.csv data renamed to `TPM`
TPM_20Q2 <- CCLE_expression_full_20Q2
# names(TPM_20Q2)

### rename column first column to "depmap_id"
names(TPM_20Q2)[1] <-"depmap_id"

### gather `TPM` into long form on columns: `depmap_id`, `gene`, `expression`
TPM_20Q2_long <- gather(TPM_20Q2, gene, rna_expression, -depmap_id)

### mutate gene into gene_name and ensembl_id
TPM_20Q2_long <- TPM_20Q2_long %>% 
    mutate(ensembl_id = gsub("&", ";", sub("\\)", "", sub("^.+ \\(", "",gene))),
           gene_name = gsub("&", ";", sub(" \\(.+\\)$", "", gene))) 

### left_join join `TPM` and `depmap_id_to_name_20Q2` to add `cell_line` column
TPM_20Q2_long %>%
    left_join(depmap_id_to_name_20Q2, by = c("depmap_id" = "depmap_id")
              ) -> TPM_20Q2

### rearrange columns into same column format as other datasets
TPM_20Q2 %>%
    dplyr::select(depmap_id, gene, rna_expression, entrez_id, gene_name,
                  cell_line) %>%
    type_convert(cols(entrez_id = "i")) -> TPM_20Q2

### saving cleaned and converted `TPM` data as .rda file
save(TPM_20Q2, file = "../eh_data/TPM_20Q2.rda", compress = "xz",
     compression_level = 9)

##########################################
## depmap `proteomic_20Q2` dataset
##########################################

## data cleaning of `TPM` dataset
### loading data (downloading .csv file from online source)
url_38 <- "https://gygi.med.harvard.edu/sites/gygi.med.harvard.edu/files/documents/protein_quant_current_normalized.csv.gz"
protein_quant_current_normalized_20Q2 <- read_csv(url_38)

### protein_quant_current_normalized_TPM.csv data renamed to `TPM`
proteomic_20Q2 <- protein_quant_current_normalized_20Q2
# names(proteomic_20Q2)

### gather `proteomic` into long form on columns: `depmap_id`, `gene`, `expression`
proteomic_20Q2_long <- proteomic_20Q2 %>%
    dplyr::select(-starts_with("TenPx")) %>%
    pivot_longer(names_to = "Protein", values_to = "protein_expression", 7:384)

### mutate gene into gene_name and ensembl_id
proteomic_20Q2_long <- proteomic_20Q2_long %>% 
    mutate(TenPx = gsub("^.*?TenPx", "TenPx", Protein)) %>% 
    mutate(cell_line = sub("_[^_]+$", "", Protein))

### left_join join proteomic & depmap_id_to_name_20Q2, add cell_line column
proteomic_20Q2 <- proteomic_20Q2_long %>%
    dplyr::left_join(depmap_id_to_name_20Q2, by = c("cell_line" = "cell_line"))

names(proteomic_20Q2) <- c("protein_id", "gene_name", "desc",
                           "group_id", "uniprot", "uniprot_acc", "protein",
                           "protein_expression", "TenPx", "cell_line" , "depmap_id")

proteomic_20Q2 <- proteomic_20Q2 %>%
    dplyr::left_join(unique(dplyr::select(mutationCalls_20Q2, gene_name, entrez_id)),
                     by = c("gene_name" = "gene_name"))

### rearrange columns into same column format as other datasets
proteomic_20Q2 <- proteomic_20Q2 %>%
    dplyr::select(depmap_id, gene_name, entrez_id, protein, protein_expression,
                  everything()) %>%
    type_convert(cols(entrez_id = "i"))

### visual check
# View(proteomic_20Q2)

### saving cleaned and converted `proteomic` data as .rda file
save(proteomic_20Q2, file = "../eh_data/proteomic_20Q2.rda", compress = "xz",
     compression_level = 9)

## ----style, echo = FALSE, results = 'asis'------------------------------------
BiocStyle::markdown()

## ----load_libraries, message=FALSE, warning=FALSE, echo=TRUE------------------
library("dplyr")
library("ggplot2")
library("viridis")
library("tibble")
library("gridExtra")
library("stringr")
library("depmap")
library("ExperimentHub")

## ----load_data, message=FALSE, warning=FALSE, echo=TRUE-----------------------
## create ExperimentHub query object
eh <- ExperimentHub()
query(eh, "depmap")
rnai <- eh[["EH3080"]]
mutationCalls <- eh[["EH3085"]]
metadata <- eh[["EH3086"]]
TPM <- eh[["EH3084"]]
copyNumber <- eh[["EH3082"]]
# crispr <- eh[["EH3081"]]
# drug_sensitivity <- eh[["EH3087"]]

## ----soft_tissue_cell_lines, echo=TRUE----------------------------------------
## list of dependency scores
rnai |>
    dplyr::select(cell_line, gene_name, dependency) |>
    dplyr::filter(stringr::str_detect(cell_line, "SOFT_TISSUE")) |>
    dplyr::arrange(dependency) |>
    head(10)

## ----message=FALSE, warning=FALSE---------------------------------------------
## Basic histogram
rnai |>
    dplyr::select(gene, gene_name, dependency) |>
    dplyr::filter(gene_name == "RPL14") |>
    ggplot(aes(x = dependency)) +
    geom_histogram() +
    geom_vline(xintercept = mean(rnai$dependency, na.rm = TRUE),
               linetype = "dotted", color = "red") +
    ggtitle("Histogram of dependency scores for gene RPL14")

## ----message=FALSE, warning=FALSE---------------------------------------------
meta_rnai <- metadata |>
    dplyr::select(depmap_id, lineage) |>
    dplyr::full_join(rnai, by = "depmap_id") |>
    dplyr::filter(gene_name == "RPL14") |>
    dplyr::full_join((mutationCalls |>
                      dplyr::select(depmap_id, entrez_id,
                                    is_cosmic_hotspot, var_annotation)),
                     by = c("depmap_id", "entrez_id"))

p1 <- meta_rnai |>
      ggplot(aes(x = dependency, y = lineage)) +
      geom_point(alpha = 0.4, size = 0.5) +
      geom_point(data = subset(
         meta_rnai, var_annotation == "damaging"), color = "red") +
      geom_point(data = subset(
         meta_rnai, var_annotation == "other non-conserving"), color = "blue") +
      geom_point(data = subset(
         meta_rnai, var_annotation == "other conserving"), color = "cyan") +
      geom_point(data = subset(
         meta_rnai, is_cosmic_hotspot == TRUE), color = "orange") +
      geom_vline(xintercept=mean(meta_rnai$dependency, na.rm = TRUE),
                 linetype = "dotted", color = "red") +
      ggtitle("Scatterplot of dependency scores for gene RPL14 by lineage")

p1

## ----message=FALSE, warning=FALSE---------------------------------------------
metadata |>
    dplyr::select(depmap_id, lineage) |>
    dplyr::full_join(TPM, by = "depmap_id") |>
    dplyr::filter(gene_name == "RPL14") |>
    ggplot(aes(x = lineage, y = expression, fill = lineage)) +
    geom_boxplot(outlier.alpha = 0.1) +
    ggtitle("Boxplot of expression values for gene RPL14 by lineage") +
    theme(axis.text.x = element_text(angle = 45, hjust=1)) +
    theme(legend.position = "none")

## ----message=FALSE, warning=FALSE---------------------------------------------
## expression vs rnai gene dependency for Rhabdomyosarcoma Sarcoma
sarcoma <- metadata |>
    dplyr::select(depmap_id, cell_line,
                  primary_disease, subtype_disease) |>
    dplyr::filter(primary_disease == "Sarcoma",
                  subtype_disease == "Rhabdomyosarcoma")

rnai_sub <- rnai |>
    dplyr::select(depmap_id, gene, gene_name, dependency)
tpm_sub <- TPM |>
    dplyr::select(depmap_id, gene, gene_name, expression)

sarcoma_dep <- sarcoma |>
    dplyr::left_join(rnai_sub, by = "depmap_id") |>
    dplyr::select(-cell_line, -primary_disease,
                  -subtype_disease, -gene_name)

sarcoma_exp <- sarcoma |>
    dplyr::left_join(tpm_sub, by = "depmap_id")

sarcoma_dat_exp <- dplyr::full_join(sarcoma_dep, sarcoma_exp,
                                    by = c("depmap_id", "gene")) |>
    dplyr::filter(!is.na(expression))

p2 <- ggplot(data = sarcoma_dat_exp, aes(x = dependency, y = expression)) +
    geom_point(alpha = 0.4, size = 0.5) +
    geom_vline(xintercept=mean(sarcoma_dat_exp$dependency, na.rm = TRUE),
               linetype = "dotted", color = "red") +
    geom_hline(yintercept=mean(sarcoma_dat_exp$expression, na.rm = TRUE),
               linetype = "dotted", color = "red") +
    ggtitle("Scatterplot of rnai dependency vs expression values for gene")

p2 + theme(axis.text.x = element_text(angle = 45))

## -----------------------------------------------------------------------------
sarcoma_dat_exp |>
    dplyr::select(cell_line, gene_name, dependency, expression) |>
    dplyr::arrange(dependency) |>
    head(10)

## ----message=FALSE, warning=FALSE---------------------------------------------
metadata |>
    dplyr::select(depmap_id, lineage) |>
    dplyr::full_join(copyNumber, by = "depmap_id") |>
    dplyr::filter(gene_name == "RPL14") |>
    ggplot(aes(x = lineage, y = log_copy_number, fill = lineage)) +
    geom_boxplot(outlier.alpha = 0.1) +
    ggtitle("Boxplot of log copy number for gene RPL14 by lineage") +
    theme(axis.text.x = element_text(angle = 45, hjust = 1)) +
    theme(legend.position = "none")

## ----echo = FALSE-------------------------------------------------------------
sessionInfo()

### =========================================================================
### Make 19Q4 depmap data
### -------------------------------------------------------------------------
###

## This scripts documents how to download and generate the data files.
## Note 1: This scipt assumes (!!!) that it is run in ./depmap/inst/scripts/ and
## saves the resulting .rda files in ./depmap/inst/data  
## (e.g. *setwd(./depmap/inst/scripts/)*)
## Note 2: the Broad Institute may change the download urls for these datasets.
## If the link to one of these datasets is broken, please contact the package
## maintainer. All Depmap data can be downloaded from the API at
## https://depmap.org/portal/download/ even if the specific links may change

library("readr")
library("dplyr")
library("tidyr")
library("ExperimentHub")

##########################################
## EH3086 depmap `metadata_19Q4` dataset
##########################################

##  data cleaning of `metadata` dataset

### loading data (downloading .csv file from online source)
url_23 <- "https://ndownloader.figshare.com/files/20274744"
sample_info <- read_csv(url_23)

### DepMap-2019q1-celllines.csv data renamed to `metadata`
metadata_19Q4 <- sample_info
# names(metadata_19Q4)
# [1] "DepMap_ID"                 "stripped_cell_line_name"   "CCLE_Name"                
# [4] "alias"                     "COSMIC_ID"                 "lineage"                  
# [7] "lineage_subtype"           "lineage_sub_subtype"       "lineage_molecular_subtype"
# [10] "sex"                       "source"                    "Achilles_n_replicates"    
# [13] "cell_line_NNMD"            "culture_type"              "culture_medium"           
# [16] "cas9_activity"             "RRID"                      "sample_collection_site"   
# [19] "primary_or_metastasis"     "disease"                   "disease_subtype"          
# [22] "age"                       "Sanger_model_ID"           "additional_info"   

#### Rename `metadata` columns to contain underscores and be in snake case
## note: "metadata_19Q4" has different columns than "metadata_19Q4"
names(metadata_19Q4)[1:24] <-c("depmap_id", "stripped_cell_line_name",
                              "cell_line", "aliases", "cosmic_id", "lineage",
                              "lineage_subtype", "lineage_sub_subtype",
                              "lineage_molecular_subtype", "sex",
                              "source", "Achilles_n_replicates",
                              "cell_line_NNMD", "culture_type",
                              "culture_medium", "cas9_activity", "RRID",
                              "sample_collection_site", "primary_or_metastasis",
                              "primary_disease", "subtype_disease", "age",
                              "sanger_id", "additional_info")

### visual check
View(metadata_19Q4)

### saving cleaned and converted `metadata` data as .rda file
save(metadata_19Q4, file = "../eh_data/metadata_19Q4.rda",
     compress = "xz", compression_level = 9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")

##########################################
## `depmap_id_to_name_19Q4 map `depmap_id` to `cell_line`
##########################################

##  generation of `metadata` subset `depmap_id_to_name_19Q4`

## The subset of `metadata`, `depmap_id_to_name_Q2` is used to map `cell_line`
## and depmap_id via left_join in other depmap datasets that do not contain
## both variables. If you are generating the depmap data from scratch, you will
## need to run the following code to generate the data correctly.

### `depmap_id_to_name` to add `depmap_id` or `cell_line` to other datasets
depmap_id_to_name_19Q4 <- metadata_19Q4 %>% dplyr::select(depmap_id, cell_line)

### visual check
# head(depmap_id_to_name_19Q4)

##########################################
## depmap `mutationCalls_19Q4` dataset
##########################################

## data cleaning of `mutationCalls` dataset

### loading data (downloading .csv file from online source)
url_24 <- "https://ndownloader.figshare.com/files/20274747"
CCLE_mutations_19Q4 <- read_csv(url_24)

### depmap_19Q1_mutation_calls data renamed to `mutationCalls`
mutationCalls_19Q4 <- CCLE_mutations_19Q4
head(mutationCalls_19Q4)

## remove unnecessary X1 variable
mutationCalls_19Q4 <- mutationCalls_19Q4 %>% dplyr::select(-X1)

#### rename last column to depmap_id
names(mutationCalls_19Q4)
# [1] "Hugo_Symbol"            "Entrez_Gene_Id"         "NCBI_Build"            
# [4] "Chromosome"             "Start_position"         "End_position"          
# [7] "Strand"                 "Variant_Classification" "Variant_Type"          
# [10] "Reference_Allele"       "Tumor_Seq_Allele1"      "dbSNP_RS"              
# [13] "dbSNP_Val_Status"       "Genome_Change"          "Annotation_Transcript"
# [16] "Tumor_Sample_Barcode"   "cDNA_Change"            "Codon_Change"          
# [19] "Protein_Change"         "isDeleterious"          "isTCGAhotspot"         
# [22] "TCGAhsCnt"              "isCOSMIChotspot"        "COSMIChsCnt"           
# [25] "ExAC_AF"                "CGA_WES_AC"             "SangerWES_AC"          
# [28] "SangerRecalibWES_AC"    "RNAseq_AC"              "HC_AC"                 
# [31] "RD_AC"                  "WGS_AC"                 "Variant_annotation"
# [34] "DepMap_ID"             

## note: "mutationCalls_19Q4" has different columns than "mutationCalls_19Q1"
## the variable "VA_WES_AC" is no longer present in this dataset, unlike
## previous releases (e.g. 19Q1)! 
names(mutationCalls_19Q4)[1:34] <- c("gene_name", "entrez_id", "ncbi_build",
                                "chromosome", "start_pos", "end_pos", "strand",
                                "var_class","var_type", "ref_allele",
                                "tumor_seq_allele1", "dbSNP_RS",
                                "dbSNP_val_status", "genome_change",
                                "annotation_transcript", "tumor_sample_barcode",
                                "cDNA_change", "codon_change", "protein_change",  
                                "is_deleterious", "is_tcga_hotspot",
                                "tcga_hsCnt", "is_cosmic_hotspot",
                                "cosmic_hsCnt", "ExAC_AF", "CGA_WES_AC",
                                "sanger_WES_AC", "sanger_recalib_WES_AC",
                                "RNAseq_AC", "HC_AC", "RD_AC", "WGS_AC",
                                "var_annotation","depmap_id")

### rearrange columns into same column format as other datasets
mutationCalls_19Q4 <- mutationCalls_19Q4 %>%
    dplyr::select(depmap_id, gene_name, entrez_id, ncbi_build, chromosome,
                  start_pos, end_pos, strand, var_class, var_type, ref_allele,
                  tumor_seq_allele1, dbSNP_RS, dbSNP_val_status, genome_change,
                  annotation_transcript, tumor_sample_barcode, cDNA_change,
                  codon_change, protein_change, is_deleterious, is_tcga_hotspot,
                  tcga_hsCnt, is_cosmic_hotspot, cosmic_hsCnt, ExAC_AF,
                  CGA_WES_AC, sanger_WES_AC, sanger_recalib_WES_AC, RNAseq_AC,
                  HC_AC, RD_AC, WGS_AC, var_annotation)

### visual check
# head(mutationCalls_19Q4)

### saving cleaned and converted `mutationCalls` data as .rda file
save(mutationCalls_19Q4, file = "../eh_data/mutationCalls_19Q4.rda",
     compress = "xz", compression_level = 9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")

##########################################
## depmap `copyNumber_19Q4` dataset
##########################################

##  data cleaning of `copyNumber` dataset 

### loading data (downloading .csv file from online source)
url_25 <- "https://ndownloader.figshare.com/files/20234367"
CCLE_gene_cn_19Q4 <- read_csv(url_25)

### public_19Q1_gene_cn.csv data renamed to `copyNumber`
copyNumber_19Q4 <- CCLE_gene_cn_19Q4

### rename column first column to "depmap_id"
names(copyNumber_19Q4)[1] <- "depmap_id"

### gather into long form on columns: `depmap_id`, `gene`, `logCopyNumber`
copyNumber_19Q4_long <- gather(copyNumber_19Q4, gene, log_copy_number,
                               -depmap_id)

### mutate gene column into `gene_name` and `entrez_id`
copyNumber_19Q4_long <- copyNumber_19Q4_long %>% 
    mutate(entrez_id = gsub("&", ";", sub("\\)", "", sub("^.+ \\(", "", gene))),
           gene_name = gsub("&", ";", sub(" \\(.+\\)$", "", gene))) 

### left_join `copyNumber` & `depmap_id_to_name_19Q4` on `depmap_id`, 
## `cell_line`     
copyNumber_19Q4 <- copyNumber_19Q4_long %>% 
    left_join(depmap_id_to_name_19Q4, by = c("depmap_id" = "depmap_id"))

### rearrange columns into same column format as other datasets
copyNumber_19Q4 <- copyNumber_19Q4 %>% 
                        dplyr::select(depmap_id, gene, log_copy_number,
                                      entrez_id, gene_name, cell_line) %>%
                                      type_convert(cols(entrez_id = "i"))
### visual check
head(copyNumber_19Q4)

### saving cleaned and converted `copyNumber` data as .rda file
save(copyNumber_19Q4, file = "../eh_data/copyNumber_19Q4.rda",
     compress = "xz", compression_level = 9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")

##########################################
## depmap `crispr_19Q4` dataset
##########################################

##  data cleaning of `crispr` dataset`

### loading data (downloading .csv file from online source)
url_26 <- "https://ndownloader.figshare.com/files/20234073"
Achilles_gene_effect_19Q4 <- read_csv(url_26)

### gene_effect_corrected.csv data renamed to `crispr`
crispr_19Q4 <- Achilles_gene_effect_19Q4

### visual check
head(crispr_19Q4)

### rename column first column to "depmap_id"
names(crispr_19Q4)[1] <-"depmap_id"

### gather cripsr into long form with columns: `depmap_id`, `gene`, `dependency`
crispr_19Q4_long <- gather(crispr_19Q4, gene, dependency, -depmap_id)

### mutate gene into `gene_name` and `entrez_id`
crispr_19Q4_long <- crispr_19Q4_long %>% 
    mutate(entrez_id = gsub("&", ";", sub("\\)", "", sub("^.+ \\(", "", gene))),
           gene_name = gsub("&", ";", sub(" \\(.+\\)$", "", gene))) 

### left_join `crispr_long` and `depmap_id_to_name` to add `cell_line` column   
crispr_19Q4 <- crispr_19Q4_long %>% left_join(depmap_id_to_name_19Q4, 
                                    by = c("depmap_id" = "depmap_id"))

### rearrange columns into same column format as other datasets
crispr_19Q4 <- crispr_19Q4 %>% dplyr::select(depmap_id, gene,
                                             dependency, entrez_id,
                                             gene_name, cell_line) %>%
                                             type_convert(cols(entrez_id = "i"))
### visual check
head(crispr_19Q4)

### saving cleaned and converted `crispr` data as .rda file
save(crispr_19Q4, file = "../eh_data/crispr_19Q4.rda",
     compress = "xz", compression_level = 9)

## access the data on ExperimentHub
# hub <- ExperimentHub()
# x <- query(hub, "depmap")

##########################################
## depmap `TPM_19Q4` dataset
##########################################

## data cleaning of `TPM` dataset

### loading data (downloading .csv file from online source)
url_27 <- "https://ndownloader.figshare.com/files/20234346"
CCLE_expression_full_19Q4 <- read_csv(url_27)

### CCLE_depMap_19Q1_TPM.csv data renamed to `TPM`
TPM_19Q4 <- CCLE_expression_full_19Q4
names(TPM_19Q4)

### rename column first column to "depmap_id"
names(TPM_19Q4)[1] <-"depmap_id"

### gather `TPM` into long form on columns: `depmap_id`, `gene`, `expression`
TPM_19Q4_long <- gather(TPM_19Q4, gene, expression, -depmap_id)

### mutate gene into gene_name and ensembl_id
TPM_19Q4_long <- TPM_19Q4_long %>% 
    mutate(ensembl_id = gsub("&", ";", sub("\\)", "", sub("^.+ \\(", "",gene))),
           gene_name = gsub("&", ";", sub(" \\(.+\\)$", "", gene))) 

### left_join join `TPM` and `depmap_id_to_name_19Q4` to add `cell_line` column
TPM_19Q4 <- TPM_19Q4_long %>% left_join(depmap_id_to_name_19Q4, 
                              by = c("depmap_id" = "depmap_id"))

### rearrange columns into same column format as other datasets
TPM_19Q4 <- TPM_19Q4 %>% dplyr::select(depmap_id, gene, expression, entrez_id,
                                gene_name, cell_line) %>%
                                type_convert(cols(entrez_id_id = "i"))
### visual check
head(TPM_19Q4)

### saving cleaned and converted `TPM` data as .rda file
save(TPM_19Q4, file = "../eh_data/TPM_19Q4.rda", compress="xz",
     compression_level = 9)

#' metadata_22Q2
#'
#' The `metadata` dataset contains the metadata about cell lines in the 22Q2
#' Broad Institute DepMap release, which includes mapping between `depmap_id`
#' and `cell_line` name for cancer cell lines. This dataset does not contain any
#' data from the Achilles screen nor dependency data, but contains the metadata
#' from the other datasets pertaining to the 22Q1 DepMap release, for 1840
#' cell lines, 0 genes, 33 primary diseases and 30 lineages. The columns of
#' `metadata` are: `depmap_id`, `stripped_cell_line_name`, `cell_line`,
#' `aliases`, `cosmic_id`, `sanger_id`, `WTSI_master_cell_ID`,
#' `primary_disease`, `subtype_disease`, `sub_subtype_disease`, `gender`,
#' `source` . This dataset can be loaded into the R
#'  environment with the `depmap_metadata` function.
#'
#' @format A data frame with 1829 rows (cell lines) and 22 variables:
#' \describe{
#'   \item{depmap_id}{Cancer cell line primary key (i.e. "ACH-00001")}
#'   \item{stripped_cell_line_name}{Name of stripped cell line}
#'   \item{cell_line}{CCLE name of cancer cell line (i.e. "184A1_BREAST")}
#'   \item{cell_line_name}{Abbreviated name of cancer cell line (i.e. "NIH:OVCAR-3")}
#'   \item{aliases}{Aliases of cancer cell line}
#'   \item{cosmic_id}{Catalogue Of Somatic Mutations In Cancer ID number (e.g. 905933)}
#'   \item{sex}{Sex of tissue sample)}
#'   \item{source}{Source of tissue sample)}
#'   \item{culture_type}{Culture type of tissue sample)}
#'   \item{RRID}{Resource Identification Portal ID}
#'   \item{sample_collection_site}{Site of sample collection (AML), M3 (Promyelocytic))}
#'   \item{primary_or_metastasis}{Primary cancer cell line or metastatic}
#'   \item{primary_disease}{Primary Disease (e.g. cancer type)}
#'   \item{subtype_disease}{Subtype Disease (e.g. Acute Myelogenous Leukemia)}
#'   \item{age}{Age of individual sample of cell line was derived}
#'   \item{sanger_id}{Sanger ID (eg. 2201)}
#'   \item{WTSI_master_cell_ID}{Wellcome Trust Sanger Institute ID (eg. 1369)}
#'   \item{additional_info}{Additional information about samples}
#'   \item{lineage}{Lineage of cancer cell line}
#'   \item{lineage_subtype}{Subtype of lineage of cancer cell line}
#'   \item{lineage_sub_subtype}{Subtype of subtype of Lineage of cancer cell line}
#'   \item{lineage_molecular_subtype}{Molecular type of Lineage of cancer cell line}
#'   \item{model_manipulation}{Culture model manipulation details}
#'   \item{model_manipulation_details}{Culture model manipulation details}
#'   \item{patient_id}{Patient id}
#'   \item{parent_patient_id}{Parent patient id}
#'   \item{Cellosaurus_NCIt_disease}{Cellosaurus NCIt disease}
#'   \item{Cellosaurus_NCIt_id}{Cellosaurus NCIt_id}
#'   \item{Cellosaurus_NCIt_id}{Cellosaurus NCIt_id}
#' }
#'
#' @details This data represents the `sample_info.csv` file taken from the 22Q2
#' [Broad Institute](https://depmap.org/portal/download/) cancer depenedency
#' study. This dataset features the a primary key `depmap_id` which is a unique
#' ID given to each cell line and is found in the first column of this dataset.
#' The `depmap_id` attribute is used as a foreign key in all other datasets in
#' the package. This dataset has been converted to a long format tibble. This
#' dataset does not contain any expression or dependency data but rather
#' contains the metadata for all cancer cell lines used in the depmap project.
#' Variables names were converted to lower case, put in snake case, and
#' abbreviated where feasible (e.g. "Sanger ID" was changed to "sanger_id").
#'
#' @section Change log:
#'
#' - 19Q1: Initial dataset consisted of data frame with 1677 rows (cell lines)
#' and 9 variables, representing 0 genes, 1677 cell lines, 38 primary diseases
#' and 33 lineages
#'
#' - 19Q2: adds 37 new cell lines, 1 primary disease and 1 lineage. This version
#' of the metadata dataset contains 6 variables not found in previous versions,
#' relating the the Achilles metadata:  `Achilles_n_replicates`,
#' `cell_line_NNMD`, `culture_type`, `culture_medium`, and `cas9_activity`.
#'
#' - 19Q3: adds 30 cell lines, 2 primary diseases and 2 lineages
#'
#' - 19Q4: adds 42 cell lines, 0 primary diseases and 3 lineages
#'
#' - 20Q1: adds 19 cell lines, `gender` was changed to `sex`, `age`,
#' `primary_or_metastasis` and `sample_collection_site`` were added
#'
#' - 20Q2: adds 30 cell lines and 1 lineage
#'
#' - 20Q3: adds new column `WTSI_master_cell_ID`
#'
#' - 20Q4: adds 6 cell lines and 1 lineage. Adds column `cell_line_name`
#'
#' - 21Q1: removes 1 cell line
#'
#' - 21Q2: adds 3 cell lines
#'
#' - 21Q3: adds 1130 cell lines, 8 primary diseases and 8 lineages
#'
#' - 21Q4: removes 1119 cell lines, 8 primary diseases and 8 lineages
#'
#' - 22Q1: adds 4 cell lines. The features relating to Achilles metadata have
#' been removed and put into their own dataset: `Achilles_n_replicates`,
#' `cell_line_NNMD`, `culture_type`, `culture_medium`, and `cas9_activity`.
#'
#' - 22Q2: adds 11 cell lines and removes 2 primary diseases and 30 lineages.
#' The feature `culture_type` has been removed and columns "model_manipulation",
#' "model_manipulation_details", "patient_id", "parent_depmap_id",
#' "Cellosaurus_NCIt_disease", "Cellosaurus_NCIt_id" and "Cellosaurus_issues"
#' have been added.
#'
#' @docType data
#'
#' @import dplyr
#'
#' @keywords datasets
#'
#' @examples
#' \dontrun{
#' depmap_metadata()
#' }
#'
#' @references Tsherniak, A., Vazquez, F., Montgomery, P. G., Weir, B. A.,
#' Kryukov, G., Cowley, G. S., ... & Meyers, R. M. (2017). Defining a cancer
#' dependency map. Cell, 170(3), 564-576.
#'
#' DepMap, Broad (2019): DepMap Achilles 19Q1
#' Public. https://figshare.com/articles/DepMap_Achilles_19Q1_Public/7655150
#'
#' Robin M. Meyers, Jordan G. Bryan, James M. McFarland, Barbara
#' A. Weir, ...  David E. Root, William C. Hahn, Aviad
#' Tsherniak. Computational correction of copy number effect improves
#' specificity of CRISPR-Cas9 essentiality screens in cancer
#' cells. Nature Genetics 2017 October 49:1779–1784.
#'
#' Mahmoud Ghandi, Franklin W. Huang, Judit Jané-Valbuena, Gregory
#' V. Kryukov, ... Todd R. Golub, Levi A. Garraway & William
#' R. Sellers. 2019. Next- generation characterization of the Cancer
#' Cell Line Encyclopedia. Nature 569, 503–508 (2019).
#'
#' @source DepMap, Broad Institute: https://depmap.org/portal/download/
#'
#' @rdname metadata
#'
#' @aliases depmap_metadata metadata_19Q1 metadata_19Q2 metadata_19Q3
#' metadata_19Q4 metadata_20Q1 metadata_20Q2 metadata_20Q3 metadata_20Q4
#' metadata_21Q1 metadata_21Q2 metadata_21Q3 metadata_21Q4 metadata_22Q1
#' metadata_22Q2
#'
metadata <- NULL

### =========================================================================
### depmap metadata 20Q2 data 
### -------------------------------------------------------------------------
### this script generates the metadata_20Q2.csv
## note: this script assumes that your current directory is depmap/inst/scripts/

meta_20Q2 <- data.frame(
    Title = c(paste0("crispr_20Q2"), 
              paste0("copyNumber_20Q2"),
              paste0("TPM_20Q2"),
              paste0("mutationCalls_20Q2"),
              paste0("metadata_20Q2"),
              paste0("proteomic_20Q2")),
    Description = c( paste0("(CERES) Batch and off-target corrected CRISPR-Cas9 ", 
                           "gene knockdout dependency data for 18119 genes, ", 
                           "769 cell lines, 29 primary diseases and 26 ", 
                           "lineages."), 
                    paste0("WES log copy number data for 27639 genes, 1745 ", 
                           "cell lines, 35 primary diseases and 37 lineages."),
                    paste0("CCLE 'Transcript Per Million' (TPM) RNAseq gene ", 
                           "expression data (in scale scale (log2(TPM+1))) ", 
                           "for protein coding genes from 19144 genes, 1304 ", 
                           "cancer cell lines, 32 primary diseases and 34 ", 
                           "lineages."), 
                    paste0("Merged mutation calls (for coding region, germline ", 
                           "filtered) and includes data from 18802 genes, 1741 ", 
                           "cell lines, 35 primary diseases and 37 lineages. "),
                    paste0("Metadata for cell lines in the 20Q2 DepMap release, ", 
                           "for 0 genes, 1804 cell lines, 35 primary diseases ", 
                           "and 38 lineages."),
                    paste0("Quantitative profiling of 12399 proteins in 375 cell ",
                           "lines, 24 primary diseases and 27 lineages by mass ",
                           "spectrometry across 375 cell lines from the Gygi lab.")),
    BiocVersion = "3.12",
    Genome = "", 
    SourceType = "CSV", 
    SourceUrl = c(paste0("https://ndownloader.figshare.com/files/22629068"),
                  paste0("https://ndownloader.figshare.com/files/22629107"),
                  paste0("https://ndownloader.figshare.com/files/22629092"),
                  paste0("https://ndownloader.figshare.com/files/22629110"),
                  paste0("https://ndownloader.figshare.com/files/22629137"),
                  paste0("https://gygi.med.harvard.edu/sites/gygi.med.harvard.edu/files/documents/protein_quant_current_normalized.csv.gz")),
    SourceVersion = "May 15 2020",
    Species = "Homo sapiens",
    TaxonomyId = 9606,
    Coordinate_1_based = TRUE,
    DataProvider = "Broad Institute",
    Maintainer = "Theo Killian <theodore.killian@uclouvain.be>",
    RDataClass = "tibble",
    DispatchClass = "Rda",
    RDataPath = c(paste0("depmap/crispr_20Q2.rda"), 
                  paste0("depmap/copyNumber_20Q2.rda"),
                  paste0("depmap/TPM_20Q2.rda"),
                  paste0("depmap/mutationCalls_20Q2.rda"),
                  paste0("depmap/metadata_20Q2.rda"),
                  paste0("depmap/proteomic_20Q2.rda")),
    Tags=paste0("ExperimentHub, ExperimentData, ReproducibleResearch, RepositoryData, AssayDomainData, ", 
                "CopyNumberVariationData, DiseaseModel, CancerData, BreastCancerData, ColonCancerData, ", 
                "KidneyCancerData, LeukemiaCancerData, LungCancerData, OvarianCancerData, ProstateCancerData", 
                "OrganismData, Homo_sapiens_Data, PackageTypeData, SpecimenSource, CellCulture, Genome, ", 
                "Proteome, StemCell, Tissue"),
    Notes = "This dataset is from the 20Q2 release")

write.csv(meta_20Q2, file = "../extdata/metadata_20Q2.csv", row.names = FALSE)
## to upload this metadata to EH, enter the following into the CL
## ExperimentHubData::makeExperimentHubMetadata("~/tmp/depmap/", fileName = "metadata_20Q2.csv")

## List of URLs obtained from the DepMap Figshare page
## (https://figshare.com/authors/Broad_DepMap/5514062) on the
## 15 August 2024
depmapURLs <-
    c("https://figshare.com/articles/dataset/DepMap_24Q2_Public/25880521",
      "https://figshare.com/articles/dataset/DepMap_23Q4_Public/24667905",
      "https://figshare.com/articles/dataset/DepMap_23Q2_Public/22765112",
      "https://figshare.com/articles/dataset/DepMap_22Q4_Public/21637199",
      "https://figshare.com/articles/dataset/DepMap_22Q2_Public/19700056",
      "https://figshare.com/articles/dataset/DepMap_22Q1_Public/19139906",
      "https://figshare.com/articles/dataset/DepMap_21Q4_Public/16924132",
      "https://figshare.com/articles/dataset/DepMap_21Q2_Public/14541774",
      "https://figshare.com/articles/dataset/DepMap_21Q3_Public/15160110",
      "https://figshare.com/articles/dataset/public_21q1/13681534",
      "https://figshare.com/articles/dataset/DepMap_20Q4_Public/13237076",
      "https://figshare.com/articles/dataset/public_20q3/12931238",
      "https://figshare.com/articles/dataset/DepMap_20Q2_Public/12280541",
      "https://figshare.com/articles/dataset/DepMap_20Q1_Public/11791698",
      "https://figshare.com/articles/dataset/DepMap_19Q4_Public/11384241",
      "https://figshare.com/articles/dataset/DepMap_19Q3_Public/9201770",
      "https://figshare.com/articles/dataset/DepMap_19Q2_Public/8061398",
      "https://figshare.com/articles/dataset/DepMap_GeCKO_19Q1/7668407",
      "https://figshare.com/articles/dataset/DepMap_Achilles_19Q1_Public/7655150",
      "https://figshare.com/articles/dataset/DepMap_Achilles_18Q4_public/7270880",
      "https://figshare.com/articles/dataset/DepMap_Achilles_18Q3_public/6931364",
      "https://figshare.com/articles/dataset/Project_SCORE_processed_with_CERES/9116732",
      "https://figshare.com/articles/dataset/Project_Score_Chronos/14461980",
      "https://figshare.com/articles/dataset/DEMETER_2_Combined_RNAi/9170975",
      "https://figshare.com/articles/dataset/Repurposing_Public_23Q2/23600310",
      "https://figshare.com/articles/dataset/PRISM_Repurposing_19Q3_Primary_Screen/9393293",
      "https://figshare.com/articles/dataset/PRISM_Repurposing_20Q2_Dataset/20564034")

dmsets <- tibble(url = depmapURLs) |>
    mutate(dataset_id = as.integer(sub("^.+/", "", url))) |>
    mutate(data = DepMapDataset(dataset_id )) |>
    mutate(title = sapply(data, dmTitle)) |>
    mutate(n_files = sapply(data, dmNumFiles)) |>
    select(title, dataset_id, n_files, url, data)

dmfiles <- DepMapFiles(dmsets$data)
## or dmfiles <- DepMapFiles(DepMapDataset(depmap$dataset_id))

extdata <- "~/repos/OS/depmap/inst/extdata"
saveRDS(dmsets, file = file.path(extdata, "dmsets.rds"))
saveRDS(dmfiles, file = file.path(extdata, "dmfiles.rds"))

### =========================================================================
### depmap metadata 22Q2 data 
### -------------------------------------------------------------------------
### This script generates the metadata_22Q2.csv
## note: this script assumes that your current directory is depmap/inst/scripts/
# setwd("~/tmp/depmap/inst/scripts/")
## Links to download: https://depmap.org/portal/download/

data.frame(
    Title = c("crispr_22Q2", "copyNumber_22Q2", "TPM_22Q2",
              "mutationCalls_22Q2", "metadata_22Q2", "achilles_22Q2"),
    Description = c(
        paste0("(CERES) Batch and off-target corrected CRISPR-Cas9 gene, ",
               "knockdout dependency data for 17386 genes, 1086 cell lines, ",
               "31 primary diseases and 28 lineages."),
        paste0("Inferred log copy number data for 25368 genes, 1766 cell ",
               "lines, 33 primary diseases and 30 lineages."),
        paste0("CCLE 'Transcript Per Million' (TPM) RNAseq gene expression ",
               "data (in scale scale (log2(TPM+1))) for protein coding genes ",
               "from 19221 genes, 1406 cell lines, 33 primary diseases ",
               "and 30 lineages."),
        paste0("CCLE mutation calls (for coding region, germline filtered) ",
               "and includes data from 18784 genes, 1771 cell lines, 33 ", 
               "primary diseases and 30 lineages."),
        paste0("Metadata for cell lines in the 22Q2 DepMap release, for 0 ",
               "genes, 1840 cell lines, 33 primary diseases and 30 lineages."),
        paste0("Metadata for DepMap’s cancer models/cell lines, specific to ",
               "Project Achilles’ 22Q2 CRISPR screens.")),
    BiocVersion = "3.16",
    Genome = "", 
    SourceType = "CSV",
    SourceUrl = c("https://ndownloader.figshare.com/files/34990036",
                  "https://ndownloader.figshare.com/files/34989937",
                  "https://ndownloader.figshare.com/files/34989919",
                  "https://ndownloader.figshare.com/files/34989940",
                  "https://ndownloader.figshare.com/files/35020903",
                  "https://ndownloader.figshare.com/files/34989901"),
    SourceVersion = "May 9 2022",
    Species = "Homo sapiens",
    TaxonomyId = 9606,
    Coordinate_1_based = TRUE,
    DataProvider = "Broad Institute",
    Maintainer = "Theo Killian <theo.killian@vib.be>",
    RDataClass = "tibble",
    DispatchClass = "Rda",
    RDataPath = c("depmap/crispr_22Q2.rda",
                  "depmap/copyNumber_22Q2.rda",
                  "depmap/TPM_22Q2.rda",
                  "depmap/mutationCalls_22Q2.rda",
                  "depmap/metadata_22Q2.rda",
                  "depmap/achilles_22Q2.rda"),
    Tags = paste0(
 "ExperimentHub, ExperimentData, ReproducibleResearch, RepositoryData, ",
 "AssayDomainData, CopyNumberVariationData, DiseaseModel, CancerData, ",
 "BreastCancerData, ColonCancerData, KidneyCancerData, LeukemiaCancerData, ",
 "LungCancerData, OvarianCancerData, ProstateCancerData OrganismData, ",
 "Homo_sapiens_Data, PackageTypeData, SpecimenSource, CellCulture, Genome, ", 
 "Proteome, StemCell, Tissue"),
    Notes = "This dataset is from the 22Q2 release") -> meta_22Q2

write.csv(meta_22Q2, file = "../extdata/metadata_22Q2.csv", row.names = FALSE)
## to upload this metadata to EH, enter the following into the CL
# ExperimentHubData::makeExperimentHubMetadata(pathToPackage = "~/tmp/depmap/",
#                                              fileName = "metadata_22Q2.csv")

### =========================================================================
### depmap metadata 19Q4 data 
### -------------------------------------------------------------------------
### this script generates the metadata_19Q4.csv
## note: this script assumes that your current directory is depmap/inst/scripts/

meta_19Q4 <- data.frame(
    Title = c(# paste0("rnai_19Q4"), ## not found in Q4 release
              paste0("crispr_19Q4"), 
              paste0("copyNumber_19Q4"),
              # paste0("RPPA_19Q4"), ## not found in Q4 release
              paste0("TPM_19Q4"),
              paste0("mutationCalls_19Q4"),
              paste0("metadata_19Q4") #,
              # paste0("drug_sensitivity_19Q4") ## not found in Q4 release
              ),
    Description = c( #paste0("(DEMETER2) Batch and off-target corrected RNAi ", ## not found in Q4 release
                     #      "gene knockdown dependency data for 17309 genes, ", 
                     #      "712 cancer cell lines, 31 primary Diseases and ", 
                     #      "31 lineages."),
                    paste0("(CERES) Batch and off-target corrected CRISPR-Cas9 ", 
                           "gene knockdout dependency data for 18333 genes, ", 
                           "689 cell lines, 29 primary diseases and 26 ", 
                           "lineages."), 
                    paste0("WES log copy number data for 27639 genes, 1682 ", 
                           "cell lines, 35 primary diseases and 36 lineages."),
                    # paste0("Reverse Phase Protein Array (RPPA) Western Blot ",  ## not found in Q4 release
                    #        "expression data from 214 genes, 899 cancer cell ", 
                    #        "lines, 28 primary diseases and 28 lineages."),
                    paste0("CCLE 'Transcript Per Million' (TPM) RNAseq gene ", 
                           "expression data (in scale scale (log2(TPM+1))) ", 
                           "for protein coding genes from 19144 genes, 1249 ", 
                           "cancer cell lines, 32 primary diseases and 34 ", 
                           "lineages."), 
                    paste0("Merged mutation calls (for coding region, germline ", 
                           "filtered) and includes data from 18798 genes, 1666 ", 
                           "cell lines, 35 primary diseases and 36 lineages. "),
                    paste0("Metadata for cell lines in the 19Q4 DepMap release, ", 
                           "for 0 genes, 1756 cell lines, 35 primary diseases ", 
                           "and 37 lineages.") #,
                    # paste0("Drug sensitivity data for cancer cell lines ", ## not found in Q4 release
                    #        "derived from replicate collapsed logfold change ",
                    #        "values relative to DMSO, corrected for experimental ",
                    #        "confounders using ComBat representing 4686 compounds, ",
                    #        "578 cell lines, 23 primary diseases and 25 lineages")
                    ),
    BiocVersion = "3.11",
    Genome = "", 
    SourceType = "CSV", 
    SourceUrl = c(# paste0("https://ndownloader.figshare.com/files/13515395"), ## not updated
                  paste0("https://ndownloader.figshare.com/files/20234073"),
                  paste0("https://ndownloader.figshare.com/files/20234367"),
                  # paste0("https://depmap.org/portal/download/api/download/external?file_name=ccle%2Fccle_2019%2FCCLE_RPPA_20181003.csv"), ## not updated
                  paste0("https://ndownloader.figshare.com/files/20234346"),
                  paste0("https://ndownloader.figshare.com/files/20274747"),
                  paste0("https://ndownloader.figshare.com/files/20274744") #,
                  # paste0("https://ndownloader.figshare.com/files/17008628") ## not updated
                  ),
    SourceVersion = "Dec 20 2019",
    Species = "Homo sapiens",
    TaxonomyId = 9606,
    Coordinate_1_based = TRUE,
    DataProvider = "Broad Institute",
    Maintainer = "Theo Killian <theodore.killian@uclouvain.be>",
    RDataClass = "tibble",
    DispatchClass = "Rda",
    RDataPath = c(#paste0("depmap/rnai_19Q4.rda"), 
                  paste0("depmap/crispr_19Q4.rda"), 
                  paste0("depmap/copyNumber_19Q4.rda"), 
                  #paste0("depmap/RPPA_19Q4.rda"), 
                  paste0("depmap/TPM_19Q4.rda"),
                  paste0("depmap/mutationCalls_19Q4.rda"),
                  paste0("depmap/metadata_19Q4.rda") #,
                  #paste0("depmap/drug_sensitivity_19Q4.rda")
                  ),
    Tags=paste0("ExperimentHub, ExperimentData, ReproducibleResearch, RepositoryData, AssayDomainData, ", 
                "CopyNumberVariationData, DiseaseModel, CancerData, BreastCancerData, ColonCancerData, ", 
                "KidneyCancerData, LeukemiaCancerData, LungCancerData, OvarianCancerData, ProstateCancerData", 
                "OrganismData, Homo_sapiens_Data, PackageTypeData, SpecimenSource, CellCulture, Genome, ", 
                "Proteome, StemCell, Tissue"),
    Notes = "This dataset is from the 19Q4 release")

write.csv(meta_19Q4, file="../extdata/metadata_19Q4.csv", row.names=FALSE)
## to upload this metadata to EH, enter the following into the CL
## ExperimentHubData::makeExperimentHubMetadata("~/tmp/depmap/", fileName = "metadata_19Q4.csv")

### =========================================================================
### depmap metadata 19Q1 data
### -------------------------------------------------------------------------
### this script generates the metadata_19Q1.csv
## note: this script assumes that your current directory is depmap/inst/scripts/

meta_19Q1 <- data.frame(
    Title = c(paste0("rnai_19Q1"),
              paste0("crispr_19Q1"), 
              paste0("copyNumber_19Q1"),
              paste0("RPPA_19Q1"), 
              paste0("TPM_19Q1"),
              paste0("mutationCalls_19Q1"),
              paste0("metadata_19Q1")),
    Description = c(paste0("(DEMETER2) Batch and off-target corrected RNAi ", 
                           "gene knockdown dependency data for 17309 genes, ", 
                           "711 cancer cell lines, 30 primary Diseases and ", 
                           "31 lineages."), 
                    paste0("(CERES) Batch and off-target corrected CRISPR-Cas9 ", 
                           "gene knockdout dependency data for 17634 genes, ", 
                           "558 cell lines, 26 primary diseases and 28 ", 
                           "lineages."), 
                    paste0("WES log copy number data for 23299 genes, 1604 ", 
                           "cell lines, 38 primary diseases and 33 lineages."),
                    paste0("Reverse Phase Protein Array (RPPA) Western Blot ", 
                           "expression data from 214 genes, 899 cancer cell ", 
                           "lines, 28 primary diseases and 28 lineages."),
                    paste0("CCLE 'Transcript Per Million' (TPM) RNAseq gene ", 
                           "expression data (in scale scale (log2(TPM+1))) ", 
                           "for protein coding genes from 57820 genes, 1165 ", 
                           "cancer cell lines, 33 primary diseases and 32 ", 
                           "lineages."), 
                    paste0("Merged mutation calls (for coding region, germline ", 
                           "filtered) and includes data from 18755 genes, 1601 ", 
                           "cell lines, 37 primary diseases and 33 lineages. "),
                    paste0("Metadata for cell lines in the 19Q1 DepMap release, ", 
                           "for 0 genes, 1677 cell lines, 38 primary diseases ", 
                           "and 33 lineages.")),
    BiocVersion = "3.10",
    Genome = "", 
    SourceType = "CSV", 
    SourceUrl = c(paste0("https://ndownloader.figshare.com/files/13515395"),
                  paste0("https://ndownloader.figshare.com/files/14221385"),
                  paste0("https://depmap.org/portal/download/api/download/external?file_name=ccle%2Fdepmap-wes-cn-data-97cc.14%2Fpublic_19Q1_gene_cn.csv"),
                  paste0("https://depmap.org/portal/download/api/download/external?file_name=ccle%2Fdepmap-rnaseq-expression-data-ccd0.12%2FCCLE_depMap_19Q1_TPM.csv"),
                  paste0("https://depmap.org/portal/download/api/download/external?file_name=ccle%2FCCLE_RPPA_20180123.csv"),
                  paste0("https://depmap.org/portal/download/api/download/external?file_name=ccle%2Fdepmap-mutation-calls-9a1a.7%2Fdepmap_19Q1_mutation_calls.csv"),
                  paste0("https://depmap.org/portal/download/api/download/external?file_name=processed_portal_downloads%2Fdepmap-public-cell-line-metadata-183e.4%2FDepMap-2019q1-celllines_v2.csv")),
    SourceVersion = "Feb 19 2019",
    Species = "Homo sapiens",
    TaxonomyId = 9606,
    Coordinate_1_based = TRUE,
    DataProvider = "Broad Institute",
    Maintainer = "Theo Killian <theodore.killian@uclouvain.be>",
    RDataClass = "tibble",
    DispatchClass = "Rda",
    RDataPath = c(paste0("depmap/rnai_19Q1.rda"), 
                  paste0("depmap/crispr_19Q1.rda"), 
                  paste0("depmap/copyNumber_19Q1.rda"), 
                  paste0("depmap/RPPA_19Q1.rda"), 
                  paste0("depmap/TPM_19Q1.rda"),
                  paste0("depmap/mutationCalls_19Q1.rda"),
                  paste0("depmap/metadata_19Q1.rda")),
    Tags=paste0("ExperimentHub, ExperimentData, ReproducibleResearch, RepositoryData, AssayDomainData, ", 
                "CopyNumberVariationData, DiseaseModel, CancerData, BreastCancerData, ColonCancerData, ", 
                "KidneyCancerData, LeukemiaCancerData, LungCancerData, OvarianCancerData, ProstateCancerData", 
                "OrganismData, Homo_sapiens_Data, PackageTypeData, SpecimenSource, CellCulture, Genome, ", 
                "Proteome, StemCell, Tissue"),
    Notes = "This dataset is from the 19Q1 release")

write.csv(meta_19Q1, file="../extdata/metadata_19Q1.csv", row.names=FALSE)
## to upload this metadata to EH, enter the following into the CL
## ExperimentHubData::makeExperimentHubMetadata("~/tmp/depmap/", fileName = "metadata_19Q2.csv")

### =========================================================================
### depmap metadata 20Q4 data 
### -------------------------------------------------------------------------
### this script generates the metadata_20Q4.csv
## note: this script assumes that your current directory is depmap/inst/scripts/
## https://depmap.org/portal/download/

meta_20Q4 <- data.frame(
    Title = c(paste0("crispr_20Q4"), 
              paste0("copyNumber_20Q4"),
              paste0("TPM_20Q4"),
              paste0("mutationCalls_20Q4"),
              paste0("metadata_20Q4")),
    Description = c(
        paste0("(CERES) Batch and off-target corrected CRISPR-Cas9 gene, ",
               "knockdout dependency data for 18119 genes, 808 cell lines, 31 ",
               "primary diseases and 29 lineages."), 
        paste0("WES log copy number data for 27562 genes, 1753 cell lines, 35 ",
               "primary diseases and 38 lineages."),
        paste0("CCLE 'Transcript Per Million' (TPM) RNAseq gene expression ",
               "data (in scale scale (log2(TPM+1))) for protein coding genes ",
               "from 19182 genes, 1376 cancer cell lines, 33 primary diseases ",
               "and 37 lineages."), 
        paste0("CCLE mutation calls (for coding region, germline filtered) ",
               "and includes data from 18789 genes, 1749 cell lines, 35 ", 
               "primary diseases and 38 lineages. "),
        paste0("Metadata for cell lines in the 20Q4 DepMap release, for 0 ",
               "genes, 1812 cell lines, 35 primary diseases and 39 lineages.")),
    BiocVersion = "3.12",
    Genome = "", 
    SourceType = "CSV", 
    SourceUrl = c(paste0("https://ndownloader.figshare.com/files/25494359"),
                  paste0("https://ndownloader.figshare.com/files/25494416"),
                  paste0("https://ndownloader.figshare.com/files/25494389"),
                  paste0("https://ndownloader.figshare.com/files/25494419"),
                  paste0("https://ndownloader.figshare.com/files/25494443")),
    SourceVersion = "Nov 20 2020",
    Species = "Homo sapiens",
    TaxonomyId = 9606,
    Coordinate_1_based = TRUE,
    DataProvider = "Broad Institute",
    Maintainer = "Theo Killian <theodore.killian@kuleuven.vib.be>",
    RDataClass = "tibble",
    DispatchClass = "Rda",
    RDataPath = c(paste0("depmap/crispr_20Q4.rda"), 
                  paste0("depmap/copyNumber_20Q4.rda"),
                  paste0("depmap/TPM_20Q4.rda"),
                  paste0("depmap/mutationCalls_20Q4.rda"),
                  paste0("depmap/metadata_20Q4.rda")),
    Tags = paste0("ExperimentHub, ExperimentData, ReproducibleResearch, RepositoryData, AssayDomainData, ", 
                "CopyNumberVariationData, DiseaseModel, CancerData, BreastCancerData, ColonCancerData, ", 
                "KidneyCancerData, LeukemiaCancerData, LungCancerData, OvarianCancerData, ProstateCancerData", 
                "OrganismData, Homo_sapiens_Data, PackageTypeData, SpecimenSource, CellCulture, Genome, ", 
                "Proteome, StemCell, Tissue"),
    Notes = "This dataset is from the 20Q4 release")

write.csv(meta_20Q4, file = "../extdata/metadata_20Q4.csv", row.names = FALSE)
## to upload this metadata to EH, enter the following into the CL
## ExperimentHubData::makeExperimentHubMetadata("~/tmp/depmap/", fileName = "metadata_20Q4.csv")

### =========================================================================
### depmap metadata 21Q3 data 
### -------------------------------------------------------------------------
### this script generates the metadata_21Q3.csv
## note: this script assumes that your current directory is depmap/inst/scripts/
## https://depmap.org/portal/download/

data.frame(
    Title = c(paste0("crispr_21Q3"), 
              paste0("copyNumber_21Q3"),
              paste0("TPM_21Q3"),
              paste0("mutationCalls_21Q3"),
              paste0("metadata_21Q3")),
    Description = c(
        paste0("(CERES) Batch and off-target corrected CRISPR-Cas9 gene, ",
               "knockdout dependency data for 17393 genes, 1032 cell lines, 32 ",
               "primary diseases and 30 lineages."),
        paste0("WES log copy number data for 27562 genes, 1741 cell lines, 35 ",
               "primary diseases and 37 lineages."),
        paste0("CCLE 'Transcript Per Million' (TPM) RNAseq gene expression ",
               "data (in scale scale (log2(TPM+1))) for protein coding genes ",
               "from 19177 genes, 1377 cell lines, 33 primary diseases ",
               "and 37 lineages."),
        paste0("CCLE mutation calls (for coding region, germline filtered) ",
               "and includes data from 18784 genes, 1746 cell lines, 35 ", 
               "primary diseases and 37 lineages."),
        paste0("Metadata for cell lines in the 21Q3 DepMap release, for 0 ",
               "genes, 2944 cell lines, 43 primary diseases and 47 lineages.")),
    BiocVersion = "3.14",
    Genome = "", 
    SourceType = "CSV",
    SourceUrl = c(paste0("https://ndownloader.figshare.com/files/29125323"), 
                  paste0("https://ndownloader.figshare.com/files/29125230"), 
                  paste0("https://ndownloader.figshare.com/files/29124747"),
                  paste0("https://ndownloader.figshare.com/files/29125233"),
                  paste0("https://ndownloader.figshare.com/files/29162481")),
    SourceVersion = "Aug 20 2021",
    Species = "Homo sapiens",
    TaxonomyId = 9606,
    Coordinate_1_based = TRUE,
    DataProvider = "Broad Institute",
    Maintainer = "Theo Killian <theo.killian@kuleuven.be>",
    RDataClass = "tibble",
    DispatchClass = "Rda",
    RDataPath = c(paste0("depmap/crispr_21Q3.rda"),
                  paste0("depmap/copyNumber_21Q3.rda"),
                  paste0("depmap/TPM_21Q3.rda"),
                  paste0("depmap/mutationCalls_21Q3.rda"),
                  paste0("depmap/metadata_21Q3.rda")),
    Tags = paste0(
 "ExperimentHub, ExperimentData, ReproducibleResearch, RepositoryData, ",
 "AssayDomainData, CopyNumberVariationData, DiseaseModel, CancerData, ",
 "BreastCancerData, ColonCancerData, KidneyCancerData, LeukemiaCancerData, ",
 "LungCancerData, OvarianCancerData, ProstateCancerData OrganismData, ",
 "Homo_sapiens_Data, PackageTypeData, SpecimenSource, CellCulture, Genome, ", 
 "Proteome, StemCell, Tissue"),
    Notes = "This dataset is from the 21Q3 release") -> meta_21Q3

write.csv(meta_21Q3, file = "../extdata/metadata_21Q3.csv", row.names = FALSE)
## to upload this metadata to EH, enter the following into the CL
# ExperimentHubData::makeExperimentHubMetadata(pathToPackage = "~/tmp/depmap/",
#                                              fileName = "metadata_21Q3.csv")

---
title: "The depmap data"
author:
- name: Theo Killian
- name: Laurent Gatto
  affiliation: Computational Biology, UCLouvain
date: "`r Sys.Date()`"
output:
  BiocStyle::html_document:
    toc_float: true
vignette: >
  %\VignetteIndexEntry{depmap}
  %\VignetteEngine{knitr::rmarkdown}
  %\usepackage[utf8]{inputenc}
---

```{r style, echo = FALSE, results = 'asis'}
BiocStyle::markdown()
```

```{r, echo = FALSE}
suppressPackageStartupMessages(library("tidyverse"))
```

# Introduction

The `depmap` package aims to provide a reproducible research framework
to cancer dependency data described by [Tsherniak, Aviad, et
al. "Defining a cancer dependency map." Cell 170.3 (2017):
564-576.](https://www.ncbi.nlm.nih.gov/pubmed/28753430).  The data
found in the
[depmap](https://bioconductor.org/packages/devel/data/experiment/html/depmap.html)
package has been formatted to facilitate the use of common R packages
such as `dplyr` and `ggplot2`. We hope that this package will allow
researchers to more easily mine, explore and visually illustrate
dependency data taken from the Depmap cancer genomic dependency study.

# Installation instructions

To install
[depmap](https://bioconductor.org/packages/devel/data/experiment/html/depmap.html),
the
[BiocManager](https://cran.r-project.org/web/packages/BiocManager/index.html)
Bioconductor Project Package Manager is required. If
[BiocManager](https://cran.r-project.org/web/packages/BiocManager/index.html)
is not already installed, it will need to be done so beforehand. Type
(within R) install.packages("BiocManager") (This needs to be done just
once.)

```{r install, eval=FALSE}
install.packages("BiocManager")
BiocManager::install("depmap")
```

The `depmap` package fully depends on the `ExperimentHub` Bioconductor
package, which allows the data accessed in this package to be stored
and retrieved from the cloud.

```{r import_EH, message = FALSE}
library("depmap")
library("ExperimentHub")
```

# Tidy depmap data

The
[depmap](https://bioconductor.org/packages/devel/data/experiment/html/depmap.html)
package currently contains eight datasets available through
`ExperimentHub`.

The data found in this R package has been converted from a "wide"
format `.csv` file to "long" format .rda file. None of the values
taken from the original datasets have been changed, although the
columns have been re-arranged.  Descriptions of the changes made are
described under the `Details` section after querying the relevant
dataset.

```{r ehquery}
## create ExperimentHub query object
eh <- ExperimentHub()
query(eh, "depmap")
```

Each dataset has a `ExperimentHub` accession number, (e.g. *EH2260*
refers to the `rnai` dataset from the 19Q1 release).

## RNA inference knockout data


The `rnai` dataset contains the combined genetic dependency data for
RNAi - induced gene knockdown for select genes and cancer cell
lines. This data corresponds to the
`D2_combined_genetic_dependency_scores.csv` file.

Specific `rnai` datasets can be accessed, such as `rnai_19Q1` by EH number.

```{r, eval = FALSE}
eh[["EH2260"]]
```

The most recent `rnai` dataset can be automatically loaded into R by
using the `depmap_rnai` function.

```{r}
depmap::depmap_rnai()
```

## CRISPR-Cas9 knockout data

The `crispr` dataset contains the (batch corrected CERES inferred gene
effect) CRISPR-Cas9 knockout data of select genes and cancer cell
lines. This data corresponds to the `gene_effect_corrected.csv` file.

Specific `crispr` datasets can be accessed, such as `crispr_19Q1` by
EH number.

```{r, eval = FALSE}
eh[["EH2261"]]
```

The most recent `crispr` dataset can be automatically loaded into R by
using the `depmap_crispr` function.

```{r}
depmap::depmap_crispr()
```

## WES copy number data

The `copyNumber` dataset contains the WES copy number data, relating
to the numerical log-fold copy number change measured against the
baseline copy number of select genes and cell lines. This dataset
corresponds to the `public_19Q1_gene_cn.csv`

Specific `copyNumber` datasets can be accessed, such as
`copyNumber_19Q1` by EH number.

```{r, eval = FALSE}
eh[["EH2262"]]
```

The most recent `copyNumber` dataset can be automatically loaded into
R by using the `depmap_copyNumber` function.

```{r}
depmap::depmap_copyNumber()
```

## CCLE Reverse Phase Protein Array data


The `RPPA` dataset contains the CCLE Reverse Phase Protein Array
(RPPA) data which corresponds to the `CCLE_RPPA_20180123.csv` file.

Specific `RPPA` datasets can be accessed, such as `RPPA_19Q1` by EH
number.

```{r, eval = FALSE}
eh[["EH2263"]]
```

The most recent `RPPA` dataset can be automatically loaded into R by
using the `depmap_RPPA` function.

```{r}
depmap::depmap_RPPA()
```

## CCLE RNAseq gene expression data

The `TPM` dataset contains the CCLE RNAseq gene expression data. This
shows expression data only for protein coding genes (using scale
log2(TPM+1)). This data corresponds to the `CCLE_depMap_19Q1_TPM.csv`
file.

Specific `TPM` datasets can be accessed, such as `TPM_19Q1` by EH number.

```{r, eval = FALSE}
eh[["EH2264"]]
```

The `TPM` dataset can also be accessed by using the `depmap_TPM` function.

```{r}
depmap::depmap_TPM()
```

## Cancer cell lines

The `metadata` dataset contains the metadata about all of the cancer
cell lines.  It corresponds to the `depmap_19Q1_cell_lines.csv` file.

Specific `metadata` datasets can be accessed, such as `metadata_19Q1`
by EH number.

```{r, eval = FALSE}
eh[["EH2266"]]
```

The most recent `metadata` dataset can be automatically loaded into R by using
the `depmap_metadata` function.

```{r}
depmap::depmap_metadata()
```


## Mutation calls


The `mutationCalls` dataset contains all merged mutation calls (coding
region, germline filtered) found in the depmap dependency study. This
dataset corresponds with the `depmap_19Q1_mutation_calls.csv` file.

Specific `mutationCalls` datasets can be accessed, such as
`mutationCalls_19Q1` by EH number.

```{r, eval = FALSE}
eh[["EH2265"]]
```

The most recent `mutationCalls` dataset can be automatically loaded into R by
using the  `depmap_mutationCalls` function.

```{r}
depmap::depmap_mutationCalls()
```


## Drug Sensitivity

The `drug_sensitivity` dataset contains dependency data for cancer
cell lines treated with various compounds. This dataset corresponds
with the `primary_replicate_collapsed_logfold_change.csv` file.

Specific `drug_sensitivity` datasets can be accessed, such as
`drug_sensitivity_19Q3` by EH number.

```{r, eval = FALSE}
 eh[["EH3087"]]
```

The most recent `drug_sensitivity` dataset can be automatically loaded
into R by using the `depmap_drug_sensitivity` function.

```{r}
depmap::depmap_drug_sensitivity()
```

## Proteomic

The `proteomic` dataset contains normalized quantitative profiling of
proteins of cancer cell lines by mass spectrometry. This dataset
corresponds with the
`https://gygi.med.harvard.edu/sites/gygi.med.harvard.edu/files/documents/protein_quant_current_normalized.csv.gz`
file.

Specific `proteomic` datasets can be accessed, such as
`proteomic_20Q2` by EH number.

```{r, eval = FALSE}
eh[["EH3459"]]
```

The most recent `proteomic` dataset can be automatically loaded into R by
using the `depmap_proteomic` function.

```{r}
depmap::depmap_proteomic()
```


## Repackaged data source

If desired, the original data from which the
[depmap](https://bioconductor.org/packages/depmap) package were
derived from can be downloaded from the [Broad
Institute](https://depmap.org/portal/download/) website. The
instructions on how to download these files and how the data was
transformed and loaded into the
[depmap](https://bioconductor.org/packages/depmap) package can be
found in the `make_data.R` file found in `./inst/scripts`. (It should
be noted that the original uncompressed *.csv* files are > 1.5GB in
total and take a moderate amount of time to download remotely.)

# Original depmap data

In addition to the re-packaged files, the package also allows to
download any of the original files provided by the [DepMap project on
Figshare](https://figshare.com/authors/Broad_DepMap/5514062).

A list of all the datasets is available with the `dmsets()` function:

```{r}
dmsets()
```

We could check what datasets from any quarter of 2020 are available by
searching for `"20Q"` in the datasets titles:

```{r, message=FALSE}
library(tidyverse)
dmsets() |>
    filter(grepl("20Q", title))
```

Let's focus on the *PRISM Repurposing 20Q2 Dataset* dataset, with
identifier `20564034`.

A list of all the files is available with the `dmfiles()` function:

```{r}
dmfiles()
```

If we want to find all files from the *PRISM Repurposing 20Q2 Dataset*
identified above, we could filter all files with its `dataset_id`:

```{r}
dmfiles() |>
    filter(dataset_id == 20564034)
```

Let's now focus on the
`prism-repurposing-20q2-primary-screen-cell-line-info.csv` file. We
can filter it by its name and downloaded it with `dmget()`:

```{r}
dmfiles() |>
    filter(name == "prism-repurposing-20q2-primary-screen-cell-line-info.csv") |>
    dmget()
```

The `dmget()` function will first check if it hasn't already been
downloaded and cached in the depmap cache directory (see
`?dmCache()`). If so, it will retrieve if from there. Otherwise, it
will download the file and store it in the package cache directory. It
will return the location of the cached file.

Given that the file is in csv format, we can directly open it with
`read_csv()`:

```{r}
dmfiles() |>
    filter(name == "prism-repurposing-20q2-primary-screen-cell-line-info.csv") |>
    dmget() |>
    read_csv()
```

It is also possible to pass multiple rows of the `dmfiles()` table to
`dmget()` to retrieve multiple file paths. Below, let's get all the
README.txt files from 2020:

```{r}
ids_2020 <- filter(dmsets(), grepl("20Q", title)) |>
    pull(dataset_id)

dmfiles() |>
    filter(dataset_id %in% ids_2020) |>
    filter(grepl("README", name)) |>
    dmget()
```

# Session information

```{r echo = FALSE}
sessionInfo()

---
title: "Using the depmap data"
author:
- name: Theo Killian
- name: Laurent Gatto
  affiliation: Computational Biology, UCLouvain
date: "`r Sys.Date()`"
output:
  BiocStyle::html_document:
    toc_float: true
vignette: >
  %\VignetteIndexEntry{depmap use cases}
  %\VignetteEngine{knitr::rmarkdown}
  %\usepackage[utf8]{inputenc}
---

```{r style, echo = FALSE, results = 'asis'}
BiocStyle::markdown()
```

This vignette illustrates use cases and visualizations of the data
found in the [depmap](https://bioconductor.org/packages/devel/data/experiment/html/depmap.html)
package. See the *depmap* vignette for details about the datasets.

# Introduction

The [depmap](https://bioconductor.org/packages/devel/data/experiment/html/depmap.html)
package aims to provide a reproducible research framework to cancer dependency
data described by [Tsherniak, Aviad, et al. "Defining a cancer dependency map."
Cell 170.3 (2017): 564-576.](https://www.ncbi.nlm.nih.gov/pubmed/28753430). The
data found in the [depmap](https://bioconductor.org/packages/devel/data/experiment/html/depmap.html)
package has been formatted to facilitate the use of common R packages such as
`dplyr` and `ggplot2`. We hope that this package will allow researchers to more
easily mine, explore and visually illustrate dependency data taken from the
Depmap cancer genomic dependency study.

# Use cases

Perhaps the most interesting datasets found within the
[depmap](https://bioconductor.org/packages/devel/data/experiment/html/depmap.html)
package are those that relate to the cancer gene dependency score, such as
`rnai` and `crispr`. These datasets contain a score expressing how vital a
particular gene is in terms of how lethal the knockout/knockdown of that gene is
on a target cell line. For example, a highly negative dependency score implies
that a cell line is highly dependent on that gene.

Load necessary libaries.

```{r load_libraries, message=FALSE, warning=FALSE, echo=TRUE}
library("dplyr")
library("ggplot2")
library("viridis")
library("tibble")
library("gridExtra")
library("stringr")
library("depmap")
library("ExperimentHub")
```

Load the `rnai`, `crispr` and `copyNumber` datasets for visualization. Note: the
datasets listed below are from the 19Q3 release. Newer datasets, such as those
from the 20Q1 release are available.

```{r load_data, message=FALSE, warning=FALSE, echo=TRUE}
## create ExperimentHub query object
eh <- ExperimentHub()
query(eh, "depmap")
rnai <- eh[["EH3080"]]
mutationCalls <- eh[["EH3085"]]
metadata <- eh[["EH3086"]]
TPM <- eh[["EH3084"]]
copyNumber <- eh[["EH3082"]]
# crispr <- eh[["EH3081"]]
# drug_sensitivity <- eh[["EH3087"]]
```

By importing the `depmap` data into the R environment, the data can be mined
more effectively. For example, if one interested researching soft tissue
sarcomas and wanted to search all such cancer cell lines for the gene with the
greatest dependency, it is possible to accomplish this task by using data
manipulation and visualization tools `dplyr` and `ggplot2`. Below, the `rnai`
dataset is selected for cell lines with *"SOFT_TISSUE"* in the CCLE name, and
displaying a list of the highest dependency scores.

```{r, soft_tissue_cell_lines, echo=TRUE}
## list of dependency scores
rnai |>
    dplyr::select(cell_line, gene_name, dependency) |>
    dplyr::filter(stringr::str_detect(cell_line, "SOFT_TISSUE")) |>
    dplyr::arrange(dependency) |>
    head(10)
```

As the gene `RPL14` appears several times in the top dependencies scores, it may
make an interesting candidate target. Below, a plot of the `rnai` data is
displayed as a histogram showing the distribution of dependency scores for gene
`RPL14`.

```{r message=FALSE, warning=FALSE}
## Basic histogram
rnai |>
    dplyr::select(gene, gene_name, dependency) |>
    dplyr::filter(gene_name == "RPL14") |>
    ggplot(aes(x = dependency)) +
    geom_histogram() +
    geom_vline(xintercept = mean(rnai$dependency, na.rm = TRUE),
               linetype = "dotted", color = "red") +
    ggtitle("Histogram of dependency scores for gene RPL14")
```

A more complex plot of the `rnai` data, as shown below involves plotting the
distribution of dependency scores for gene `RPL14` for each major type of
cancer, while highlighting the nature of mutations of this gene in such cancer
cell lines (e.g. if such are COSMIC hotspots, damaging, etc.). Notice that the
plot above reflects the same overall distribution in two dimensions.

```{r message=FALSE, warning=FALSE}
meta_rnai <- metadata |>
    dplyr::select(depmap_id, lineage) |>
    dplyr::full_join(rnai, by = "depmap_id") |>
    dplyr::filter(gene_name == "RPL14") |>
    dplyr::full_join((mutationCalls |>
                      dplyr::select(depmap_id, entrez_id,
                                    is_cosmic_hotspot, var_annotation)),
                     by = c("depmap_id", "entrez_id"))

p1 <- meta_rnai |>
      ggplot(aes(x = dependency, y = lineage)) +
      geom_point(alpha = 0.4, size = 0.5) +
      geom_point(data = subset(
         meta_rnai, var_annotation == "damaging"), color = "red") +
      geom_point(data = subset(
         meta_rnai, var_annotation == "other non-conserving"), color = "blue") +
      geom_point(data = subset(
         meta_rnai, var_annotation == "other conserving"), color = "cyan") +
      geom_point(data = subset(
         meta_rnai, is_cosmic_hotspot == TRUE), color = "orange") +
      geom_vline(xintercept=mean(meta_rnai$dependency, na.rm = TRUE),
                 linetype = "dotted", color = "red") +
      ggtitle("Scatterplot of dependency scores for gene RPL14 by lineage")

p1
```

Below is a boxplot displaying expression values for gene `RPL14` by lineage:

```{r message=FALSE, warning=FALSE}
metadata |>
    dplyr::select(depmap_id, lineage) |>
    dplyr::full_join(TPM, by = "depmap_id") |>
    dplyr::filter(gene_name == "RPL14") |>
    ggplot(aes(x = lineage, y = expression, fill = lineage)) +
    geom_boxplot(outlier.alpha = 0.1) +
    ggtitle("Boxplot of expression values for gene RPL14 by lineage") +
    theme(axis.text.x = element_text(angle = 45, hjust=1)) +
    theme(legend.position = "none")
```

High dependency, high expression genes are more likely to interesting research
targets. Below is a plot of expression vs rnai gene dependency for
Rhabdomyosarcoma Sarcoma:

```{r  message=FALSE, warning=FALSE}
## expression vs rnai gene dependency for Rhabdomyosarcoma Sarcoma
sarcoma <- metadata |>
    dplyr::select(depmap_id, cell_line,
                  primary_disease, subtype_disease) |>
    dplyr::filter(primary_disease == "Sarcoma",
                  subtype_disease == "Rhabdomyosarcoma")

rnai_sub <- rnai |>
    dplyr::select(depmap_id, gene, gene_name, dependency)
tpm_sub <- TPM |>
    dplyr::select(depmap_id, gene, gene_name, expression)

sarcoma_dep <- sarcoma |>
    dplyr::left_join(rnai_sub, by = "depmap_id") |>
    dplyr::select(-cell_line, -primary_disease,
                  -subtype_disease, -gene_name)

sarcoma_exp <- sarcoma |>
    dplyr::left_join(tpm_sub, by = "depmap_id")

sarcoma_dat_exp <- dplyr::full_join(sarcoma_dep, sarcoma_exp,
                                    by = c("depmap_id", "gene")) |>
    dplyr::filter(!is.na(expression))

p2 <- ggplot(data = sarcoma_dat_exp, aes(x = dependency, y = expression)) +
    geom_point(alpha = 0.4, size = 0.5) +
    geom_vline(xintercept=mean(sarcoma_dat_exp$dependency, na.rm = TRUE),
               linetype = "dotted", color = "red") +
    geom_hline(yintercept=mean(sarcoma_dat_exp$expression, na.rm = TRUE),
               linetype = "dotted", color = "red") +
    ggtitle("Scatterplot of rnai dependency vs expression values for gene")

p2 + theme(axis.text.x = element_text(angle = 45))
```

A selection of the genes shown above with the lowest depenency scores, also
displaying gene expression in TPM in the last column.

```{r}
sarcoma_dat_exp |>
    dplyr::select(cell_line, gene_name, dependency, expression) |>
    dplyr::arrange(dependency) |>
    head(10)
```

Below is a boxplot displaying log genomic copy number for gene `RPL14` by
lineage:

```{r message=FALSE, warning=FALSE}
metadata |>
    dplyr::select(depmap_id, lineage) |>
    dplyr::full_join(copyNumber, by = "depmap_id") |>
    dplyr::filter(gene_name == "RPL14") |>
    ggplot(aes(x = lineage, y = log_copy_number, fill = lineage)) +
    geom_boxplot(outlier.alpha = 0.1) +
    ggtitle("Boxplot of log copy number for gene RPL14 by lineage") +
    theme(axis.text.x = element_text(angle = 45, hjust = 1)) +
    theme(legend.position = "none")
```

# Session information

```{r echo = FALSE}
sessionInfo()
```

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RPPA.R
\docType{data}
\name{RPPA}
\alias{RPPA}
\alias{RPPA_19Q3}
\alias{RPPA_19Q2}
\alias{RPPA_19Q1}
\alias{depmap_RPPA}
\title{RPPA_19Q3}
\format{
A data frame with 192386 rows and 4 variables:
\describe{
    \item{depmap_id}{cancer cell line foreign key (i.e. "ACH-000001")}
    \item{cell_line}{CCLE name of cancer cell line (i.e. "NIHOVCAR3_OVARY")}
    \item{antibody}{Name of antibody targeting protein (i.e. "14-3-3_beta")}
    \item{expression}{Observed expression via RPPA of protein coding genes}
}
}
\source{
DepMap, Broad Institute: https://depmap.org/portal/download/
}
\usage{
RPPA
}
\description{
The `RPPA` dataset contains the 19Q3 CCLE Reverse Phase Protein Array (RPPA)
cellular model expression data. This dataset includes data from 214 genes,
899 cancer cell lines, 28 primary diseases and 28 lineages. The columns of
`RPPA` are: `depmap_id`, a foreign key corresponding to the cancer cell
lineage, `cell_line` which contains the common CCLE name of the cancer cell
lines, `gene` which contains the knockdown gene expression, `antibody`
containing the name of knocked down gene and `expression` containing
numerical protein expression data. This dataset can be loaded into R
environment with the `depmap_RPPA` function.
}
\details{
This data represents the `CCLE_RPPA_20181003.csv` file taken from
the 19Q3 [Broad Institute](https://depmap.org/portal/download/) cancer
depenedency study. The derived dataset found in the `depmap` package features
the addition of a foreign key `depmap_id` found in the first column of this
dataset, which was added from the `metadata` dataset. This dataset has been
converted to a long format tibble. Variables names from the original dataset
were converted to lower case, put in snake case, and abbreviated where
feasible.
}
\section{Change log}{


- 19Q1: Initial dataset consisted of a data frame with 192386 rows and 4
variables representing 214 genes, 899 cancer cell lines, 28 primary diseases
and 28 lineages.

- 19Q2: no change

- 19Q3: no change, no further releases are scheduled at this time.

- 19Q4: no change, no further releases are scheduled at this time.

- 20Q1: no change, no further releases are scheduled at this time.

- 20Q2: no change, no further releases are scheduled at this time.

- 20Q3: no change, no further releases are scheduled at this time.

- 20Q4: no change, no further releases are scheduled at this time.

- 21Q1: no change, no further releases are scheduled at this time.

- 21Q2: no change, no further releases are scheduled at this time.

- 21Q3: no change, no further releases are scheduled at this time.

- 21Q4: no change, no further releases are scheduled at this time.

- 22Q1: no change, no further releases are scheduled at this time.

- 22Q2: no change, no further releases are scheduled at this time.
}

\examples{
\dontrun{
depmap_RPPA()
}

}
\references{
Tsherniak, A., Vazquez, F., Montgomery, P. G., Weir, B. A.,
Kryukov, G., Cowley, G. S., ... & Meyers, R. M. (2017). Defining a cancer
dependency map. Cell, 170(3), 564-576.

Mahmoud Ghandi, Franklin W. Huang, Judit Jané-Valbuena, Gregory V. Kryukov,
... Todd R. Golub, Levi A. Garraway & William R. Sellers. 2019. Next-
generation characterization of the Cancer Cell Line Encyclopedia. Nature 569,
503–508 (2019).

Haoxin Li, Shaoyang Ning, Mahmoud Ghandi, Gregory V. Kryukov, Shuba Gopal,
... Levi A. Garraway & William R. Sellers. The landscape of cancer cell line
metabolism. Nature Medicine 25, 850-860 (2019).
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cache.R
\name{dmCache}
\alias{dmCache}
\title{Depmap Package Cache}
\usage{
dmCache()
}
\value{
The `dmCache()` function returns an instance of class
    `BiocFileCache`.
}
\description{
Function to access (and manage) the depmap package
cache. `dmCache()` returns the central `depmap` cache.
}
\details{
The cache is an object of class `BiocFileCache`, and created with
[BiocFileCache::BiocFileCache()]. It can be either the
package-wide cache as defined by `dmCache()` or an instaned
provided by the user.

When projects are cached, they are given a resource name
(`rname`), that is set to the file's identifier.
}
\examples{

## Default depmap cache
dmCache()
}
\author{
Laurent Gatto
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/depmap.R
\name{depmap_release}
\alias{depmap_release}
\title{Returns the depmap release}
\usage{
depmap_release()
}
\value{
\code{character(1)} with the depmap release
}
\description{
Returns the depmap release
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/proteomic.R
\docType{data}
\name{proteomic}
\alias{proteomic}
\alias{proteomic_20Q2}
\alias{depmap_proteomic}
\title{proteomic_20Q2}
\format{
A data frame with 24963776 rows (cell lines) and 12 variables:
\describe{
     \item{depmap_id}{Cell line foreign key (i.e. "ACH-000956")}
     \item{cell_line}{Name of cancer cell line (i.e. "22RV1_PROSTATE")}
     \item{gene_name}{HUGO symbol (e.g. "TSPAN6")}
     \item{entrez_id}{Ensembl ID (e.g. ENSG00000044574)}
     \item{protein_expression}{normalized protein expression}
     \item{protein}{protein name with TenPx (e.g. MDAMB468_BREAST_TenPx01)}
     \item{protein_id}{Protein ID (e.g. sp|P55011|S12A2_HUMAN)}
     \item{desc}{Description (e.g. S12A2_HUMAN Solute carrier family 12 member 2)}
     \item{group_id}{Group ID}
     \item{uniprot}{Uniprot ID (e.g. S12A2_HUMAN)}
     \item{uniprot_acc}{Uniprot accession ID (e.g. P55011)}
     \item{TenPx}{TenPx number (e.g. TenPx01)}
}
}
\source{
DepMap, Broad Institute: https://depmap.org/portal/download/
}
\usage{
proteomic
}
\description{
The `proteomic` dataset contains the 20Q2 quantitative profiling of proteins
via mass spectrometry from the Gygi lab. This dataset contains 12399 proteins
tested in 375 cell lines, including 24 primary diseases and 27 lineages. The
columns of this dataset are: `depmap_id`, a foreign key corresponding to the
cancer cell lineage, `cell_line` the common CCLE name of the cancer cell
lines, `gene_name` containing the HUGO gene name and `entrez_id` containing
only the entrez ID# and `protein_expression` which contains the normalized
protein expression for cancer cell lines. This dataset can be loaded into R
environment with the `depmap_proteomic` function.
}
\details{
This data originates from the `protein_quant_current_normalized.csv`
file taken from the 20Q2 [Broad Institute](https://depmap.org/portal/download/)
cancer depenedency study. The derived dataset found in the `depmap` package
features the addition of a foreign key `depmap_id` found in the first column
of this dataset, which was added from the `metadata` dataset. This dataset
has been converted to a long format tibble. Variables names from the original
dataset were converted to lower case, put in snake case, and abbreviated
where feasible.
}
\section{Change log}{


- 20Q2: Initial dataset consisted of a data frame with 24963776 rows
(cell lines) and 12 variables

- 20Q3: no change, no further releases are scheduled at this time.

- 20Q4: no change, no further releases are scheduled at this time.

- 21Q1: no change, no further releases are scheduled at this time.

- 21Q2: no change, no further releases are scheduled at this time.

- 21Q3: no change, no further releases are scheduled at this time.

- 21Q4: no change, no further releases are scheduled at this time.

- 22Q1: no change, no further releases are scheduled at this time.

- 22Q2: no change, no further releases are scheduled at this time.
}

\examples{
\dontrun{
depmap_proteomic()
}

}
\references{
David P. Nusinow, John Szpyt, Mahmoud Ghandi, Christopher M.  Rose,
E. Robert McDonald III, Marian Kalocsay, Judit Jané-Valbuena, Ellen
Gelfand, Devin K. Schweppe, Mark Jedrychowski, Javad Golji, Dale
A. Porter, Tomas Rejtar, Y. Karen Wang, Gregory V. Kryukov, Frank
Stegmeier, Brian K.  Erickson, Levi A. Garraway, William
R. Sellers, Steven P. Gygi (2020).  Quantitative Proteomics of the
Cancer Cell Line Encyclopedia. Cell 180, 2.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/DepMapFiles.R
\name{DepMapFiles}
\alias{DepMapFiles}
\alias{DepMapDataset}
\alias{dmFileNames}
\alias{dmTitle}
\alias{dmNumFiles}
\alias{dmsets}
\alias{dmfiles}
\alias{dmget}
\title{DepMap Dataset and Files}
\usage{
DepMapDataset(id)

DepMapFiles(x)

dmFileNames(object)

dmTitle(object)

dmNumFiles(object)

dmget(dmtab, cache = dmCache())

dmfiles()

dmsets()
}
\arguments{
\item{id}{`numeric()` with one or multiple DepMap dataset
identifier(s). Note that `id` is converted to an
integer. Missing values are not permitted.}

\item{x}{either an `numeric()` that will be passed to
`DepMapDataset` or an instance (or list of) `DepMapDataset`.}

\item{object}{an instance of class `DepMapDataset`.}

\item{dmtab}{A `tibble` or `data.frame` containing the file to be
downloaded, such as [dmfiles()], or created by
[DepMapFiles()]. If is expected to contain the `"name"`,
`"id"` and `"dowload_url"` variables.}

\item{cache}{Object of class [BiocFileCache()]. Default is to use
the central `depmap` cache returned by [dmCache()], but users
can use their own cache.}
}
\description{
Two tibbles are provided that give access to DepMap data, as
shared by the Broad Institute's DepMap project on Figshare
(https://figshare.com/authors/Broad_DepMap/5514062).

- The [dmsets()] function returns a tibble with DepMap
  datasets. Each dataset is described by its title, its unique
  identifier, the number of files it contains, the Figshare URL,
  and a `DepMapDataset` object that contains further details of
  the dataset.

- The [dmfiles()] function returns a tibble with DepMap
  files. Each file is described by its dataset identifier, its own
  unique identifier, its name, size (in bytes), a download URL,
  md5 hash and mime type.

- Depmap data files can be downloaded with the [dmget()] function,
  that takes as input a tibble or data.frame of depmap files such
  as `dmfiles`. Files are downloaded and automatically in the
  package's central cache. See [dmCache()].
}
\details{
The `DepMapDataset` class stores the informtion describing a
depmap dataset, as stored on Figshare (articles, as it's called
there). The [DepMapDataset()] constructor requires one or multiple
dataset identifiers and returns one or a list of instances.

The following accessors are available:
- [dmFileNames()] returns the dataset's filenames.
- [dmTitle()] returns the dataset's title.
- [dmNumFiles()] returns the number of files in the dataset.

(These are used to construct the main depmap dataset tibble.)

A tibble describing the files in depmap dataset can be cretated
with the [DepMapFiles()] function. It either takes one or multiple
dataset idenifiers, or one or a list of `DepMapDataset` instances

The [DepMapDataset()] and [DepMapFiles()] functions are mostly
used internally, to create the `dmsets` and `dmfiles` tibbles. If
a more recent dataset is available on Figshare and not (yet) in
the `depmap` package, a user might create the depmap files table
to download the files, and/or open a [GitHub
issue](https://github.com/UCLouvain-CBIO/depmap) for the new data
to be added by the maintainer(s).

All the information is retrieved from Figshare using their API, as
described at https://docs.figshare.com.
}
\section{Adding new datasets}{


Adding new datasets is simple. Once a new dataset (or Article, as
called on Figshare) has been identified on the Broad Institute's
[DepMap project on
Figshare](https://figshare.com/authors/Broad_DepMap/5514062), one
needs to add the dataset's URL to the `depmapURLs` vector in
[`inst/extdata/make-dmfiles.R`](https://github.com/UCLouvain-CBIO/depmap/blob/master/inst/scripts/make-dmfiles.R),
and re-run the script to update the `dmsets.rds.` and
`dmfiles.rds` files in `inst/extdata`.

Feel free to send a GitHub pull request or open a [GitHub
issue](https://github.com/UCLouvain-CBIO/depmap) for the new data
to be added by the maintainer(s).
}

\examples{

## The depmap datasets
dmsets

## The depmap files
dmfiles

############################################################
## Mostly for internal use, or to update/generate the depmap
## dataset and files tables.

## One dataset identifier: 24667905
my_dmset <- DepMapDataset(24667905)
my_dmset

## Multiple dataset identifiers
my_dmsets <- DepMapDataset(c(24667905, 22765112))
my_dmsets

## Create the files table from one or dataset multiple dataset
## identifiers

DepMapFiles(24667905)
DepMapFiles(my_dmset)

DepMapFiles(c(24667905, 22765112))
DepMapFiles(my_dmsets)
}
\author{
Laurent Gatto
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/copyNumber.R
\docType{data}
\name{copyNumber}
\alias{copyNumber}
\alias{depmap_copyNumber}
\alias{copyNumber_19Q1}
\alias{copyNumber_19Q2}
\alias{copyNumber_19Q3}
\alias{copyNumber_19Q4}
\alias{copyNumber_20Q1}
\alias{copyNumber_20Q2}
\alias{copyNumber_20Q3}
\alias{copyNumber_20Q4}
\alias{copyNumber_21Q1}
\alias{copyNumber_21Q2}
\alias{copyNumber_21Q3}
\alias{copyNumber_21Q4}
\alias{copyNumber_22Q1}
\alias{copyNumber_22Q2}
\title{copyNumber_22Q2}
\format{
A data frame with 44799888 rows (cell lines) and 6 variables.

\describe{
     \item{depmap_id}{Cancer cell line foreign key (i.e. "ACH-00001")}
     \item{gene}{HUGO symbol (e.g. "SAP25") and Entrez ID# (e.g. 100316904)}
     \item{gene_name}{HUGO symbol (e.g. "SAP25")}
     \item{entrez_id}{Entrez ID# (e.g. 100316904)}
     \item{log_copy_number}{numerical log fold change in copy number for a
     given gene and cell line}
     \item{cell_line}{CCLE name of cancer cell line (i.e. "184A1_BREAST")}
}
}
\source{
DepMap, Broad Institute: https://depmap.org/portal/download/
}
\usage{
copyNumber
}
\description{
The `copyNumber` dataset contains the 22Q2 inferred copy number data for
genes and cancer cell lines. This dataset includes data from 25368 genes,
1754 cell lines, 35 primary diseases and 38 lineages. The columns of
`copyNumber` are: `depmap_id`, a foreign key corresponding to the cancer
cell lineage, `cell_line` containing the common CCLE name of the cancer cell
lines, `gene` containing both the HUGO gene name of the knockdown gene along
with entrez ID#, `gene_name` containing only the HUGO gene name, `entrez_id`
containing only the entrez ID#, and `log_copy_number` containing the
numerical dependency score values for each pair of genes and cell lines.
This dataset can be loaded into the R environment with the
`depmap_copyNumber` function.
}
\details{
This data represents the `CCLE_gene_cn.csv` file taken from the
22Q2 [Broad Institute](https://depmap.org/portal/download/) cancer
depenedency study. The derived dataset found in the `depmap` package features
the addition of a foreign key `depmap_id` found in the first column of this
dataset, which was added from the `metadata` dataset. This dataset has been
converted to a long format tibble. Variables names from the original dataset
were converted to lower case, put in snake case, and abbreviated where
feasible.
}
\section{Change log}{


- 19Q1: Initial dataset consisted of a data frame with 37907473 rows
(cell lines) and 6 variables representing 23299 genes, 1604 cell lines, 38
primary diseases and 33 lineages.

- 19Q2: adds 23 cell lines and 1 lineage

- 19Q3: adds 3263 genes, 30 cell lines and removes 2 primary diseases. Now a
dataframe with 45670234 rows and 6 variables

- 19Q4: adds 77 genes, 25 cell lines, 0 primary diseases and 2 lineages

- 20Q1: adds 31 cell lines

- 20Q2: adds 32 cell lines

- 20Q3: no change

- 20Q4: removes 77 genes, adds 8 cell lines and 1 lineage

- 21Q1: removes 13 cell lines

- 21Q2: adds 2 cell lines

- 21Q3: removes 1 cell line and 1 lineage

- 21Q4: removes 194 genes and adds 9 cell lines

- 22Q1: removes 2000 genes, adds 4 cell lines and 1 lineage

- 22Q2: adds 12 cell lines and removes 2 primary diseases and 8 lineages
}

\examples{
\dontrun{
depmap_copyNumber()
}

}
\references{
Tsherniak, A., Vazquez, F., Montgomery, P. G., Weir, B. A.,
Kryukov, G., Cowley, G. S., ... & Meyers, R. M. (2017). Defining a cancer
dependency map. Cell, 170(3), 564-576.

DepMap, Broad (2019): DepMap Achilles 19Q1
Public. https://figshare.com/articles/DepMap_Achilles_19Q1_Public/7655150

Robin M. Meyers, Jordan G. Bryan, James M. McFarland, Barbara A. Weir, ...
David E. Root, William C. Hahn, Aviad Tsherniak. Computational correction of
copy number effect improves specificity of CRISPR-Cas9 essentiality screens
in cancer cells. Nature Genetics 2017 October 49:1779–1784.

Mahmoud Ghandi, Franklin W. Huang, Judit Jané-Valbuena, Gregory V. Kryukov,
... Todd R. Golub, Levi A. Garraway & William R. Sellers. 2019. Next-
generation characterization of the Cancer Cell Line Encyclopedia. Nature 569,
503–508 (2019).
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/crispr.R
\docType{data}
\name{crispr}
\alias{crispr}
\alias{depmap_crispr}
\alias{crispr_19Q1}
\alias{crispr_19Q2}
\alias{crispr_19Q3}
\alias{crispr_19Q4}
\alias{crispr_20Q1}
\alias{crispr_20Q2}
\alias{crispr_20Q3}
\alias{crispr_20Q4}
\alias{crispr_21Q1}
\alias{crispr_21Q2}
\alias{crispr_21Q3}
\alias{crispr_21Q4}
\alias{crispr_22Q1}
\alias{crispr_22Q2}
\title{crispr_22Q2}
\format{
A data frame with 18881196 rows (cell lines) and 6 variables:
\describe{
    \item{depmap_id}{Cancer cell line foreign key (i.e. "ACH-00001")}
    \item{gene}{HUGO symbol (e.g. "SAP25") and Entrez ID# (e.g. 100316904)}
    \item{gene_name}{HUGO symbol (e.g. "SAP25")}
    \item{entrez_id}{Entrez ID# (e.g. 100316904)}
    \item{dependency}{numerical depenency score of given gene and cell line}
    \item{cell_line}{CCLE name of cancer cell line (i.e. "184A1_BREAST")}
}
}
\source{
DepMap, Broad Institute: https://depmap.org/portal/download/
}
\usage{
crispr
}
\description{
The `crispr` dataset contains the 22Q2 genetic effect of CRISPR-Cas9 gene
knockout of select genes in various cancer cell lines. This dataset includes
data from 17386 genes, 1086 cell lines, 31 primary diseases and 28 lineages.
The columns of `crispr` are: `depmap_id` a foreign key corresponding to the
cancer cell lineage, `cell_line` containing the common CCLE name of the
cancer cell lines, `gene` containing both the HUGO gene name of the knockout
gene along with entrez ID#, `gene_name` containing only the HUGO gene name,
`entrez_id` containing only the entrez ID# and `dependency` which contains
the numerical dependency score values for each pair of genes and cell lines.
This dataset can be loaded into R environment with the `depmap_crispr`
function. NOTE: the `crispr` dataset has replaced the `rnai` dataset as the
primary supported measurement of cancer dependency data as of the 19Q4
release.
}
\details{
This data represents the `Achilles_gene_effect.csv` file taken from
the 22Q2 [Broad Institute](https://depmap.org/portal/download/) cancer
depenedency study. The derived dataset found in the `depmap` package features
the addition of a foreign key `depmap_id` found in the first column of this
dataset, which was added from the `metadata` dataset. This dataset has been
converted to a long format tibble. Variables names from the original dataset
were converted to lower case, put in snake case, and abbreviated where
feasible.
}
\section{Change log}{


- 19Q1: Initial dataset consisted of a data frame with 9839772 rows (cell
lines) and 6 variables representing 17634 genes, 558 cell lines, 26 primary
diseases and 28 lineages.

- 19Q2: adds 5 cell lines, 1 primary disease and 1 lineage

- 19Q3: adds 699 genes, 62 cell lines and 1 primary disease. Now a dataset
with 11458125 rows and 6 variables.

- 19Q4: adds 0 genes, 64 cell lines, 1 primary disease and 0 lineages.

- 20Q1: adds 50 cell lines.

- 20Q2: adds 30 cell lines.

- 20Q3: adds 20 cell lines, 1 primary disease and 1 lineages.

- 20Q4: adds 19 cell lines, 1 primary disease and 2 lineages

- 21Q1: no change

- 21Q2: removes 474 genes and adds 182 cell lines 1 primary disease and 1
 lineage

- 21Q3: removes 252 genes and adds 42 cell lines

- 21Q4: removes 7 genes and 22 cell lines

- 22Q1: adds 16 cell lines and 1 lineage

- 22Q2: adds 16 cell lines and removes 1 primary diseases and 3 lineages.
}

\examples{
\dontrun{
depmap_crispr()
}

}
\references{
Tsherniak, A., Vazquez, F., Montgomery, P. G., Weir, B. A.,
Kryukov, G., Cowley, G. S., ... & Meyers, R. M. (2017). Defining a cancer
dependency map. Cell, 170(3), 564-576.

DepMap, Broad (2019): DepMap Achilles 19Q1
Public. https://figshare.com/articles/DepMap_Achilles_19Q1_Public/7655150
Fileset.

Robin M. Meyers, Jordan G. Bryan, James M. McFarland, Barbara A. Weir, ...
David E. Root, William C. Hahn, Aviad Tsherniak. Computational correction of
copy number effect improves specificity of CRISPR-Cas9 essentiality screens
in cancer cells. Nature Genetics 2017 October 49:1779–1784.

Mahmoud Ghandi, Franklin W. Huang, Judit Jané-Valbuena, Gregory V. Kryukov,
... Todd R. Golub, Levi A. Garraway & William R. Sellers. 2019. Next-
generation characterization of the Cancer Cell Line Encyclopedia. Nature 569,
503–508 (2019).
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gene_summary.R
\docType{data}
\name{gene_summary}
\alias{gene_summary}
\alias{gene_summary_22Q1}
\alias{depmap_gene_summary}
\title{gene_summary_22Q1}
\format{
A data frame with 69746 rows (cell lines) and 7 variables:
\describe{
    \item{entrez_id}{Entrez ID# (e.g. 100316904)}
    \item{gene_name}{HUGO symbol (e.g. "SAP25")}
    \item{dataset}{which dataset this probability derives}
    \item{dependent_cell_lines}{number of dependent cell lines}
    \item{cell_lines_with_data}{number of cell lines with relevant dependency
     data}
    \item{strongly_selective}{Gene knockout is selective (not pan-lethal)}
    \item{common_essential}{common essential gene dependency}
}
}
\source{
DepMap, Broad Institute: https://depmap.org/portal/download/
}
\usage{
gene_summary
}
\description{
The `gene_summary` dataset contains the 22Q1 gene essentiality
probabilities for select genes. This dataset can be loaded into the R
environment with the `depmap_gene_summary` function.
}
\details{
This data represents the `Gene Dependency Profile Summary.csv` file
taken from the 22Q1
[Broad Institute](https://depmap.org/portal/api/download/gene_dep_summary)
release.
}
\section{Change log}{


- 22Q1: Initial dataset

- 22Q2: no change, no further releases are scheduled at this time.
}

\examples{
\dontrun{
depmap_gene_summary()
}

}
\references{
Tsherniak, A., Vazquez, F., Montgomery, P. G., Weir, B. A.,
Kryukov, G., Cowley, G. S., ... & Meyers, R. M. (2017). Defining a cancer
dependency map. Cell, 170(3), 564-576.

James M. McFarland, Zandra V. Ho, Guillaume Kugener, Joshua M. Dempster,
Phillip G. Montgomery, Jordan G. Bryan, John M. Krill-Burger, Thomas M.
Green, Francisca Vazquez, Jesse S. Boehm, Todd R. Golub, William C. Hahn,
David E. Root, Aviad Tsherniak. (2018). Improved estimation of cancer
dependencies from large-scale RNAi screens using model-based normalization
and data integration. Nature Communications 9, 1.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mutationCalls.R
\docType{data}
\name{mutationCalls}
\alias{mutationCalls}
\alias{depmap_mutationCalls}
\alias{mutationCalls_19Q1}
\alias{mutationCalls_19Q2}
\alias{mutationCalls_19Q3}
\alias{mutationCalls_19Q4}
\alias{mutationCalls_20Q1}
\alias{mutationCalls_20Q2}
\alias{mutationCalls_20Q3}
\alias{mutationCalls_20Q4}
\alias{mutationCalls_21Q1}
\alias{mutationCalls_21Q2}
\alias{mutationCalls_21Q3}
\alias{mutationCalls_21Q4}
\alias{mutationCalls_22Q1}
\alias{mutationCalls_22Q2}
\title{mutationCalls_22Q2}
\format{
A data frame with 1235466 rows and 32 variables:
\describe{
  \item{depmap_id}{depmap_id}
  \item{gene_name}{Hugo Symbol denotes a unique and meaningful name for each
  gene (e.g. SAP25)}
  \item{entrez_id}{Gene ID for NCBI Entrez gene database, (e.g. 100316904)}
  \item{ncbi_build}{NCBI Build (i.e. reference genome)}
  \item{chromosome}{Chromosome}
  \item{start_pos}{Gene start position}
  \item{end_pos}{Gene end position}
  \item{strand}{Strand location of gene}
  \item{var_class}{Variant Classification}
  \item{var_type}{Variant Type}
  \item{ref_allele}{Reference Allele}
  \item{alt_allele}{Tumor Seq Allele1}
  \item{dbSNP_RS}{Single Nucleotide Polymorphism Database (dbSNP) reference
   cluster}
  \item{dbSNP_val_status}{dbSNP Val Status}
  \item{genome_change}{Genome Change}
  \item{annotation_transcript}{Annotation Transcript}
  \item{cDNA_change}{change in cDNA}
  \item{codon_change}{Codon_Change}
  \item{protein_change}{Protein_Change}
  \item{is_deleterious}{Status of gene knockout on cell lineage}
  \item{is_tcga_hotspot}{isTCGAhotspot}
  \item{tcga_hsCnt}{TCGAhsCnt}
  \item{is_cosmic_hotspot}{isCOSMIChotspot}
  \item{cosmic_hsCnt}{COSMIChsCnt}
  \item{ExAC_AF}{ExAC_AF}
  \item{CGA_WES_AC}{CGA_WES_AC}
  \item{sanger_WES_AC}{SangerWES_AC}
  \item{RNAseq_AC}{RNAseq_AC}
  \item{HC_AC}{HC_AC}
  \item{RD_AC}{RD_AC}
  \item{WGS_AC}{WGS_AC}
  \item{var_annotation}{Variant_annotation}
}
}
\source{
DepMap, Broad Institute: https://depmap.org/portal/download/
}
\usage{
mutationCalls
}
\description{
The `mutationCalls` dataset contains merged the 22Q2 mutation calls (for
coding region, germline filtered) and includes data from 18784 genes, 1771
cell lines, 33 primary diseases and 30 lineages. This dataset can be
considered the metadata data set for mutations and does not contain any
dependency data. This dataset can be loaded into the R environment with the
`depmap_mutationCalls` function.
}
\details{
This data represents the `CCLE_mutations.csv` file taken from the
22Q2 [Broad Institute](https://depmap.org/portal/download/) cancer
depenedency study. The derived dataset found in the `depmap` package features
the addition of a foreign key `depmap_id` found in the first column of this
dataset, which was added from the `metadata` dataset. This dataset has been
converted to a long format tibble. Variables names from the original dataset
were converted to lower case, put in snake case, and abbreviated where
feasible.
}
\section{Change log}{


- 19Q1: Initial dataset for package consisted of dataframe with
  1243145 rows and 35 variables representing 18755 genes, 1601 cell
  lines, 37 primary diseases and 33 lineages.

- 19Q2: adds 30 cell lines, 1 primary disease and 1 lineage. This
  version has different columns than the previous version: the
  variable "VA_WES_AC" is no longer present in this dataset. Some
  minor alterations to the original file were made. The first
  column of the original dataset, (ID, Sample number) was removed,
  as this column was only the row number and did not serve any
  unique identifying purpose.

- 19Q3: adds 1 gene, 25 cell lines and removes 1 primary disease.

- 19Q4: adds 1 gene, 10 cell lines, 0 primary diseases and 2
  lineages.

- 20Q1: adds 4 genes, 31 cell lines, 1 lineage.

- 20Q2: adds 44 cell lines, 1 lineage.

- 20Q3: no change.

- 20Q4: removes 13 genes, adds 8 cell lines and 1 lineage. Columns
 `tumor_sample_barcode` and `sanger_recalib_WES_AC` were removed.

- 21Q1: removes 11 genes and 2 cell lines.

- 21Q2: removes 1 genes and adds 3 cell lines.

- 21Q3: removes 3 genes, 4 cell lines and 1 lineage.

- 21Q3: removes 3 genes, 4 cell lines and 1 lineage.

- 21Q4: adds 9 cell lines.

- 22Q1: adds 4 cell lines and 1 lineage. The variable `tumor_seq_allele1`
  was renamed `alt_allele`.

- 22Q2: adds 12 cell lines and removes 2 primary diseases and 8
  lineages.
}

\examples{
\dontrun{
depmap_mutationCalls()
}

}
\references{
Tsherniak, A., Vazquez, F., Montgomery, P. G., Weir, B. A.,
Kryukov, G., Cowley, G. S., ... & Meyers, R. M. (2017). Defining a cancer
dependency map. Cell, 170(3), 564-576.

DepMap, Broad (2019): DepMap Achilles 19Q1
Public. https://figshare.com/articles/DepMap_Achilles_19Q1_Public/7655150

Robin M. Meyers, Jordan G. Bryan, James M. McFarland, Barbara
A. Weir, ...  David E. Root, William C. Hahn, Aviad
Tsherniak. Computational correction of copy number effect improves
specificity of CRISPR-Cas9 essentiality screens in cancer
cells. Nature Genetics 2017 October 49:1779–1784.

Mahmoud Ghandi, Franklin W. Huang, Judit Jané-Valbuena, Gregory V. Kryukov,
... Todd R. Golub, Levi A. Garraway & William R. Sellers. 2019. Next-
generation characterization of the Cancer Cell Line Encyclopedia. Nature 569,
503–508 (2019).
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/TPM.R
\docType{data}
\name{TPM}
\alias{TPM}
\alias{depmap_TPM}
\alias{TPM_19Q1}
\alias{TPM_19Q2}
\alias{TPM_19Q3}
\alias{TPM_19Q4}
\alias{TPM_20Q1}
\alias{TPM_20Q2}
\alias{TPM_20Q3}
\alias{TPM_20Q4}
\alias{TPM_21Q1}
\alias{TPM_21Q2}
\alias{TPM_21Q3}
\alias{TPM_21Q4}
\alias{TPM_22Q1}
\alias{TPM_22Q2}
\title{TPM_22Q2}
\format{
A data frame with 27024726 rows (cell lines) and 6 variables:
\describe{
     \item{depmap_id}{Cell line foreign key (i.e. "ACH-000956")}
     \item{cell_line}{Name of cancer cell line (i.e. "22RV1_PROSTATE")}
     \item{gene}{HUGO symbol and Ensembl ID (e.g. TSPAN6 (ENSG00000000003))}
     \item{gene_name}{HUGO symbol (e.g. "TSPAN6")}
     \item{ensembl_id}{Ensembl ID (e.g. ENSG00000044574)}
     \item{rna_expression}{Log fold (log2(TPM+1)) protein expression change}
}
}
\source{
DepMap, Broad Institute: https://depmap.org/portal/download/
}
\usage{
TPM
}
\description{
The `TPM` dataset contains the 22Q2 CCLE "Transcript Per Million" RNAseq gene
expression data for protein coding genes. This dataset includes data from
19221 genes, 1406 cell lines, 33 primary diseases and 30 lineages. The
columns of `TPM` are: `depmap_id`, a foreign key corresponding to the cancer
cell lineage, `cell_line` the common CCLE name of the cancer cell lines,
`gene` containing both the HUGO gene name of the knockdown gene along with
ensembl ID#, `gene_name` containing the HUGO gene name and `ensembl_id`
containing only the ensembl ID# and `rna_expression` which contains the
numerical protein coding gene expression change at scale (log2(TPM+1)). This
dataset can be loaded into R environment with the `depmap_TPM` function.
}
\details{
This data originates from the `CCLE_expression.csv` file taken
from the 22Q2 [Broad Institute](https://depmap.org/portal/download/) cancer
depenedency study. The derived dataset found in the `depmap` package features
the addition of a foreign key `depmap_id` found in the first column of this
dataset, which was added from the `metadata` dataset. This dataset has been
converted to a long format tibble. Variables names from the original dataset
were converted to lower case, put in snake case, and abbreviated where
feasible.
}
\section{Change log}{


- 19Q1: Initial dataset consisted of a data frame with 67360300 rows (cell
lines) and 6 variables representing 57820 genes, 1165 cell lines, 33
primary diseases, 32 lineages.

- 19Q2: removes 1618 genes, adds 36 cell lines, removes one primary disease
and adds 1 lineage

- 19Q3: removes 37058 genes, adds 9 cell lines, removes 2 primary diseases.
Now a 23164240 by 6 dataframe.

- 19Q4: 0 genes, 39 cancer cell lines, 0 primary diseases and 1 lineage

- 20Q1: adds 31 cell lines

- 20Q2: adds 34 cell lines. `expression` changed to `rna_expression`

- 20Q3: adds 1 cell line

- 20Q4: removes 38 genes and 71 cell lines, addes 1 primary disease and 3
 lineages

- 21Q1: removes 5 genes

- 21Q2: adds 3 cell lines. Additionally, a bug was fixed where the Entrez ID
appeared as Ensembl_ID. This was changed for all previous versions of this
dataset from 19Q3 to 21Q2

- 21Q3: removes 2 cell lines

- 21Q4: adds 12 cell lines

- 22Q1: adds 4 cell lines and 1 lineage

- 22Q2: adds 44 genes, 13 cell lines and removes 8 lineages
}

\examples{
\dontrun{
depmap_TPM()
}

}
\references{
Tsherniak, A., Vazquez, F., Montgomery, P. G., Weir, B. A.,
Kryukov, G., Cowley, G. S., ... & Meyers, R. M. (2017). Defining a cancer
dependency map. Cell, 170(3), 564-576.

DepMap, Broad (2019): DepMap Achilles 19Q1
Public. https://figshare.com/articles/DepMap_Achilles_19Q1_Public/7655150.
Fileset.

Robin M. Meyers, Jordan G. Bryan, James M. McFarland, Barbara A. Weir, ...
David E. Root, William C. Hahn, Aviad Tsherniak. Computational correction of
copy number effect improves specificity of CRISPR-Cas9 essentiality screens
in cancer cells. Nature Genetics 2017 October 49:1779–1784.

Mahmoud Ghandi, Franklin W. Huang, Judit Jané-Valbuena, Gregory V. Kryukov,
... Todd R. Golub, Levi A. Garraway & William R. Sellers. 2019. Next-
generation characterization of the Cancer Cell Line Encyclopedia. Nature 569,
503–508 (2019).
}
\keyword{datasets}
